# coding: utf-8

"""
    OpenAPI Definition

    The OpenAPI Specification is a standard format to define the structure and syntax of REST APIs. OpenAPI documents are both machine and human-readable, which enables anyone to easily determine how each API works. [More details](https://www.openapis.org/faq)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, SecretStr, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ApacheKafkaConfigV1Config(BaseModel):
    """
    
    """ # noqa: E501
    var_schema: Optional[StrictStr] = Field(default=None, description="Destination schema. Schema is permanent and cannot be changed after connection creation", alias="schema")
    consumer_group: Optional[StrictStr] = Field(default=None, description="Kafka consumer group name.")
    sync_type: Optional[Dict[str, Any]] = Field(default=None, description="Kafka sync type.  Unpacked messages must be valid JSON.")
    client_cert: Optional[SecretStr] = Field(default=None, description="Kafka client certificate.")
    sasl_scram512_secret: Optional[SecretStr] = Field(default=None, description="API Secret")
    sasl_plain_secret: Optional[SecretStr] = Field(default=None, description="API Secret")
    schema_registry_credentials_source: Optional[StrictStr] = Field(default=None, description="Schema Registry Credentials source")
    client_cert_key: Optional[SecretStr] = Field(default=None, description="Kafka client certificate key.")
    message_type: Optional[Dict[str, Any]] = Field(default=None, description="Kafka message type.")
    sasl_scram512_key: Optional[SecretStr] = Field(default=None, description="API Key")
    sasl_scram256_secret: Optional[SecretStr] = Field(default=None, description="API Secret")
    servers: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of Kafka servers in the format `server:port`.")
    sasl_plain_key: Optional[SecretStr] = Field(default=None, description="API Key")
    sasl_mechanism: Optional[Dict[str, Any]] = Field(default=None, description="SASL Mechanism")
    security_protocol: Optional[Dict[str, Any]] = Field(default=None, description="Security protocol for Kafka interaction.")
    sasl_scram256_key: Optional[SecretStr] = Field(default=None, description="API Key")
    schema_registry_secret: Optional[SecretStr] = Field(default=None, description="Schema Registry Secret")
    trusted_cert: Optional[SecretStr] = Field(default=None, description="Kafka trusted certificate.")
    schema_registry_urls: Optional[List[StrictStr]] = Field(default=None, description="Your schema registry URLs")
    schema_registry_key: Optional[SecretStr] = Field(default=None, description="Schema Registry Key")
    __properties: ClassVar[List[str]] = ["schema", "consumer_group", "sync_type", "client_cert", "sasl_scram512_secret", "sasl_plain_secret", "schema_registry_credentials_source", "client_cert_key", "message_type", "sasl_scram512_key", "sasl_scram256_secret", "servers", "sasl_plain_key", "sasl_mechanism", "security_protocol", "sasl_scram256_key", "schema_registry_secret", "trusted_cert", "schema_registry_urls", "schema_registry_key"]

    @field_validator('sync_type')
    def sync_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Packed', 'Unpacked'):
            raise ValueError("must be one of enum values ('Packed', 'Unpacked')")
        return value

    @field_validator('message_type')
    def message_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Text', 'Json', 'Avro', 'Protobuf'):
            raise ValueError("must be one of enum values ('Text', 'Json', 'Avro', 'Protobuf')")
        return value

    @field_validator('sasl_mechanism')
    def sasl_mechanism_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('PLAIN', 'SCRAM_SHA_512', 'SCRAM_SHA_256'):
            raise ValueError("must be one of enum values ('PLAIN', 'SCRAM_SHA_512', 'SCRAM_SHA_256')")
        return value

    @field_validator('security_protocol')
    def security_protocol_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('SASL', 'PLAINTEXT', 'TLS'):
            raise ValueError("must be one of enum values ('SASL', 'PLAINTEXT', 'TLS')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApacheKafkaConfigV1Config from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApacheKafkaConfigV1Config from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "schema": obj.get("schema"),
            "consumer_group": obj.get("consumer_group"),
            "sync_type": obj.get("sync_type"),
            "client_cert": obj.get("client_cert"),
            "sasl_scram512_secret": obj.get("sasl_scram512_secret"),
            "sasl_plain_secret": obj.get("sasl_plain_secret"),
            "schema_registry_credentials_source": obj.get("schema_registry_credentials_source"),
            "client_cert_key": obj.get("client_cert_key"),
            "message_type": obj.get("message_type"),
            "sasl_scram512_key": obj.get("sasl_scram512_key"),
            "sasl_scram256_secret": obj.get("sasl_scram256_secret"),
            "servers": obj.get("servers"),
            "sasl_plain_key": obj.get("sasl_plain_key"),
            "sasl_mechanism": obj.get("sasl_mechanism"),
            "security_protocol": obj.get("security_protocol"),
            "sasl_scram256_key": obj.get("sasl_scram256_key"),
            "schema_registry_secret": obj.get("schema_registry_secret"),
            "trusted_cert": obj.get("trusted_cert"),
            "schema_registry_urls": obj.get("schema_registry_urls"),
            "schema_registry_key": obj.get("schema_registry_key")
        })
        return _obj


