# coding: utf-8

"""
    OpenAPI Definition

    The OpenAPI Specification is a standard format to define the structure and syntax of REST APIs. OpenAPI documents are both machine and human-readable, which enables anyone to easily determine how each API works. [More details](https://www.openapis.org/faq)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, SecretStr, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AuroraPostgresConfigV1Config(BaseModel):
    """
    
    """ # noqa: E501
    public_key: Optional[StrictStr] = Field(default=None, description="Public Key")
    publication_name: Optional[StrictStr] = Field(default=None, description="Publication name. Specify only for `\"updated_method\": \"WAL_PGOUTPUT\"`.")
    connection_type: Optional[Dict[str, Any]] = Field(default=None, description="Possible values:`Directly`, `PrivateLink`, `SshTunnel`. `SshTunnel` is used as a value if this parameter is omitted in the request and any of the following parameter's values is specified: `tunnel_host`, `tunnel_port`, `tunnel_user`. Otherwise, `Directly` is used as a value if the parameter is omitted.")
    update_method: Optional[Dict[str, Any]] = Field(default=None, description="The method to detect new or changed rows. <br>Specify only for `\"service\": \"postgres\"` or `\"service\": \"postgres_rds\"`. <br>Supported values:<br>`WAL` - this method replicates new, changed and deleted rows by tailing the write-ahead log (WAL) via a logical slot. This is more efficient than the XMIN method, but requires more setup and monitoring.<br>`XMIN` - this method detects new or changed rows via the XMIN system column, but is not capable of detecting deleted rows.<br>`WAL_PGOUTPUT` -  logical replication of the WAL using the pgoutput plugin. This method replicates new, changed, and deleted rows by tailing the write-ahead log (WAL) using a logical slot.<br>`TELEPORT` - Fivetran's proprietary replication method that uses compressed snapshots to detect and apply changes.")
    always_encrypted: Optional[StrictBool] = Field(default=None, description="Require TLS through Tunnel")
    tunnel_user: Optional[StrictStr] = Field(default=None, description="SSH user, specify only to connect via an SSH tunnel.")
    tunnel_port: Optional[StrictInt] = Field(default=None, description="SSH port, specify only to connect via an SSH tunnel.")
    database: Optional[StrictStr] = Field(default=None, description="The database name.")
    password: Optional[SecretStr] = Field(default=None, description="The user's password.")
    port: Optional[StrictInt] = Field(default=None, description="The port number.")
    host: Optional[StrictStr] = Field(default=None, description="DB instance host or IP address.")
    tunnel_host: Optional[StrictStr] = Field(default=None, description="SSH host, specify only to connect via an SSH tunnel (do not use a load balancer).")
    schema_prefix: Optional[StrictStr] = Field(default=None, description="Destination schema prefix. Prefix for each replicated schema. For example with prefix 'x', source schemas 'foo' and 'bar' get replicated as 'x_foo' and 'x_bar'. The prefix is permanent and cannot be changed after connection creation")
    replication_slot: Optional[StrictStr] = Field(default=None, description="Replication slot name. Specify only for `\"updated_method\": \"WAL\"` or `\"WAL_PGOUTPUT\"`.")
    user: Optional[StrictStr] = Field(default=None, description="The user name.")
    __properties: ClassVar[List[str]] = ["public_key", "publication_name", "connection_type", "update_method", "always_encrypted", "tunnel_user", "tunnel_port", "database", "password", "port", "host", "tunnel_host", "schema_prefix", "replication_slot", "user"]

    @field_validator('connection_type')
    def connection_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Directly', 'PrivateLink', 'SshTunnel'):
            raise ValueError("must be one of enum values ('Directly', 'PrivateLink', 'SshTunnel')")
        return value

    @field_validator('update_method')
    def update_method_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('XMIN', 'TELEPORT', 'WAL_PGOUTPUT'):
            raise ValueError("must be one of enum values ('XMIN', 'TELEPORT', 'WAL_PGOUTPUT')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuroraPostgresConfigV1Config from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuroraPostgresConfigV1Config from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "public_key": obj.get("public_key"),
            "publication_name": obj.get("publication_name"),
            "connection_type": obj.get("connection_type"),
            "update_method": obj.get("update_method"),
            "always_encrypted": obj.get("always_encrypted"),
            "tunnel_user": obj.get("tunnel_user"),
            "tunnel_port": obj.get("tunnel_port"),
            "database": obj.get("database"),
            "password": obj.get("password"),
            "port": obj.get("port"),
            "host": obj.get("host"),
            "tunnel_host": obj.get("tunnel_host"),
            "schema_prefix": obj.get("schema_prefix"),
            "replication_slot": obj.get("replication_slot"),
            "user": obj.get("user")
        })
        return _obj


