# coding: utf-8

"""
    OpenAPI Definition

    The OpenAPI Specification is a standard format to define the structure and syntax of REST APIs. OpenAPI documents are both machine and human-readable, which enables anyone to easily determine how each API works. [More details](https://www.openapis.org/faq)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from openapi_client.models.connect_card_config import ConnectCardConfig
from openapi_client.models.connect_card_response import ConnectCardResponse
from openapi_client.models.connector_status_response import ConnectorStatusResponse
from openapi_client.models.setup_test_result_response import SetupTestResultResponse
from typing import Optional, Set
from typing_extensions import Self

class ConnectorResponseV1(BaseModel):
    """
    ConnectorResponseV1
    """ # noqa: E501
    id: StrictStr = Field(description="The unique identifier for the connector within the Fivetran system")
    service: StrictStr = Field(description="The connector type name within the Fivetran system")
    var_schema: StrictStr = Field(description="The name used both as the connector's name within the Fivetran system and as the source schema's name within your destination", alias="schema")
    paused: StrictBool = Field(description="Specifies whether the connector is paused")
    status: Optional[ConnectorStatusResponse] = None
    daily_sync_time: Optional[StrictStr] = Field(default=None, description="The connector daily sync start time that we return only when the sync frequency is set to 1440 (which means 24 hours) and the daily_sync_time parameter was set using the Create a Connector or Modify a Connector request")
    succeeded_at: Optional[datetime] = Field(default=None, description="The timestamp of the time the connector sync succeeded last time")
    connect_card: Optional[ConnectCardResponse] = None
    sync_frequency: StrictInt = Field(description="The connector sync frequency in minutes")
    pause_after_trial: StrictBool = Field(description="Specifies whether the connector should be paused after the free trial period has ended")
    data_delay_threshold: Optional[StrictInt] = Field(default=None, description="Custom sync delay notification threshold in minutes. The default value is 0. This parameter is only used when data_delay_sensitivity set to CUSTOM.")
    group_id: StrictStr = Field(description="The unique identifier for the group within the Fivetran system")
    connected_by: StrictStr = Field(description="The unique identifier of the user who has created the connector in your account")
    setup_tests: Optional[List[SetupTestResultResponse]] = Field(default=None, description="Setup tests results for this connector")
    source_sync_details: Optional[Dict[str, Any]] = Field(default=None, description="The additional information about the connector's state. The format of this parameter is specific for each connector type")
    data_delay_sensitivity: StrictStr = Field(description="The level of data delay notification threshold. Possible values: LOW, NORMAL, HIGH, CUSTOM. The default value NORMAL. CUSTOM is only available for customers using the [Enterprise plan](https://fivetran.com/docs/getting-started/pricing#fivetranplans) or above.")
    service_version: StrictInt = Field(description="The connector type version within the Fivetran system")
    created_at: datetime = Field(description="The timestamp of the time the connector was created in your account")
    failed_at: Optional[datetime] = Field(default=None, description="The timestamp of the time the connector sync failed last time")
    schedule_type: StrictStr = Field(description="The connector schedule configuration type. Supported values: auto, manual")
    connect_card_config: Optional[ConnectCardConfig] = None
    __properties: ClassVar[List[str]] = ["id", "service", "schema", "paused", "status", "daily_sync_time", "succeeded_at", "connect_card", "sync_frequency", "pause_after_trial", "data_delay_threshold", "group_id", "connected_by", "setup_tests", "source_sync_details", "data_delay_sensitivity", "service_version", "created_at", "failed_at", "schedule_type", "connect_card_config"]

    @field_validator('data_delay_sensitivity')
    def data_delay_sensitivity_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('LOW', 'NORMAL', 'HIGH', 'CUSTOM'):
            raise ValueError("must be one of enum values ('LOW', 'NORMAL', 'HIGH', 'CUSTOM')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    # JSON field name that stores the object type
    __discriminator_property_name: ClassVar[str] = 'service'

    # discriminator mappings
    __discriminator_value_class_map: ClassVar[Dict[str, str]] = {
        '15five': 'Model15fiveConnectorResponseV1','360learning': 'Model360learningConnectorResponseV1','6sense': 'Model6senseConnectorResponseV1','activecampaign': 'ActivecampaignConnectorResponseV1','acumatica': 'AcumaticaConnectorResponseV1','ada': 'AdaConnectorResponseV1','adjust': 'AdjustConnectorResponseV1','adobe_analytics': 'AdobeAnalyticsConnectorResponseV1','adobe_analytics_data_feed': 'AdobeAnalyticsDataFeedConnectorResponseV1','adobe_commerce': 'AdobeCommerceConnectorResponseV1','adp_workforce_now': 'AdpWorkforceNowConnectorResponseV1','adroll': 'AdrollConnectorResponseV1','affinity': 'AffinityConnectorResponseV1','afterpay': 'AfterpayConnectorResponseV1','aha': 'AhaConnectorResponseV1','aircall': 'AircallConnectorResponseV1','airtable': 'AirtableConnectorResponseV1','alchemer': 'AlchemerConnectorResponseV1','algolia': 'AlgoliaConnectorResponseV1','amazon_ads': 'AmazonAdsConnectorResponseV1','amazon_attribution': 'AmazonAttributionConnectorResponseV1','amazon_selling_partner': 'AmazonSellingPartnerConnectorResponseV1','amplitude': 'AmplitudeConnectorResponseV1','anaplan': 'AnaplanConnectorResponseV1','apache_kafka': 'ApacheKafkaConnectorResponseV1','appcues': 'AppcuesConnectorResponseV1','appfigures': 'AppfiguresConnectorResponseV1','apple_search_ads': 'AppleSearchAdsConnectorResponseV1','appsflyer': 'AppsflyerConnectorResponseV1','asana': 'AsanaConnectorResponseV1','assembled': 'AssembledConnectorResponseV1','atlassian_jira_align': 'AtlassianJiraAlignConnectorResponseV1','atlassian_ops_genie': 'AtlassianOpsGenieConnectorResponseV1','attentive': 'AttentiveConnectorResponseV1','attio': 'AttioConnectorResponseV1','aumni': 'AumniConnectorResponseV1','aurora': 'AuroraConnectorResponseV1','aurora_postgres': 'AuroraPostgresConnectorResponseV1','auth0': 'Auth0ConnectorResponseV1','autodesk_bim_360': 'AutodeskBim360ConnectorResponseV1','avantlink': 'AvantlinkConnectorResponseV1','awin': 'AwinConnectorResponseV1','aws_cloudtrail': 'AwsCloudtrailConnectorResponseV1','aws_cost': 'AwsCostConnectorResponseV1','aws_inventory': 'AwsInventoryConnectorResponseV1','aws_lambda': 'AwsLambdaConnectorResponseV1','aws_msk': 'AwsMskConnectorResponseV1','azure_blob_storage': 'AzureBlobStorageConnectorResponseV1','azure_boards': 'AzureBoardsConnectorResponseV1','azure_devops': 'AzureDevopsConnectorResponseV1','azure_event_hub': 'AzureEventHubConnectorResponseV1','azure_function': 'AzureFunctionConnectorResponseV1','azure_postgres': 'AzurePostgresConnectorResponseV1','azure_service_bus': 'AzureServiceBusConnectorResponseV1','azure_sql_db': 'AzureSqlDbConnectorResponseV1','azure_sql_managed_db': 'AzureSqlManagedDbConnectorResponseV1','ballotready': 'BallotreadyConnectorResponseV1','bamboohr': 'BamboohrConnectorResponseV1','big_commerce': 'BigCommerceConnectorResponseV1','bigquery_db': 'BigqueryDbConnectorResponseV1','billing_platform': 'BillingPlatformConnectorResponseV1','bingads': 'BingadsConnectorResponseV1','birdeye': 'BirdeyeConnectorResponseV1','bitly': 'BitlyConnectorResponseV1','box': 'BoxConnectorResponseV1','braintree': 'BraintreeConnectorResponseV1','braintree_sandbox': 'BraintreeSandboxConnectorResponseV1','branch': 'BranchConnectorResponseV1','braze': 'BrazeConnectorResponseV1','brevo': 'BrevoConnectorResponseV1','brex': 'BrexConnectorResponseV1','buildkite': 'BuildkiteConnectorResponseV1','business_central': 'BusinessCentralConnectorResponseV1','buzzsprout': 'BuzzsproutConnectorResponseV1','calabrio': 'CalabrioConnectorResponseV1','calendly': 'CalendlyConnectorResponseV1','campaignmonitor': 'CampaignmonitorConnectorResponseV1','canny': 'CannyConnectorResponseV1','care_quality_commission': 'CareQualityCommissionConnectorResponseV1','castor_edc': 'CastorEdcConnectorResponseV1','ceridian_dayforce': 'CeridianDayforceConnectorResponseV1','channel_advisor': 'ChannelAdvisorConnectorResponseV1','chargebee_product_catalog_1': 'ChargebeeProductCatalog1ConnectorResponseV1','chargebee_product_catalog_2': 'ChargebeeProductCatalog2ConnectorResponseV1','chargedesk': 'ChargedeskConnectorResponseV1','chartmogul': 'ChartmogulConnectorResponseV1','checkout': 'CheckoutConnectorResponseV1','checkr': 'CheckrConnectorResponseV1','chorusai': 'ChorusaiConnectorResponseV1','churnkey': 'ChurnkeyConnectorResponseV1','churnzero': 'ChurnzeroConnectorResponseV1','cimis': 'CimisConnectorResponseV1','cin7': 'Cin7ConnectorResponseV1','circleci': 'CircleciConnectorResponseV1','cj_commission_detail': 'CjCommissionDetailConnectorResponseV1','clari': 'ClariConnectorResponseV1','clickup': 'ClickupConnectorResponseV1','close': 'CloseConnectorResponseV1','cloudfront': 'CloudfrontConnectorResponseV1','coassemble': 'CoassembleConnectorResponseV1','codefresh': 'CodefreshConnectorResponseV1','collibra': 'CollibraConnectorResponseV1','column': 'ColumnConnectorResponseV1','concord': 'ConcordConnectorResponseV1','concur': 'ConcurConnectorResponseV1','confluence': 'ConfluenceConnectorResponseV1','confluent_cloud': 'ConfluentCloudConnectorResponseV1','contrast_security': 'ContrastSecurityConnectorResponseV1','convex': 'ConvexConnectorResponseV1','copper': 'CopperConnectorResponseV1','cosmos': 'CosmosConnectorResponseV1','coupa': 'CoupaConnectorResponseV1','criteo': 'CriteoConnectorResponseV1','crossbeam': 'CrossbeamConnectorResponseV1','crowddev': 'CrowddevConnectorResponseV1','customerio': 'CustomerioConnectorResponseV1','cvent': 'CventConnectorResponseV1','d2l_brightspace': 'D2lBrightspaceConnectorResponseV1','db2': 'Db2ConnectorResponseV1','db2i_hva': 'Db2iHvaConnectorResponseV1','db2i_sap_hva': 'Db2iSapHvaConnectorResponseV1','dbt_cloud': 'DbtCloudConnectorResponseV1','dcl_logistics': 'DclLogisticsConnectorResponseV1','dear': 'DearConnectorResponseV1','delighted': 'DelightedConnectorResponseV1','deputy': 'DeputyConnectorResponseV1','destini': 'DestiniConnectorResponseV1','dixa': 'DixaConnectorResponseV1','docebo': 'DoceboConnectorResponseV1','documentdb': 'DocumentdbConnectorResponseV1','double_click_campaign_manager': 'DoubleClickCampaignManagerConnectorResponseV1','double_click_publishers': 'DoubleClickPublishersConnectorResponseV1','drata': 'DrataConnectorResponseV1','drift': 'DriftConnectorResponseV1','drip': 'DripConnectorResponseV1','dropbox': 'DropboxConnectorResponseV1','dropbox_sign': 'DropboxSignConnectorResponseV1','dsv': 'DsvConnectorResponseV1','dynamics_365': 'Dynamics365ConnectorResponseV1','dynamics_365_fo': 'Dynamics365FoConnectorResponseV1','dynamodb': 'DynamodbConnectorResponseV1','easypost': 'EasypostConnectorResponseV1','economic': 'EconomicConnectorResponseV1','elastic_cloud': 'ElasticCloudConnectorResponseV1','eloqua': 'EloquaConnectorResponseV1','email': 'EmailConnectorResponseV1','employment_hero': 'EmploymentHeroConnectorResponseV1','es_self_hosted': 'EsSelfHostedConnectorResponseV1','eventbrite': 'EventbriteConnectorResponseV1','everhour': 'EverhourConnectorResponseV1','expensify': 'ExpensifyConnectorResponseV1','ezofficeinventory': 'EzofficeinventoryConnectorResponseV1','facebook_ads': 'FacebookAdsConnectorResponseV1','facebook_pages': 'FacebookPagesConnectorResponseV1','factorial': 'FactorialConnectorResponseV1','financial_force': 'FinancialForceConnectorResponseV1','firebase': 'FirebaseConnectorResponseV1','fivetran_log': 'FivetranLogConnectorResponseV1','flexport': 'FlexportConnectorResponseV1','float': 'FloatConnectorResponseV1','fone_dynamics': 'FoneDynamicsConnectorResponseV1','forj_community': 'ForjCommunityConnectorResponseV1','fountain': 'FountainConnectorResponseV1','freightview': 'FreightviewConnectorResponseV1','freshbooks': 'FreshbooksConnectorResponseV1','freshchat': 'FreshchatConnectorResponseV1','freshdesk': 'FreshdeskConnectorResponseV1','freshservice': 'FreshserviceConnectorResponseV1','freshteam': 'FreshteamConnectorResponseV1','friendbuy': 'FriendbuyConnectorResponseV1','front': 'FrontConnectorResponseV1','ftp': 'FtpConnectorResponseV1','fullstory': 'FullstoryConnectorResponseV1','gainsight_customer_success': 'GainsightCustomerSuccessConnectorResponseV1','gcs': 'GcsConnectorResponseV1','gem': 'GemConnectorResponseV1','getfeedback': 'GetfeedbackConnectorResponseV1','github': 'GithubConnectorResponseV1','gitlab': 'GitlabConnectorResponseV1','gladly': 'GladlyConnectorResponseV1','globalmeet': 'GlobalmeetConnectorResponseV1','gocardless': 'GocardlessConnectorResponseV1','gongio': 'GongioConnectorResponseV1','google_ads': 'GoogleAdsConnectorResponseV1','google_analytics': 'GoogleAnalyticsConnectorResponseV1','google_analytics_360': 'GoogleAnalytics360ConnectorResponseV1','google_analytics_4': 'GoogleAnalytics4ConnectorResponseV1','google_analytics_4_export': 'GoogleAnalytics4ExportConnectorResponseV1','google_analytics_mcf': 'GoogleAnalyticsMcfConnectorResponseV1','google_business_profile': 'GoogleBusinessProfileConnectorResponseV1','google_calendar': 'GoogleCalendarConnectorResponseV1','google_cloud_function': 'GoogleCloudFunctionConnectorResponseV1','google_cloud_mysql': 'GoogleCloudMysqlConnectorResponseV1','google_cloud_postgresql': 'GoogleCloudPostgresqlConnectorResponseV1','google_cloud_sqlserver': 'GoogleCloudSqlserverConnectorResponseV1','google_display_and_video_360': 'GoogleDisplayAndVideo360ConnectorResponseV1','google_drive': 'GoogleDriveConnectorResponseV1','google_play': 'GooglePlayConnectorResponseV1','google_search_ads_360': 'GoogleSearchAds360ConnectorResponseV1','google_search_console': 'GoogleSearchConsoleConnectorResponseV1','google_sheets': 'GoogleSheetsConnectorResponseV1','gorgias': 'GorgiasConnectorResponseV1','green_power_monitor': 'GreenPowerMonitorConnectorResponseV1','greenhouse': 'GreenhouseConnectorResponseV1','grepsr': 'GrepsrConnectorResponseV1','grin': 'GrinConnectorResponseV1','guru': 'GuruConnectorResponseV1','hana_sap_hva_b1': 'HanaSapHvaB1ConnectorResponseV1','hana_sap_hva_ecc': 'HanaSapHvaEccConnectorResponseV1','hana_sap_hva_ecc_netweaver': 'HanaSapHvaEccNetweaverConnectorResponseV1','hana_sap_hva_s4': 'HanaSapHvaS4ConnectorResponseV1','hana_sap_hva_s4_netweaver': 'HanaSapHvaS4NetweaverConnectorResponseV1','happyfox': 'HappyfoxConnectorResponseV1','harvest': 'HarvestConnectorResponseV1','heap': 'HeapConnectorResponseV1','height': 'HeightConnectorResponseV1','helpscout': 'HelpscoutConnectorResponseV1','helpshift': 'HelpshiftConnectorResponseV1','heroku_kafka': 'HerokuKafkaConnectorResponseV1','heroku_postgres': 'HerokuPostgresConnectorResponseV1','hibob': 'HibobConnectorResponseV1','hopin': 'HopinConnectorResponseV1','hubspot': 'HubspotConnectorResponseV1','ilevel': 'IlevelConnectorResponseV1','impact': 'ImpactConnectorResponseV1','incidentio': 'IncidentioConnectorResponseV1','infobip': 'InfobipConnectorResponseV1','insightly': 'InsightlyConnectorResponseV1','instagram_business': 'InstagramBusinessConnectorResponseV1','integral_ad_science': 'IntegralAdScienceConnectorResponseV1','integrate': 'IntegrateConnectorResponseV1','intercom': 'IntercomConnectorResponseV1','ironclad': 'IroncladConnectorResponseV1','ironsource': 'IronsourceConnectorResponseV1','iterable': 'IterableConnectorResponseV1','itunes_connect': 'ItunesConnectConnectorResponseV1','ivanti': 'IvantiConnectorResponseV1','jira': 'JiraConnectorResponseV1','jotform': 'JotformConnectorResponseV1','justcall': 'JustcallConnectorResponseV1','kandji': 'KandjiConnectorResponseV1','katana': 'KatanaConnectorResponseV1','keypay': 'KeypayConnectorResponseV1','khoros_care': 'KhorosCareConnectorResponseV1','kinesis': 'KinesisConnectorResponseV1','kissmetrics': 'KissmetricsConnectorResponseV1','klarna': 'KlarnaConnectorResponseV1','klaviyo': 'KlaviyoConnectorResponseV1','konnect_insights': 'KonnectInsightsConnectorResponseV1','kustomer': 'KustomerConnectorResponseV1','lattice': 'LatticeConnectorResponseV1','launchdarkly': 'LaunchdarklyConnectorResponseV1','learnupon': 'LearnuponConnectorResponseV1','lessonly': 'LessonlyConnectorResponseV1','lever': 'LeverConnectorResponseV1','liftoff': 'LiftoffConnectorResponseV1','light_speed_retail': 'LightSpeedRetailConnectorResponseV1','linear': 'LinearConnectorResponseV1','linkedin_ads': 'LinkedinAdsConnectorResponseV1','linkedin_company_pages': 'LinkedinCompanyPagesConnectorResponseV1','linksquares': 'LinksquaresConnectorResponseV1','livechat': 'LivechatConnectorResponseV1','lob': 'LobConnectorResponseV1','looker_source': 'LookerSourceConnectorResponseV1','loop': 'LoopConnectorResponseV1','loopio': 'LoopioConnectorResponseV1','luma': 'LumaConnectorResponseV1','magento_mysql': 'MagentoMysqlConnectorResponseV1','magento_mysql_rds': 'MagentoMysqlRdsConnectorResponseV1','mailchimp': 'MailchimpConnectorResponseV1','mailgun': 'MailgunConnectorResponseV1','mandrill': 'MandrillConnectorResponseV1','maria': 'MariaConnectorResponseV1','maria_azure': 'MariaAzureConnectorResponseV1','maria_rds': 'MariaRdsConnectorResponseV1','marin': 'MarinConnectorResponseV1','marketo': 'MarketoConnectorResponseV1','mavenlink': 'MavenlinkConnectorResponseV1','maxio_chargify': 'MaxioChargifyConnectorResponseV1','maxio_saasoptics': 'MaxioSaasopticsConnectorResponseV1','medallia': 'MedalliaConnectorResponseV1','megaphone': 'MegaphoneConnectorResponseV1','meltwater': 'MeltwaterConnectorResponseV1','mention': 'MentionConnectorResponseV1','microsoft_dynamics_365_fo': 'MicrosoftDynamics365FoConnectorResponseV1','microsoft_lists': 'MicrosoftListsConnectorResponseV1','microsoft_teams': 'MicrosoftTeamsConnectorResponseV1','mixmax': 'MixmaxConnectorResponseV1','mixpanel': 'MixpanelConnectorResponseV1','mode': 'ModeConnectorResponseV1','moloco': 'MolocoConnectorResponseV1','monday': 'MondayConnectorResponseV1','mongo': 'MongoConnectorResponseV1','mongo_sharded': 'MongoShardedConnectorResponseV1','mountain': 'MountainConnectorResponseV1','mux': 'MuxConnectorResponseV1','mysql': 'MysqlConnectorResponseV1','mysql_azure': 'MysqlAzureConnectorResponseV1','mysql_rds': 'MysqlRdsConnectorResponseV1','namely': 'NamelyConnectorResponseV1','navan': 'NavanConnectorResponseV1','netsuite_suiteanalytics': 'NetsuiteSuiteanalyticsConnectorResponseV1','notion': 'NotionConnectorResponseV1','nylas': 'NylasConnectorResponseV1','okta': 'OktaConnectorResponseV1','ometria': 'OmetriaConnectorResponseV1','one_drive': 'OneDriveConnectorResponseV1','open_exchange_rates': 'OpenExchangeRatesConnectorResponseV1','opendistro': 'OpendistroConnectorResponseV1','opensearch': 'OpensearchConnectorResponseV1','optimizely': 'OptimizelyConnectorResponseV1','oracle': 'OracleConnectorResponseV1','oracle_business_intelligence_publisher': 'OracleBusinessIntelligencePublisherConnectorResponseV1','oracle_ebs': 'OracleEbsConnectorResponseV1','oracle_fusion_cloud_apps_crm': 'OracleFusionCloudAppsCrmConnectorResponseV1','oracle_fusion_cloud_apps_fscm': 'OracleFusionCloudAppsFscmConnectorResponseV1','oracle_fusion_cloud_apps_hcm': 'OracleFusionCloudAppsHcmConnectorResponseV1','oracle_hva': 'OracleHvaConnectorResponseV1','oracle_moat_analytics': 'OracleMoatAnalyticsConnectorResponseV1','oracle_rac': 'OracleRacConnectorResponseV1','oracle_rds': 'OracleRdsConnectorResponseV1','oracle_sap_hva': 'OracleSapHvaConnectorResponseV1','oracle_sap_hva_netweaver': 'OracleSapHvaNetweaverConnectorResponseV1','orbit': 'OrbitConnectorResponseV1','ordway': 'OrdwayConnectorResponseV1','ortto': 'OrttoConnectorResponseV1','outbrain': 'OutbrainConnectorResponseV1','outreach': 'OutreachConnectorResponseV1','pagerduty': 'PagerdutyConnectorResponseV1','papershift': 'PapershiftConnectorResponseV1','pardot': 'PardotConnectorResponseV1','partnerstack_vendor': 'PartnerstackVendorConnectorResponseV1','paychex': 'PaychexConnectorResponseV1','paypal': 'PaypalConnectorResponseV1','paypal_sandbox': 'PaypalSandboxConnectorResponseV1','pendo': 'PendoConnectorResponseV1','persona': 'PersonaConnectorResponseV1','personio': 'PersonioConnectorResponseV1','pingdom': 'PingdomConnectorResponseV1','pinpoint': 'PinpointConnectorResponseV1','pinterest_ads': 'PinterestAdsConnectorResponseV1','pinterest_organic': 'PinterestOrganicConnectorResponseV1','pipe17': 'Pipe17ConnectorResponseV1','pipedrive': 'PipedriveConnectorResponseV1','pivotal_tracker': 'PivotalTrackerConnectorResponseV1','piwik_pro': 'PiwikProConnectorResponseV1','planetscale': 'PlanetscaleConnectorResponseV1','playvox': 'PlayvoxConnectorResponseV1','postgres': 'PostgresConnectorResponseV1','postgres_rds': 'PostgresRdsConnectorResponseV1','posthog': 'PosthogConnectorResponseV1','postmark': 'PostmarkConnectorResponseV1','power_reviews_enterprise': 'PowerReviewsEnterpriseConnectorResponseV1','prive': 'PriveConnectorResponseV1','productboard': 'ProductboardConnectorResponseV1','qualaroo': 'QualarooConnectorResponseV1','qualtrics': 'QualtricsConnectorResponseV1','quickbooks': 'QuickbooksConnectorResponseV1','rakutenadvertising': 'RakutenadvertisingConnectorResponseV1','ramp': 'RampConnectorResponseV1','rarible': 'RaribleConnectorResponseV1','recharge': 'RechargeConnectorResponseV1','recurly': 'RecurlyConnectorResponseV1','reddit_ads': 'RedditAdsConnectorResponseV1','redshift_db': 'RedshiftDbConnectorResponseV1','reltio': 'ReltioConnectorResponseV1','replyio': 'ReplyioConnectorResponseV1','resource_management_by_smartsheet': 'ResourceManagementBySmartsheetConnectorResponseV1','retailnext': 'RetailnextConnectorResponseV1','retently': 'RetentlyConnectorResponseV1','revel': 'RevelConnectorResponseV1','revops': 'RevopsConnectorResponseV1','revx': 'RevxConnectorResponseV1','ringcentral': 'RingcentralConnectorResponseV1','ringover': 'RingoverConnectorResponseV1','rippling': 'RipplingConnectorResponseV1','rocketlane': 'RocketlaneConnectorResponseV1','rollbar': 'RollbarConnectorResponseV1','rootly': 'RootlyConnectorResponseV1','rtb_house': 'RtbHouseConnectorResponseV1','s3': 'S3ConnectorResponseV1','safetyculture': 'SafetycultureConnectorResponseV1','sage_hr': 'SageHrConnectorResponseV1','sage_intacct': 'SageIntacctConnectorResponseV1','sailthru': 'SailthruConnectorResponseV1','salesforce': 'SalesforceConnectorResponseV1','salesforce_commerce_cloud': 'SalesforceCommerceCloudConnectorResponseV1','salesforce_marketing_cloud': 'SalesforceMarketingCloudConnectorResponseV1','salesforce_sandbox': 'SalesforceSandboxConnectorResponseV1','salesloft': 'SalesloftConnectorResponseV1','salsify': 'SalsifyConnectorResponseV1','samsara': 'SamsaraConnectorResponseV1','sap_business_by_design': 'SapBusinessByDesignConnectorResponseV1','sap_hana': 'SapHanaConnectorResponseV1','sap_hana_db': 'SapHanaDbConnectorResponseV1','sap_s4hana': 'SapS4hanaConnectorResponseV1','scorm': 'ScormConnectorResponseV1','security_journey': 'SecurityJourneyConnectorResponseV1','segment': 'SegmentConnectorResponseV1','sendgrid': 'SendgridConnectorResponseV1','sensor_tower': 'SensorTowerConnectorResponseV1','servicenow': 'ServicenowConnectorResponseV1','servicetitan': 'ServicetitanConnectorResponseV1','sftp': 'SftpConnectorResponseV1','share_point': 'SharePointConnectorResponseV1','shiphero': 'ShipheroConnectorResponseV1','shipstation': 'ShipstationConnectorResponseV1','shopify': 'ShopifyConnectorResponseV1','shopware': 'ShopwareConnectorResponseV1','shortcut': 'ShortcutConnectorResponseV1','shortio': 'ShortioConnectorResponseV1','simplecast': 'SimplecastConnectorResponseV1','simplesat': 'SimplesatConnectorResponseV1','skilljar': 'SkilljarConnectorResponseV1','skuvault': 'SkuvaultConnectorResponseV1','slab': 'SlabConnectorResponseV1','slack': 'SlackConnectorResponseV1','smadex': 'SmadexConnectorResponseV1','smartwaiver': 'SmartwaiverConnectorResponseV1','snapchat_ads': 'SnapchatAdsConnectorResponseV1','snowflake_db': 'SnowflakeDbConnectorResponseV1','snowplow': 'SnowplowConnectorResponseV1','sonarqube': 'SonarqubeConnectorResponseV1','splitio': 'SplitioConnectorResponseV1','splunk': 'SplunkConnectorResponseV1','spotify_ads': 'SpotifyAdsConnectorResponseV1','sprout': 'SproutConnectorResponseV1','sql_server': 'SqlServerConnectorResponseV1','sql_server_hva': 'SqlServerHvaConnectorResponseV1','sql_server_rds': 'SqlServerRdsConnectorResponseV1','sql_server_sap_ecc_hva': 'SqlServerSapEccHvaConnectorResponseV1','square': 'SquareConnectorResponseV1','squarespace': 'SquarespaceConnectorResponseV1','stackadapt': 'StackadaptConnectorResponseV1','standard_metrics': 'StandardMetricsConnectorResponseV1','statsig': 'StatsigConnectorResponseV1','statuspage': 'StatuspageConnectorResponseV1','stripe': 'StripeConnectorResponseV1','stripe_test': 'StripeTestConnectorResponseV1','stylight': 'StylightConnectorResponseV1','subscript': 'SubscriptConnectorResponseV1','survey_monkey': 'SurveyMonkeyConnectorResponseV1','survicate': 'SurvicateConnectorResponseV1','swoogo': 'SwoogoConnectorResponseV1','tableau_source': 'TableauSourceConnectorResponseV1','taboola': 'TaboolaConnectorResponseV1','talkdesk': 'TalkdeskConnectorResponseV1','talkwalker': 'TalkwalkerConnectorResponseV1','teamwork': 'TeamworkConnectorResponseV1','tempo': 'TempoConnectorResponseV1','the_trade_desk': 'TheTradeDeskConnectorResponseV1','thinkific': 'ThinkificConnectorResponseV1','tiktok_ads': 'TiktokAdsConnectorResponseV1','toggl_track': 'TogglTrackConnectorResponseV1','transcend': 'TranscendConnectorResponseV1','trello': 'TrelloConnectorResponseV1','trisolute': 'TrisoluteConnectorResponseV1','twilio': 'TwilioConnectorResponseV1','twitter': 'TwitterConnectorResponseV1','twitter_ads': 'TwitterAdsConnectorResponseV1','typeform': 'TypeformConnectorResponseV1','ukg_pro': 'UkgProConnectorResponseV1','unicommerce': 'UnicommerceConnectorResponseV1','upland': 'UplandConnectorResponseV1','uppromote': 'UppromoteConnectorResponseV1','uservoice': 'UservoiceConnectorResponseV1','vitally': 'VitallyConnectorResponseV1','vonage': 'VonageConnectorResponseV1','vts': 'VtsConnectorResponseV1','vwo': 'VwoConnectorResponseV1','wasabi_cloud_storage': 'WasabiCloudStorageConnectorResponseV1','webhooks': 'WebhooksConnectorResponseV1','when_i_work': 'WhenIWorkConnectorResponseV1','wherefour': 'WherefourConnectorResponseV1','woocommerce': 'WoocommerceConnectorResponseV1','wordpress': 'WordpressConnectorResponseV1','workable': 'WorkableConnectorResponseV1','workday': 'WorkdayConnectorResponseV1','workday_financial_management': 'WorkdayFinancialManagementConnectorResponseV1','workday_hcm': 'WorkdayHcmConnectorResponseV1','workday_strategic_sourcing': 'WorkdayStrategicSourcingConnectorResponseV1','workflowmax': 'WorkflowmaxConnectorResponseV1','workramp': 'WorkrampConnectorResponseV1','wrike': 'WrikeConnectorResponseV1','xero': 'XeroConnectorResponseV1','xray': 'XrayConnectorResponseV1','xsolla': 'XsollaConnectorResponseV1','yahoo_dsp': 'YahooDspConnectorResponseV1','yahoo_gemini': 'YahooGeminiConnectorResponseV1','yahoo_search_ads_yahoo_japan': 'YahooSearchAdsYahooJapanConnectorResponseV1','yotpo': 'YotpoConnectorResponseV1','youtube_analytics': 'YoutubeAnalyticsConnectorResponseV1','zendesk': 'ZendeskConnectorResponseV1','zendesk_chat': 'ZendeskChatConnectorResponseV1','zendesk_sell': 'ZendeskSellConnectorResponseV1','zendesk_sunshine': 'ZendeskSunshineConnectorResponseV1','zenefits': 'ZenefitsConnectorResponseV1','zoho_books': 'ZohoBooksConnectorResponseV1','zoho_campaigns': 'ZohoCampaignsConnectorResponseV1','zoho_crm': 'ZohoCrmConnectorResponseV1','zoho_desk': 'ZohoDeskConnectorResponseV1','zoom': 'ZoomConnectorResponseV1','zuora': 'ZuoraConnectorResponseV1','zuora_sandbox': 'ZuoraSandboxConnectorResponseV1'
    }

    @classmethod
    def get_discriminator_value(cls, obj: Dict[str, Any]) -> Optional[str]:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Union[Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self]]:
        """Create an instance of ConnectorResponseV1 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        # override the default output from pydantic by calling `to_dict()` of connect_card
        if self.connect_card:
            _dict['connect_card'] = self.connect_card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in setup_tests (list)
        _items = []
        if self.setup_tests:
            for _item in self.setup_tests:
                if _item:
                    _items.append(_item.to_dict())
            _dict['setup_tests'] = _items
        # override the default output from pydantic by calling `to_dict()` of connect_card_config
        if self.connect_card_config:
            _dict['connect_card_config'] = self.connect_card_config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Optional[Union[Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self]]:
        """Create an instance of ConnectorResponseV1 from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type:
            klass = globals()[object_type]
            return klass.from_dict(obj)
        else:
            raise ValueError("ConnectorResponseV1 failed to lookup discriminator value from " +
                             json.dumps(obj) + ". Discriminator property name: " + cls.__discriminator_property_name +
                             ", mapping: " + json.dumps(cls.__discriminator_value_class_map))

from openapi_client.models.activecampaign_connector_response_v1 import ActivecampaignConnectorResponseV1
from openapi_client.models.acumatica_connector_response_v1 import AcumaticaConnectorResponseV1
from openapi_client.models.ada_connector_response_v1 import AdaConnectorResponseV1
from openapi_client.models.adjust_connector_response_v1 import AdjustConnectorResponseV1
from openapi_client.models.adobe_analytics_connector_response_v1 import AdobeAnalyticsConnectorResponseV1
from openapi_client.models.adobe_analytics_data_feed_connector_response_v1 import AdobeAnalyticsDataFeedConnectorResponseV1
from openapi_client.models.adobe_commerce_connector_response_v1 import AdobeCommerceConnectorResponseV1
from openapi_client.models.adp_workforce_now_connector_response_v1 import AdpWorkforceNowConnectorResponseV1
from openapi_client.models.adroll_connector_response_v1 import AdrollConnectorResponseV1
from openapi_client.models.affinity_connector_response_v1 import AffinityConnectorResponseV1
from openapi_client.models.afterpay_connector_response_v1 import AfterpayConnectorResponseV1
from openapi_client.models.aha_connector_response_v1 import AhaConnectorResponseV1
from openapi_client.models.aircall_connector_response_v1 import AircallConnectorResponseV1
from openapi_client.models.airtable_connector_response_v1 import AirtableConnectorResponseV1
from openapi_client.models.alchemer_connector_response_v1 import AlchemerConnectorResponseV1
from openapi_client.models.algolia_connector_response_v1 import AlgoliaConnectorResponseV1
from openapi_client.models.amazon_ads_connector_response_v1 import AmazonAdsConnectorResponseV1
from openapi_client.models.amazon_attribution_connector_response_v1 import AmazonAttributionConnectorResponseV1
from openapi_client.models.amazon_selling_partner_connector_response_v1 import AmazonSellingPartnerConnectorResponseV1
from openapi_client.models.amplitude_connector_response_v1 import AmplitudeConnectorResponseV1
from openapi_client.models.anaplan_connector_response_v1 import AnaplanConnectorResponseV1
from openapi_client.models.apache_kafka_connector_response_v1 import ApacheKafkaConnectorResponseV1
from openapi_client.models.appcues_connector_response_v1 import AppcuesConnectorResponseV1
from openapi_client.models.appfigures_connector_response_v1 import AppfiguresConnectorResponseV1
from openapi_client.models.apple_search_ads_connector_response_v1 import AppleSearchAdsConnectorResponseV1
from openapi_client.models.appsflyer_connector_response_v1 import AppsflyerConnectorResponseV1
from openapi_client.models.asana_connector_response_v1 import AsanaConnectorResponseV1
from openapi_client.models.assembled_connector_response_v1 import AssembledConnectorResponseV1
from openapi_client.models.atlassian_jira_align_connector_response_v1 import AtlassianJiraAlignConnectorResponseV1
from openapi_client.models.atlassian_ops_genie_connector_response_v1 import AtlassianOpsGenieConnectorResponseV1
from openapi_client.models.attentive_connector_response_v1 import AttentiveConnectorResponseV1
from openapi_client.models.attio_connector_response_v1 import AttioConnectorResponseV1
from openapi_client.models.aumni_connector_response_v1 import AumniConnectorResponseV1
from openapi_client.models.aurora_connector_response_v1 import AuroraConnectorResponseV1
from openapi_client.models.aurora_postgres_connector_response_v1 import AuroraPostgresConnectorResponseV1
from openapi_client.models.auth0_connector_response_v1 import Auth0ConnectorResponseV1
from openapi_client.models.autodesk_bim360_connector_response_v1 import AutodeskBim360ConnectorResponseV1
from openapi_client.models.avantlink_connector_response_v1 import AvantlinkConnectorResponseV1
from openapi_client.models.awin_connector_response_v1 import AwinConnectorResponseV1
from openapi_client.models.aws_cloudtrail_connector_response_v1 import AwsCloudtrailConnectorResponseV1
from openapi_client.models.aws_cost_connector_response_v1 import AwsCostConnectorResponseV1
from openapi_client.models.aws_inventory_connector_response_v1 import AwsInventoryConnectorResponseV1
from openapi_client.models.aws_lambda_connector_response_v1 import AwsLambdaConnectorResponseV1
from openapi_client.models.aws_msk_connector_response_v1 import AwsMskConnectorResponseV1
from openapi_client.models.azure_blob_storage_connector_response_v1 import AzureBlobStorageConnectorResponseV1
from openapi_client.models.azure_boards_connector_response_v1 import AzureBoardsConnectorResponseV1
from openapi_client.models.azure_devops_connector_response_v1 import AzureDevopsConnectorResponseV1
from openapi_client.models.azure_event_hub_connector_response_v1 import AzureEventHubConnectorResponseV1
from openapi_client.models.azure_function_connector_response_v1 import AzureFunctionConnectorResponseV1
from openapi_client.models.azure_postgres_connector_response_v1 import AzurePostgresConnectorResponseV1
from openapi_client.models.azure_service_bus_connector_response_v1 import AzureServiceBusConnectorResponseV1
from openapi_client.models.azure_sql_db_connector_response_v1 import AzureSqlDbConnectorResponseV1
from openapi_client.models.azure_sql_managed_db_connector_response_v1 import AzureSqlManagedDbConnectorResponseV1
from openapi_client.models.ballotready_connector_response_v1 import BallotreadyConnectorResponseV1
from openapi_client.models.bamboohr_connector_response_v1 import BamboohrConnectorResponseV1
from openapi_client.models.big_commerce_connector_response_v1 import BigCommerceConnectorResponseV1
from openapi_client.models.bigquery_db_connector_response_v1 import BigqueryDbConnectorResponseV1
from openapi_client.models.billing_platform_connector_response_v1 import BillingPlatformConnectorResponseV1
from openapi_client.models.bingads_connector_response_v1 import BingadsConnectorResponseV1
from openapi_client.models.birdeye_connector_response_v1 import BirdeyeConnectorResponseV1
from openapi_client.models.bitly_connector_response_v1 import BitlyConnectorResponseV1
from openapi_client.models.box_connector_response_v1 import BoxConnectorResponseV1
from openapi_client.models.braintree_connector_response_v1 import BraintreeConnectorResponseV1
from openapi_client.models.braintree_sandbox_connector_response_v1 import BraintreeSandboxConnectorResponseV1
from openapi_client.models.branch_connector_response_v1 import BranchConnectorResponseV1
from openapi_client.models.braze_connector_response_v1 import BrazeConnectorResponseV1
from openapi_client.models.brevo_connector_response_v1 import BrevoConnectorResponseV1
from openapi_client.models.brex_connector_response_v1 import BrexConnectorResponseV1
from openapi_client.models.buildkite_connector_response_v1 import BuildkiteConnectorResponseV1
from openapi_client.models.business_central_connector_response_v1 import BusinessCentralConnectorResponseV1
from openapi_client.models.buzzsprout_connector_response_v1 import BuzzsproutConnectorResponseV1
from openapi_client.models.calabrio_connector_response_v1 import CalabrioConnectorResponseV1
from openapi_client.models.calendly_connector_response_v1 import CalendlyConnectorResponseV1
from openapi_client.models.campaignmonitor_connector_response_v1 import CampaignmonitorConnectorResponseV1
from openapi_client.models.canny_connector_response_v1 import CannyConnectorResponseV1
from openapi_client.models.care_quality_commission_connector_response_v1 import CareQualityCommissionConnectorResponseV1
from openapi_client.models.castor_edc_connector_response_v1 import CastorEdcConnectorResponseV1
from openapi_client.models.ceridian_dayforce_connector_response_v1 import CeridianDayforceConnectorResponseV1
from openapi_client.models.channel_advisor_connector_response_v1 import ChannelAdvisorConnectorResponseV1
from openapi_client.models.chargebee_product_catalog1_connector_response_v1 import ChargebeeProductCatalog1ConnectorResponseV1
from openapi_client.models.chargebee_product_catalog2_connector_response_v1 import ChargebeeProductCatalog2ConnectorResponseV1
from openapi_client.models.chargedesk_connector_response_v1 import ChargedeskConnectorResponseV1
from openapi_client.models.chartmogul_connector_response_v1 import ChartmogulConnectorResponseV1
from openapi_client.models.checkout_connector_response_v1 import CheckoutConnectorResponseV1
from openapi_client.models.checkr_connector_response_v1 import CheckrConnectorResponseV1
from openapi_client.models.chorusai_connector_response_v1 import ChorusaiConnectorResponseV1
from openapi_client.models.churnkey_connector_response_v1 import ChurnkeyConnectorResponseV1
from openapi_client.models.churnzero_connector_response_v1 import ChurnzeroConnectorResponseV1
from openapi_client.models.cimis_connector_response_v1 import CimisConnectorResponseV1
from openapi_client.models.cin7_connector_response_v1 import Cin7ConnectorResponseV1
from openapi_client.models.circleci_connector_response_v1 import CircleciConnectorResponseV1
from openapi_client.models.cj_commission_detail_connector_response_v1 import CjCommissionDetailConnectorResponseV1
from openapi_client.models.clari_connector_response_v1 import ClariConnectorResponseV1
from openapi_client.models.clickup_connector_response_v1 import ClickupConnectorResponseV1
from openapi_client.models.close_connector_response_v1 import CloseConnectorResponseV1
from openapi_client.models.cloudfront_connector_response_v1 import CloudfrontConnectorResponseV1
from openapi_client.models.coassemble_connector_response_v1 import CoassembleConnectorResponseV1
from openapi_client.models.codefresh_connector_response_v1 import CodefreshConnectorResponseV1
from openapi_client.models.collibra_connector_response_v1 import CollibraConnectorResponseV1
from openapi_client.models.column_connector_response_v1 import ColumnConnectorResponseV1
from openapi_client.models.concord_connector_response_v1 import ConcordConnectorResponseV1
from openapi_client.models.concur_connector_response_v1 import ConcurConnectorResponseV1
from openapi_client.models.confluence_connector_response_v1 import ConfluenceConnectorResponseV1
from openapi_client.models.confluent_cloud_connector_response_v1 import ConfluentCloudConnectorResponseV1
from openapi_client.models.contrast_security_connector_response_v1 import ContrastSecurityConnectorResponseV1
from openapi_client.models.convex_connector_response_v1 import ConvexConnectorResponseV1
from openapi_client.models.copper_connector_response_v1 import CopperConnectorResponseV1
from openapi_client.models.cosmos_connector_response_v1 import CosmosConnectorResponseV1
from openapi_client.models.coupa_connector_response_v1 import CoupaConnectorResponseV1
from openapi_client.models.criteo_connector_response_v1 import CriteoConnectorResponseV1
from openapi_client.models.crossbeam_connector_response_v1 import CrossbeamConnectorResponseV1
from openapi_client.models.crowddev_connector_response_v1 import CrowddevConnectorResponseV1
from openapi_client.models.customerio_connector_response_v1 import CustomerioConnectorResponseV1
from openapi_client.models.cvent_connector_response_v1 import CventConnectorResponseV1
from openapi_client.models.d2l_brightspace_connector_response_v1 import D2lBrightspaceConnectorResponseV1
from openapi_client.models.db2_connector_response_v1 import Db2ConnectorResponseV1
from openapi_client.models.db2i_hva_connector_response_v1 import Db2iHvaConnectorResponseV1
from openapi_client.models.db2i_sap_hva_connector_response_v1 import Db2iSapHvaConnectorResponseV1
from openapi_client.models.dbt_cloud_connector_response_v1 import DbtCloudConnectorResponseV1
from openapi_client.models.dcl_logistics_connector_response_v1 import DclLogisticsConnectorResponseV1
from openapi_client.models.dear_connector_response_v1 import DearConnectorResponseV1
from openapi_client.models.delighted_connector_response_v1 import DelightedConnectorResponseV1
from openapi_client.models.deputy_connector_response_v1 import DeputyConnectorResponseV1
from openapi_client.models.destini_connector_response_v1 import DestiniConnectorResponseV1
from openapi_client.models.dixa_connector_response_v1 import DixaConnectorResponseV1
from openapi_client.models.docebo_connector_response_v1 import DoceboConnectorResponseV1
from openapi_client.models.documentdb_connector_response_v1 import DocumentdbConnectorResponseV1
from openapi_client.models.double_click_campaign_manager_connector_response_v1 import DoubleClickCampaignManagerConnectorResponseV1
from openapi_client.models.double_click_publishers_connector_response_v1 import DoubleClickPublishersConnectorResponseV1
from openapi_client.models.drata_connector_response_v1 import DrataConnectorResponseV1
from openapi_client.models.drift_connector_response_v1 import DriftConnectorResponseV1
from openapi_client.models.drip_connector_response_v1 import DripConnectorResponseV1
from openapi_client.models.dropbox_connector_response_v1 import DropboxConnectorResponseV1
from openapi_client.models.dropbox_sign_connector_response_v1 import DropboxSignConnectorResponseV1
from openapi_client.models.dsv_connector_response_v1 import DsvConnectorResponseV1
from openapi_client.models.dynamics365_connector_response_v1 import Dynamics365ConnectorResponseV1
from openapi_client.models.dynamics365_fo_connector_response_v1 import Dynamics365FoConnectorResponseV1
from openapi_client.models.dynamodb_connector_response_v1 import DynamodbConnectorResponseV1
from openapi_client.models.easypost_connector_response_v1 import EasypostConnectorResponseV1
from openapi_client.models.economic_connector_response_v1 import EconomicConnectorResponseV1
from openapi_client.models.elastic_cloud_connector_response_v1 import ElasticCloudConnectorResponseV1
from openapi_client.models.eloqua_connector_response_v1 import EloquaConnectorResponseV1
from openapi_client.models.email_connector_response_v1 import EmailConnectorResponseV1
from openapi_client.models.employment_hero_connector_response_v1 import EmploymentHeroConnectorResponseV1
from openapi_client.models.es_self_hosted_connector_response_v1 import EsSelfHostedConnectorResponseV1
from openapi_client.models.eventbrite_connector_response_v1 import EventbriteConnectorResponseV1
from openapi_client.models.everhour_connector_response_v1 import EverhourConnectorResponseV1
from openapi_client.models.expensify_connector_response_v1 import ExpensifyConnectorResponseV1
from openapi_client.models.ezofficeinventory_connector_response_v1 import EzofficeinventoryConnectorResponseV1
from openapi_client.models.facebook_ads_connector_response_v1 import FacebookAdsConnectorResponseV1
from openapi_client.models.facebook_pages_connector_response_v1 import FacebookPagesConnectorResponseV1
from openapi_client.models.factorial_connector_response_v1 import FactorialConnectorResponseV1
from openapi_client.models.financial_force_connector_response_v1 import FinancialForceConnectorResponseV1
from openapi_client.models.firebase_connector_response_v1 import FirebaseConnectorResponseV1
from openapi_client.models.fivetran_log_connector_response_v1 import FivetranLogConnectorResponseV1
from openapi_client.models.flexport_connector_response_v1 import FlexportConnectorResponseV1
from openapi_client.models.float_connector_response_v1 import FloatConnectorResponseV1
from openapi_client.models.fone_dynamics_connector_response_v1 import FoneDynamicsConnectorResponseV1
from openapi_client.models.forj_community_connector_response_v1 import ForjCommunityConnectorResponseV1
from openapi_client.models.fountain_connector_response_v1 import FountainConnectorResponseV1
from openapi_client.models.freightview_connector_response_v1 import FreightviewConnectorResponseV1
from openapi_client.models.freshbooks_connector_response_v1 import FreshbooksConnectorResponseV1
from openapi_client.models.freshchat_connector_response_v1 import FreshchatConnectorResponseV1
from openapi_client.models.freshdesk_connector_response_v1 import FreshdeskConnectorResponseV1
from openapi_client.models.freshservice_connector_response_v1 import FreshserviceConnectorResponseV1
from openapi_client.models.freshteam_connector_response_v1 import FreshteamConnectorResponseV1
from openapi_client.models.friendbuy_connector_response_v1 import FriendbuyConnectorResponseV1
from openapi_client.models.front_connector_response_v1 import FrontConnectorResponseV1
from openapi_client.models.ftp_connector_response_v1 import FtpConnectorResponseV1
from openapi_client.models.fullstory_connector_response_v1 import FullstoryConnectorResponseV1
from openapi_client.models.gainsight_customer_success_connector_response_v1 import GainsightCustomerSuccessConnectorResponseV1
from openapi_client.models.gcs_connector_response_v1 import GcsConnectorResponseV1
from openapi_client.models.gem_connector_response_v1 import GemConnectorResponseV1
from openapi_client.models.getfeedback_connector_response_v1 import GetfeedbackConnectorResponseV1
from openapi_client.models.github_connector_response_v1 import GithubConnectorResponseV1
from openapi_client.models.gitlab_connector_response_v1 import GitlabConnectorResponseV1
from openapi_client.models.gladly_connector_response_v1 import GladlyConnectorResponseV1
from openapi_client.models.globalmeet_connector_response_v1 import GlobalmeetConnectorResponseV1
from openapi_client.models.gocardless_connector_response_v1 import GocardlessConnectorResponseV1
from openapi_client.models.gongio_connector_response_v1 import GongioConnectorResponseV1
from openapi_client.models.google_ads_connector_response_v1 import GoogleAdsConnectorResponseV1
from openapi_client.models.google_analytics360_connector_response_v1 import GoogleAnalytics360ConnectorResponseV1
from openapi_client.models.google_analytics4_connector_response_v1 import GoogleAnalytics4ConnectorResponseV1
from openapi_client.models.google_analytics4_export_connector_response_v1 import GoogleAnalytics4ExportConnectorResponseV1
from openapi_client.models.google_analytics_connector_response_v1 import GoogleAnalyticsConnectorResponseV1
from openapi_client.models.google_analytics_mcf_connector_response_v1 import GoogleAnalyticsMcfConnectorResponseV1
from openapi_client.models.google_business_profile_connector_response_v1 import GoogleBusinessProfileConnectorResponseV1
from openapi_client.models.google_calendar_connector_response_v1 import GoogleCalendarConnectorResponseV1
from openapi_client.models.google_cloud_function_connector_response_v1 import GoogleCloudFunctionConnectorResponseV1
from openapi_client.models.google_cloud_mysql_connector_response_v1 import GoogleCloudMysqlConnectorResponseV1
from openapi_client.models.google_cloud_postgresql_connector_response_v1 import GoogleCloudPostgresqlConnectorResponseV1
from openapi_client.models.google_cloud_sqlserver_connector_response_v1 import GoogleCloudSqlserverConnectorResponseV1
from openapi_client.models.google_display_and_video360_connector_response_v1 import GoogleDisplayAndVideo360ConnectorResponseV1
from openapi_client.models.google_drive_connector_response_v1 import GoogleDriveConnectorResponseV1
from openapi_client.models.google_play_connector_response_v1 import GooglePlayConnectorResponseV1
from openapi_client.models.google_search_ads360_connector_response_v1 import GoogleSearchAds360ConnectorResponseV1
from openapi_client.models.google_search_console_connector_response_v1 import GoogleSearchConsoleConnectorResponseV1
from openapi_client.models.google_sheets_connector_response_v1 import GoogleSheetsConnectorResponseV1
from openapi_client.models.gorgias_connector_response_v1 import GorgiasConnectorResponseV1
from openapi_client.models.green_power_monitor_connector_response_v1 import GreenPowerMonitorConnectorResponseV1
from openapi_client.models.greenhouse_connector_response_v1 import GreenhouseConnectorResponseV1
from openapi_client.models.grepsr_connector_response_v1 import GrepsrConnectorResponseV1
from openapi_client.models.grin_connector_response_v1 import GrinConnectorResponseV1
from openapi_client.models.guru_connector_response_v1 import GuruConnectorResponseV1
from openapi_client.models.hana_sap_hva_b1_connector_response_v1 import HanaSapHvaB1ConnectorResponseV1
from openapi_client.models.hana_sap_hva_ecc_connector_response_v1 import HanaSapHvaEccConnectorResponseV1
from openapi_client.models.hana_sap_hva_ecc_netweaver_connector_response_v1 import HanaSapHvaEccNetweaverConnectorResponseV1
from openapi_client.models.hana_sap_hva_s4_connector_response_v1 import HanaSapHvaS4ConnectorResponseV1
from openapi_client.models.hana_sap_hva_s4_netweaver_connector_response_v1 import HanaSapHvaS4NetweaverConnectorResponseV1
from openapi_client.models.happyfox_connector_response_v1 import HappyfoxConnectorResponseV1
from openapi_client.models.harvest_connector_response_v1 import HarvestConnectorResponseV1
from openapi_client.models.heap_connector_response_v1 import HeapConnectorResponseV1
from openapi_client.models.height_connector_response_v1 import HeightConnectorResponseV1
from openapi_client.models.helpscout_connector_response_v1 import HelpscoutConnectorResponseV1
from openapi_client.models.helpshift_connector_response_v1 import HelpshiftConnectorResponseV1
from openapi_client.models.heroku_kafka_connector_response_v1 import HerokuKafkaConnectorResponseV1
from openapi_client.models.heroku_postgres_connector_response_v1 import HerokuPostgresConnectorResponseV1
from openapi_client.models.hibob_connector_response_v1 import HibobConnectorResponseV1
from openapi_client.models.hopin_connector_response_v1 import HopinConnectorResponseV1
from openapi_client.models.hubspot_connector_response_v1 import HubspotConnectorResponseV1
from openapi_client.models.ilevel_connector_response_v1 import IlevelConnectorResponseV1
from openapi_client.models.impact_connector_response_v1 import ImpactConnectorResponseV1
from openapi_client.models.incidentio_connector_response_v1 import IncidentioConnectorResponseV1
from openapi_client.models.infobip_connector_response_v1 import InfobipConnectorResponseV1
from openapi_client.models.insightly_connector_response_v1 import InsightlyConnectorResponseV1
from openapi_client.models.instagram_business_connector_response_v1 import InstagramBusinessConnectorResponseV1
from openapi_client.models.integral_ad_science_connector_response_v1 import IntegralAdScienceConnectorResponseV1
from openapi_client.models.integrate_connector_response_v1 import IntegrateConnectorResponseV1
from openapi_client.models.intercom_connector_response_v1 import IntercomConnectorResponseV1
from openapi_client.models.ironclad_connector_response_v1 import IroncladConnectorResponseV1
from openapi_client.models.ironsource_connector_response_v1 import IronsourceConnectorResponseV1
from openapi_client.models.iterable_connector_response_v1 import IterableConnectorResponseV1
from openapi_client.models.itunes_connect_connector_response_v1 import ItunesConnectConnectorResponseV1
from openapi_client.models.ivanti_connector_response_v1 import IvantiConnectorResponseV1
from openapi_client.models.jira_connector_response_v1 import JiraConnectorResponseV1
from openapi_client.models.jotform_connector_response_v1 import JotformConnectorResponseV1
from openapi_client.models.justcall_connector_response_v1 import JustcallConnectorResponseV1
from openapi_client.models.kandji_connector_response_v1 import KandjiConnectorResponseV1
from openapi_client.models.katana_connector_response_v1 import KatanaConnectorResponseV1
from openapi_client.models.keypay_connector_response_v1 import KeypayConnectorResponseV1
from openapi_client.models.khoros_care_connector_response_v1 import KhorosCareConnectorResponseV1
from openapi_client.models.kinesis_connector_response_v1 import KinesisConnectorResponseV1
from openapi_client.models.kissmetrics_connector_response_v1 import KissmetricsConnectorResponseV1
from openapi_client.models.klarna_connector_response_v1 import KlarnaConnectorResponseV1
from openapi_client.models.klaviyo_connector_response_v1 import KlaviyoConnectorResponseV1
from openapi_client.models.konnect_insights_connector_response_v1 import KonnectInsightsConnectorResponseV1
from openapi_client.models.kustomer_connector_response_v1 import KustomerConnectorResponseV1
from openapi_client.models.lattice_connector_response_v1 import LatticeConnectorResponseV1
from openapi_client.models.launchdarkly_connector_response_v1 import LaunchdarklyConnectorResponseV1
from openapi_client.models.learnupon_connector_response_v1 import LearnuponConnectorResponseV1
from openapi_client.models.lessonly_connector_response_v1 import LessonlyConnectorResponseV1
from openapi_client.models.lever_connector_response_v1 import LeverConnectorResponseV1
from openapi_client.models.liftoff_connector_response_v1 import LiftoffConnectorResponseV1
from openapi_client.models.light_speed_retail_connector_response_v1 import LightSpeedRetailConnectorResponseV1
from openapi_client.models.linear_connector_response_v1 import LinearConnectorResponseV1
from openapi_client.models.linkedin_ads_connector_response_v1 import LinkedinAdsConnectorResponseV1
from openapi_client.models.linkedin_company_pages_connector_response_v1 import LinkedinCompanyPagesConnectorResponseV1
from openapi_client.models.linksquares_connector_response_v1 import LinksquaresConnectorResponseV1
from openapi_client.models.livechat_connector_response_v1 import LivechatConnectorResponseV1
from openapi_client.models.lob_connector_response_v1 import LobConnectorResponseV1
from openapi_client.models.looker_source_connector_response_v1 import LookerSourceConnectorResponseV1
from openapi_client.models.loop_connector_response_v1 import LoopConnectorResponseV1
from openapi_client.models.loopio_connector_response_v1 import LoopioConnectorResponseV1
from openapi_client.models.luma_connector_response_v1 import LumaConnectorResponseV1
from openapi_client.models.magento_mysql_connector_response_v1 import MagentoMysqlConnectorResponseV1
from openapi_client.models.magento_mysql_rds_connector_response_v1 import MagentoMysqlRdsConnectorResponseV1
from openapi_client.models.mailchimp_connector_response_v1 import MailchimpConnectorResponseV1
from openapi_client.models.mailgun_connector_response_v1 import MailgunConnectorResponseV1
from openapi_client.models.mandrill_connector_response_v1 import MandrillConnectorResponseV1
from openapi_client.models.maria_azure_connector_response_v1 import MariaAzureConnectorResponseV1
from openapi_client.models.maria_connector_response_v1 import MariaConnectorResponseV1
from openapi_client.models.maria_rds_connector_response_v1 import MariaRdsConnectorResponseV1
from openapi_client.models.marin_connector_response_v1 import MarinConnectorResponseV1
from openapi_client.models.marketo_connector_response_v1 import MarketoConnectorResponseV1
from openapi_client.models.mavenlink_connector_response_v1 import MavenlinkConnectorResponseV1
from openapi_client.models.maxio_chargify_connector_response_v1 import MaxioChargifyConnectorResponseV1
from openapi_client.models.maxio_saasoptics_connector_response_v1 import MaxioSaasopticsConnectorResponseV1
from openapi_client.models.medallia_connector_response_v1 import MedalliaConnectorResponseV1
from openapi_client.models.megaphone_connector_response_v1 import MegaphoneConnectorResponseV1
from openapi_client.models.meltwater_connector_response_v1 import MeltwaterConnectorResponseV1
from openapi_client.models.mention_connector_response_v1 import MentionConnectorResponseV1
from openapi_client.models.microsoft_dynamics365_fo_connector_response_v1 import MicrosoftDynamics365FoConnectorResponseV1
from openapi_client.models.microsoft_lists_connector_response_v1 import MicrosoftListsConnectorResponseV1
from openapi_client.models.microsoft_teams_connector_response_v1 import MicrosoftTeamsConnectorResponseV1
from openapi_client.models.mixmax_connector_response_v1 import MixmaxConnectorResponseV1
from openapi_client.models.mixpanel_connector_response_v1 import MixpanelConnectorResponseV1
from openapi_client.models.mode_connector_response_v1 import ModeConnectorResponseV1
from openapi_client.models.model15five_connector_response_v1 import Model15fiveConnectorResponseV1
from openapi_client.models.model360learning_connector_response_v1 import Model360learningConnectorResponseV1
from openapi_client.models.model6sense_connector_response_v1 import Model6senseConnectorResponseV1
from openapi_client.models.moloco_connector_response_v1 import MolocoConnectorResponseV1
from openapi_client.models.monday_connector_response_v1 import MondayConnectorResponseV1
from openapi_client.models.mongo_connector_response_v1 import MongoConnectorResponseV1
from openapi_client.models.mongo_sharded_connector_response_v1 import MongoShardedConnectorResponseV1
from openapi_client.models.mountain_connector_response_v1 import MountainConnectorResponseV1
from openapi_client.models.mux_connector_response_v1 import MuxConnectorResponseV1
from openapi_client.models.mysql_azure_connector_response_v1 import MysqlAzureConnectorResponseV1
from openapi_client.models.mysql_connector_response_v1 import MysqlConnectorResponseV1
from openapi_client.models.mysql_rds_connector_response_v1 import MysqlRdsConnectorResponseV1
from openapi_client.models.namely_connector_response_v1 import NamelyConnectorResponseV1
from openapi_client.models.navan_connector_response_v1 import NavanConnectorResponseV1
from openapi_client.models.netsuite_suiteanalytics_connector_response_v1 import NetsuiteSuiteanalyticsConnectorResponseV1
from openapi_client.models.notion_connector_response_v1 import NotionConnectorResponseV1
from openapi_client.models.nylas_connector_response_v1 import NylasConnectorResponseV1
from openapi_client.models.okta_connector_response_v1 import OktaConnectorResponseV1
from openapi_client.models.ometria_connector_response_v1 import OmetriaConnectorResponseV1
from openapi_client.models.one_drive_connector_response_v1 import OneDriveConnectorResponseV1
from openapi_client.models.open_exchange_rates_connector_response_v1 import OpenExchangeRatesConnectorResponseV1
from openapi_client.models.opendistro_connector_response_v1 import OpendistroConnectorResponseV1
from openapi_client.models.opensearch_connector_response_v1 import OpensearchConnectorResponseV1
from openapi_client.models.optimizely_connector_response_v1 import OptimizelyConnectorResponseV1
from openapi_client.models.oracle_business_intelligence_publisher_connector_response_v1 import OracleBusinessIntelligencePublisherConnectorResponseV1
from openapi_client.models.oracle_connector_response_v1 import OracleConnectorResponseV1
from openapi_client.models.oracle_ebs_connector_response_v1 import OracleEbsConnectorResponseV1
from openapi_client.models.oracle_fusion_cloud_apps_crm_connector_response_v1 import OracleFusionCloudAppsCrmConnectorResponseV1
from openapi_client.models.oracle_fusion_cloud_apps_fscm_connector_response_v1 import OracleFusionCloudAppsFscmConnectorResponseV1
from openapi_client.models.oracle_fusion_cloud_apps_hcm_connector_response_v1 import OracleFusionCloudAppsHcmConnectorResponseV1
from openapi_client.models.oracle_hva_connector_response_v1 import OracleHvaConnectorResponseV1
from openapi_client.models.oracle_moat_analytics_connector_response_v1 import OracleMoatAnalyticsConnectorResponseV1
from openapi_client.models.oracle_rac_connector_response_v1 import OracleRacConnectorResponseV1
from openapi_client.models.oracle_rds_connector_response_v1 import OracleRdsConnectorResponseV1
from openapi_client.models.oracle_sap_hva_connector_response_v1 import OracleSapHvaConnectorResponseV1
from openapi_client.models.oracle_sap_hva_netweaver_connector_response_v1 import OracleSapHvaNetweaverConnectorResponseV1
from openapi_client.models.orbit_connector_response_v1 import OrbitConnectorResponseV1
from openapi_client.models.ordway_connector_response_v1 import OrdwayConnectorResponseV1
from openapi_client.models.ortto_connector_response_v1 import OrttoConnectorResponseV1
from openapi_client.models.outbrain_connector_response_v1 import OutbrainConnectorResponseV1
from openapi_client.models.outreach_connector_response_v1 import OutreachConnectorResponseV1
from openapi_client.models.pagerduty_connector_response_v1 import PagerdutyConnectorResponseV1
from openapi_client.models.papershift_connector_response_v1 import PapershiftConnectorResponseV1
from openapi_client.models.pardot_connector_response_v1 import PardotConnectorResponseV1
from openapi_client.models.partnerstack_vendor_connector_response_v1 import PartnerstackVendorConnectorResponseV1
from openapi_client.models.paychex_connector_response_v1 import PaychexConnectorResponseV1
from openapi_client.models.paypal_connector_response_v1 import PaypalConnectorResponseV1
from openapi_client.models.paypal_sandbox_connector_response_v1 import PaypalSandboxConnectorResponseV1
from openapi_client.models.pendo_connector_response_v1 import PendoConnectorResponseV1
from openapi_client.models.persona_connector_response_v1 import PersonaConnectorResponseV1
from openapi_client.models.personio_connector_response_v1 import PersonioConnectorResponseV1
from openapi_client.models.pingdom_connector_response_v1 import PingdomConnectorResponseV1
from openapi_client.models.pinpoint_connector_response_v1 import PinpointConnectorResponseV1
from openapi_client.models.pinterest_ads_connector_response_v1 import PinterestAdsConnectorResponseV1
from openapi_client.models.pinterest_organic_connector_response_v1 import PinterestOrganicConnectorResponseV1
from openapi_client.models.pipe17_connector_response_v1 import Pipe17ConnectorResponseV1
from openapi_client.models.pipedrive_connector_response_v1 import PipedriveConnectorResponseV1
from openapi_client.models.pivotal_tracker_connector_response_v1 import PivotalTrackerConnectorResponseV1
from openapi_client.models.piwik_pro_connector_response_v1 import PiwikProConnectorResponseV1
from openapi_client.models.planetscale_connector_response_v1 import PlanetscaleConnectorResponseV1
from openapi_client.models.playvox_connector_response_v1 import PlayvoxConnectorResponseV1
from openapi_client.models.postgres_connector_response_v1 import PostgresConnectorResponseV1
from openapi_client.models.postgres_rds_connector_response_v1 import PostgresRdsConnectorResponseV1
from openapi_client.models.posthog_connector_response_v1 import PosthogConnectorResponseV1
from openapi_client.models.postmark_connector_response_v1 import PostmarkConnectorResponseV1
from openapi_client.models.power_reviews_enterprise_connector_response_v1 import PowerReviewsEnterpriseConnectorResponseV1
from openapi_client.models.prive_connector_response_v1 import PriveConnectorResponseV1
from openapi_client.models.productboard_connector_response_v1 import ProductboardConnectorResponseV1
from openapi_client.models.qualaroo_connector_response_v1 import QualarooConnectorResponseV1
from openapi_client.models.qualtrics_connector_response_v1 import QualtricsConnectorResponseV1
from openapi_client.models.quickbooks_connector_response_v1 import QuickbooksConnectorResponseV1
from openapi_client.models.rakutenadvertising_connector_response_v1 import RakutenadvertisingConnectorResponseV1
from openapi_client.models.ramp_connector_response_v1 import RampConnectorResponseV1
from openapi_client.models.rarible_connector_response_v1 import RaribleConnectorResponseV1
from openapi_client.models.recharge_connector_response_v1 import RechargeConnectorResponseV1
from openapi_client.models.recurly_connector_response_v1 import RecurlyConnectorResponseV1
from openapi_client.models.reddit_ads_connector_response_v1 import RedditAdsConnectorResponseV1
from openapi_client.models.redshift_db_connector_response_v1 import RedshiftDbConnectorResponseV1
from openapi_client.models.reltio_connector_response_v1 import ReltioConnectorResponseV1
from openapi_client.models.replyio_connector_response_v1 import ReplyioConnectorResponseV1
from openapi_client.models.resource_management_by_smartsheet_connector_response_v1 import ResourceManagementBySmartsheetConnectorResponseV1
from openapi_client.models.retailnext_connector_response_v1 import RetailnextConnectorResponseV1
from openapi_client.models.retently_connector_response_v1 import RetentlyConnectorResponseV1
from openapi_client.models.revel_connector_response_v1 import RevelConnectorResponseV1
from openapi_client.models.revops_connector_response_v1 import RevopsConnectorResponseV1
from openapi_client.models.revx_connector_response_v1 import RevxConnectorResponseV1
from openapi_client.models.ringcentral_connector_response_v1 import RingcentralConnectorResponseV1
from openapi_client.models.ringover_connector_response_v1 import RingoverConnectorResponseV1
from openapi_client.models.rippling_connector_response_v1 import RipplingConnectorResponseV1
from openapi_client.models.rocketlane_connector_response_v1 import RocketlaneConnectorResponseV1
from openapi_client.models.rollbar_connector_response_v1 import RollbarConnectorResponseV1
from openapi_client.models.rootly_connector_response_v1 import RootlyConnectorResponseV1
from openapi_client.models.rtb_house_connector_response_v1 import RtbHouseConnectorResponseV1
from openapi_client.models.s3_connector_response_v1 import S3ConnectorResponseV1
from openapi_client.models.safetyculture_connector_response_v1 import SafetycultureConnectorResponseV1
from openapi_client.models.sage_hr_connector_response_v1 import SageHrConnectorResponseV1
from openapi_client.models.sage_intacct_connector_response_v1 import SageIntacctConnectorResponseV1
from openapi_client.models.sailthru_connector_response_v1 import SailthruConnectorResponseV1
from openapi_client.models.salesforce_commerce_cloud_connector_response_v1 import SalesforceCommerceCloudConnectorResponseV1
from openapi_client.models.salesforce_connector_response_v1 import SalesforceConnectorResponseV1
from openapi_client.models.salesforce_marketing_cloud_connector_response_v1 import SalesforceMarketingCloudConnectorResponseV1
from openapi_client.models.salesforce_sandbox_connector_response_v1 import SalesforceSandboxConnectorResponseV1
from openapi_client.models.salesloft_connector_response_v1 import SalesloftConnectorResponseV1
from openapi_client.models.salsify_connector_response_v1 import SalsifyConnectorResponseV1
from openapi_client.models.samsara_connector_response_v1 import SamsaraConnectorResponseV1
from openapi_client.models.sap_business_by_design_connector_response_v1 import SapBusinessByDesignConnectorResponseV1
from openapi_client.models.sap_hana_connector_response_v1 import SapHanaConnectorResponseV1
from openapi_client.models.sap_hana_db_connector_response_v1 import SapHanaDbConnectorResponseV1
from openapi_client.models.sap_s4hana_connector_response_v1 import SapS4hanaConnectorResponseV1
from openapi_client.models.scorm_connector_response_v1 import ScormConnectorResponseV1
from openapi_client.models.security_journey_connector_response_v1 import SecurityJourneyConnectorResponseV1
from openapi_client.models.segment_connector_response_v1 import SegmentConnectorResponseV1
from openapi_client.models.sendgrid_connector_response_v1 import SendgridConnectorResponseV1
from openapi_client.models.sensor_tower_connector_response_v1 import SensorTowerConnectorResponseV1
from openapi_client.models.servicenow_connector_response_v1 import ServicenowConnectorResponseV1
from openapi_client.models.servicetitan_connector_response_v1 import ServicetitanConnectorResponseV1
from openapi_client.models.sftp_connector_response_v1 import SftpConnectorResponseV1
from openapi_client.models.share_point_connector_response_v1 import SharePointConnectorResponseV1
from openapi_client.models.shiphero_connector_response_v1 import ShipheroConnectorResponseV1
from openapi_client.models.shipstation_connector_response_v1 import ShipstationConnectorResponseV1
from openapi_client.models.shopify_connector_response_v1 import ShopifyConnectorResponseV1
from openapi_client.models.shopware_connector_response_v1 import ShopwareConnectorResponseV1
from openapi_client.models.shortcut_connector_response_v1 import ShortcutConnectorResponseV1
from openapi_client.models.shortio_connector_response_v1 import ShortioConnectorResponseV1
from openapi_client.models.simplecast_connector_response_v1 import SimplecastConnectorResponseV1
from openapi_client.models.simplesat_connector_response_v1 import SimplesatConnectorResponseV1
from openapi_client.models.skilljar_connector_response_v1 import SkilljarConnectorResponseV1
from openapi_client.models.skuvault_connector_response_v1 import SkuvaultConnectorResponseV1
from openapi_client.models.slab_connector_response_v1 import SlabConnectorResponseV1
from openapi_client.models.slack_connector_response_v1 import SlackConnectorResponseV1
from openapi_client.models.smadex_connector_response_v1 import SmadexConnectorResponseV1
from openapi_client.models.smartwaiver_connector_response_v1 import SmartwaiverConnectorResponseV1
from openapi_client.models.snapchat_ads_connector_response_v1 import SnapchatAdsConnectorResponseV1
from openapi_client.models.snowflake_db_connector_response_v1 import SnowflakeDbConnectorResponseV1
from openapi_client.models.snowplow_connector_response_v1 import SnowplowConnectorResponseV1
from openapi_client.models.sonarqube_connector_response_v1 import SonarqubeConnectorResponseV1
from openapi_client.models.splitio_connector_response_v1 import SplitioConnectorResponseV1
from openapi_client.models.splunk_connector_response_v1 import SplunkConnectorResponseV1
from openapi_client.models.spotify_ads_connector_response_v1 import SpotifyAdsConnectorResponseV1
from openapi_client.models.sprout_connector_response_v1 import SproutConnectorResponseV1
from openapi_client.models.sql_server_connector_response_v1 import SqlServerConnectorResponseV1
from openapi_client.models.sql_server_hva_connector_response_v1 import SqlServerHvaConnectorResponseV1
from openapi_client.models.sql_server_rds_connector_response_v1 import SqlServerRdsConnectorResponseV1
from openapi_client.models.sql_server_sap_ecc_hva_connector_response_v1 import SqlServerSapEccHvaConnectorResponseV1
from openapi_client.models.square_connector_response_v1 import SquareConnectorResponseV1
from openapi_client.models.squarespace_connector_response_v1 import SquarespaceConnectorResponseV1
from openapi_client.models.stackadapt_connector_response_v1 import StackadaptConnectorResponseV1
from openapi_client.models.standard_metrics_connector_response_v1 import StandardMetricsConnectorResponseV1
from openapi_client.models.statsig_connector_response_v1 import StatsigConnectorResponseV1
from openapi_client.models.statuspage_connector_response_v1 import StatuspageConnectorResponseV1
from openapi_client.models.stripe_connector_response_v1 import StripeConnectorResponseV1
from openapi_client.models.stripe_test_connector_response_v1 import StripeTestConnectorResponseV1
from openapi_client.models.stylight_connector_response_v1 import StylightConnectorResponseV1
from openapi_client.models.subscript_connector_response_v1 import SubscriptConnectorResponseV1
from openapi_client.models.survey_monkey_connector_response_v1 import SurveyMonkeyConnectorResponseV1
from openapi_client.models.survicate_connector_response_v1 import SurvicateConnectorResponseV1
from openapi_client.models.swoogo_connector_response_v1 import SwoogoConnectorResponseV1
from openapi_client.models.tableau_source_connector_response_v1 import TableauSourceConnectorResponseV1
from openapi_client.models.taboola_connector_response_v1 import TaboolaConnectorResponseV1
from openapi_client.models.talkdesk_connector_response_v1 import TalkdeskConnectorResponseV1
from openapi_client.models.talkwalker_connector_response_v1 import TalkwalkerConnectorResponseV1
from openapi_client.models.teamwork_connector_response_v1 import TeamworkConnectorResponseV1
from openapi_client.models.tempo_connector_response_v1 import TempoConnectorResponseV1
from openapi_client.models.the_trade_desk_connector_response_v1 import TheTradeDeskConnectorResponseV1
from openapi_client.models.thinkific_connector_response_v1 import ThinkificConnectorResponseV1
from openapi_client.models.tiktok_ads_connector_response_v1 import TiktokAdsConnectorResponseV1
from openapi_client.models.toggl_track_connector_response_v1 import TogglTrackConnectorResponseV1
from openapi_client.models.transcend_connector_response_v1 import TranscendConnectorResponseV1
from openapi_client.models.trello_connector_response_v1 import TrelloConnectorResponseV1
from openapi_client.models.trisolute_connector_response_v1 import TrisoluteConnectorResponseV1
from openapi_client.models.twilio_connector_response_v1 import TwilioConnectorResponseV1
from openapi_client.models.twitter_ads_connector_response_v1 import TwitterAdsConnectorResponseV1
from openapi_client.models.twitter_connector_response_v1 import TwitterConnectorResponseV1
from openapi_client.models.typeform_connector_response_v1 import TypeformConnectorResponseV1
from openapi_client.models.ukg_pro_connector_response_v1 import UkgProConnectorResponseV1
from openapi_client.models.unicommerce_connector_response_v1 import UnicommerceConnectorResponseV1
from openapi_client.models.upland_connector_response_v1 import UplandConnectorResponseV1
from openapi_client.models.uppromote_connector_response_v1 import UppromoteConnectorResponseV1
from openapi_client.models.uservoice_connector_response_v1 import UservoiceConnectorResponseV1
from openapi_client.models.vitally_connector_response_v1 import VitallyConnectorResponseV1
from openapi_client.models.vonage_connector_response_v1 import VonageConnectorResponseV1
from openapi_client.models.vts_connector_response_v1 import VtsConnectorResponseV1
from openapi_client.models.vwo_connector_response_v1 import VwoConnectorResponseV1
from openapi_client.models.wasabi_cloud_storage_connector_response_v1 import WasabiCloudStorageConnectorResponseV1
from openapi_client.models.webhooks_connector_response_v1 import WebhooksConnectorResponseV1
from openapi_client.models.when_i_work_connector_response_v1 import WhenIWorkConnectorResponseV1
from openapi_client.models.wherefour_connector_response_v1 import WherefourConnectorResponseV1
from openapi_client.models.woocommerce_connector_response_v1 import WoocommerceConnectorResponseV1
from openapi_client.models.wordpress_connector_response_v1 import WordpressConnectorResponseV1
from openapi_client.models.workable_connector_response_v1 import WorkableConnectorResponseV1
from openapi_client.models.workday_connector_response_v1 import WorkdayConnectorResponseV1
from openapi_client.models.workday_financial_management_connector_response_v1 import WorkdayFinancialManagementConnectorResponseV1
from openapi_client.models.workday_hcm_connector_response_v1 import WorkdayHcmConnectorResponseV1
from openapi_client.models.workday_strategic_sourcing_connector_response_v1 import WorkdayStrategicSourcingConnectorResponseV1
from openapi_client.models.workflowmax_connector_response_v1 import WorkflowmaxConnectorResponseV1
from openapi_client.models.workramp_connector_response_v1 import WorkrampConnectorResponseV1
from openapi_client.models.wrike_connector_response_v1 import WrikeConnectorResponseV1
from openapi_client.models.xero_connector_response_v1 import XeroConnectorResponseV1
from openapi_client.models.xray_connector_response_v1 import XrayConnectorResponseV1
from openapi_client.models.xsolla_connector_response_v1 import XsollaConnectorResponseV1
from openapi_client.models.yahoo_dsp_connector_response_v1 import YahooDspConnectorResponseV1
from openapi_client.models.yahoo_gemini_connector_response_v1 import YahooGeminiConnectorResponseV1
from openapi_client.models.yahoo_search_ads_yahoo_japan_connector_response_v1 import YahooSearchAdsYahooJapanConnectorResponseV1
from openapi_client.models.yotpo_connector_response_v1 import YotpoConnectorResponseV1
from openapi_client.models.youtube_analytics_connector_response_v1 import YoutubeAnalyticsConnectorResponseV1
from openapi_client.models.zendesk_chat_connector_response_v1 import ZendeskChatConnectorResponseV1
from openapi_client.models.zendesk_connector_response_v1 import ZendeskConnectorResponseV1
from openapi_client.models.zendesk_sell_connector_response_v1 import ZendeskSellConnectorResponseV1
from openapi_client.models.zendesk_sunshine_connector_response_v1 import ZendeskSunshineConnectorResponseV1
from openapi_client.models.zenefits_connector_response_v1 import ZenefitsConnectorResponseV1
from openapi_client.models.zoho_books_connector_response_v1 import ZohoBooksConnectorResponseV1
from openapi_client.models.zoho_campaigns_connector_response_v1 import ZohoCampaignsConnectorResponseV1
from openapi_client.models.zoho_crm_connector_response_v1 import ZohoCrmConnectorResponseV1
from openapi_client.models.zoho_desk_connector_response_v1 import ZohoDeskConnectorResponseV1
from openapi_client.models.zoom_connector_response_v1 import ZoomConnectorResponseV1
from openapi_client.models.zuora_connector_response_v1 import ZuoraConnectorResponseV1
from openapi_client.models.zuora_sandbox_connector_response_v1 import ZuoraSandboxConnectorResponseV1
# TODO: Rewrite to not use raise_errors
ConnectorResponseV1.model_rebuild(raise_errors=False)

