# coding: utf-8

"""
    OpenAPI Definition

    The OpenAPI Specification is a standard format to define the structure and syntax of REST APIs. OpenAPI documents are both machine and human-readable, which enables anyone to easily determine how each API works. [More details](https://www.openapis.org/faq)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, SecretStr, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MongoShardedConfigV1Config(BaseModel):
    """
    
    """ # noqa: E501
    public_key: Optional[StrictStr] = Field(default=None, description="Public Key")
    packed_mode_tables: Optional[List[StrictStr]] = Field(default=None, description="List of tables to be synced in packed mode; format:`<db>.<table>`(case-sensitive).")
    tunnel_port: Optional[StrictInt] = Field(default=None, description="SSH port, specify only to connect via an SSH tunnel.")
    password: Optional[SecretStr] = Field(default=None, description="The user's password.")
    packing_mode: Optional[Dict[str, Any]] = Field(default=None, description="Whether to sync all tables in unpacked mode only, all tables in packed mode only, or specific tables in packed mode. Default value: `UseUnpackedModeOnly`.")
    connection_type: Optional[Dict[str, Any]] = Field(default=None, description="Possible values:`Directly`, `PrivateLink`, `SshTunnel`. `SshTunnel` is used as a value if this parameter is omitted in the request and any of the following parameter's values is specified: `tunnel_host`, `tunnel_port`, `tunnel_user`. Otherwise, `Directly` is used as a value if the parameter is omitted.")
    hosts: Optional[List[StrictStr]] = Field(default=None, description="A list of host addresses of the primary node and all replicas. Each list item is either: a DB instance host/IP address with a port number, or SRV host record.")
    tunnel_host: Optional[StrictStr] = Field(default=None, description="SSH host, specify only to connect via an SSH tunnel (do not use a load balancer).")
    schema_prefix: Optional[StrictStr] = Field(default=None, description="Destination schema prefix. Prefix for each replicated schema. For example with prefix 'x', source schemas 'foo' and 'bar' get replicated as 'x_foo' and 'x_bar'. The prefix is permanent and cannot be changed after connection creation")
    always_encrypted: Optional[StrictBool] = Field(default=None, description="Require TLS through Tunnel")
    user: Optional[StrictStr] = Field(default=None, description="The user name.")
    tunnel_user: Optional[StrictStr] = Field(default=None, description="SSH user, specify only to connect via an SSH tunnel.")
    __properties: ClassVar[List[str]] = ["public_key", "packed_mode_tables", "tunnel_port", "password", "packing_mode", "connection_type", "hosts", "tunnel_host", "schema_prefix", "always_encrypted", "user", "tunnel_user"]

    @field_validator('packing_mode')
    def packing_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('SelectTablesForPackedMode', 'UsePackedModeOnly', 'UseUnpackedModeOnly'):
            raise ValueError("must be one of enum values ('SelectTablesForPackedMode', 'UsePackedModeOnly', 'UseUnpackedModeOnly')")
        return value

    @field_validator('connection_type')
    def connection_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Directly', 'PrivateLink', 'SshTunnel'):
            raise ValueError("must be one of enum values ('Directly', 'PrivateLink', 'SshTunnel')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MongoShardedConfigV1Config from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MongoShardedConfigV1Config from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "public_key": obj.get("public_key"),
            "packed_mode_tables": obj.get("packed_mode_tables"),
            "tunnel_port": obj.get("tunnel_port"),
            "password": obj.get("password"),
            "packing_mode": obj.get("packing_mode"),
            "connection_type": obj.get("connection_type"),
            "hosts": obj.get("hosts"),
            "tunnel_host": obj.get("tunnel_host"),
            "schema_prefix": obj.get("schema_prefix"),
            "always_encrypted": obj.get("always_encrypted"),
            "user": obj.get("user"),
            "tunnel_user": obj.get("tunnel_user")
        })
        return _obj


