# coding: utf-8

"""
    OpenAPI Definition

    The OpenAPI Specification is a standard format to define the structure and syntax of REST APIs. OpenAPI documents are both machine and human-readable, which enables anyone to easily determine how each API works. [More details](https://www.openapis.org/faq)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from openapi_client.models.connect_card_config import ConnectCardConfig
from typing import Optional, Set
from typing_extensions import Self

class NewConnectorRequestV1(BaseModel):
    """
    NewConnectorRequestV1
    """ # noqa: E501
    group_id: StrictStr = Field(description="The unique identifier for the group within the Fivetran system")
    service: StrictStr = Field(description="The connector type name within the Fivetran system")
    trust_certificates: Optional[StrictBool] = Field(default=None, description="Specifies whether we should trust the certificate automatically. The default value is FALSE. If a certificate is not trusted automatically, it has to be approved with [Certificates Management API Approve a destination certificate](https://fivetran.com/docs/rest-api/certificates#approveadestinationcertificate).")
    trust_fingerprints: Optional[StrictBool] = Field(default=None, description="Specifies whether we should trust the SSH fingerprint automatically. The default value is FALSE. If a fingerprint is not trusted automatically, it has to be approved with [Certificates Management API Approve a destination fingerprint](https://fivetran.com/docs/rest-api/certificates#approveadestinationfingerprint).")
    run_setup_tests: Optional[StrictBool] = Field(default=None, description="Specifies whether the setup tests should be run automatically. The default value is TRUE.")
    paused: Optional[StrictBool] = Field(default=None, description="Specifies whether the connector is paused")
    pause_after_trial: Optional[StrictBool] = Field(default=None, description="Specifies whether the connector should be paused after the free trial period has ended")
    sync_frequency: Optional[StrictInt] = Field(default=None, description="The connector sync frequency in minutes")
    data_delay_sensitivity: Optional[StrictStr] = None
    data_delay_threshold: Optional[StrictInt] = None
    daily_sync_time: Optional[StrictStr] = Field(default=None, description="The optional parameter that defines the sync start time when the sync frequency is already set or being set by the current request to 1440. It can be specified in one hour increments starting from 00:00 to 23:00. If not specified, we will use [the baseline sync start time](https://fivetran.com/docs/getting-started/syncoverview#syncfrequencyandscheduling). This parameter has no effect on the [0 to 60 minutes offset](https://fivetran.com/docs/getting-started/syncoverview#syncstarttimesandoffsets) used to determine the actual sync start time")
    schedule_type: Optional[StrictStr] = None
    connect_card_config: Optional[ConnectCardConfig] = None
    __properties: ClassVar[List[str]] = ["group_id", "service", "trust_certificates", "trust_fingerprints", "run_setup_tests", "paused", "pause_after_trial", "sync_frequency", "data_delay_sensitivity", "data_delay_threshold", "daily_sync_time", "schedule_type", "connect_card_config"]

    @field_validator('sync_frequency')
    def sync_frequency_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (5, 15, 30, 60, 120, 180, 360, 480, 720, 1440):
            raise ValueError("must be one of enum values (5, 15, 30, 60, 120, 180, 360, 480, 720, 1440)")
        return value

    @field_validator('data_delay_sensitivity')
    def data_delay_sensitivity_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('LOW', 'NORMAL', 'HIGH', 'CUSTOM'):
            raise ValueError("must be one of enum values ('LOW', 'NORMAL', 'HIGH', 'CUSTOM')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    # JSON field name that stores the object type
    __discriminator_property_name: ClassVar[str] = 'service'

    # discriminator mappings
    __discriminator_value_class_map: ClassVar[Dict[str, str]] = {
        '15five': 'Model15fiveNewConnectorRequestV1','360learning': 'Model360learningNewConnectorRequestV1','6sense': 'Model6senseNewConnectorRequestV1','activecampaign': 'ActivecampaignNewConnectorRequestV1','acumatica': 'AcumaticaNewConnectorRequestV1','ada': 'AdaNewConnectorRequestV1','adjust': 'AdjustNewConnectorRequestV1','adobe_analytics': 'AdobeAnalyticsNewConnectorRequestV1','adobe_analytics_data_feed': 'AdobeAnalyticsDataFeedNewConnectorRequestV1','adobe_commerce': 'AdobeCommerceNewConnectorRequestV1','adp_workforce_now': 'AdpWorkforceNowNewConnectorRequestV1','adroll': 'AdrollNewConnectorRequestV1','affinity': 'AffinityNewConnectorRequestV1','afterpay': 'AfterpayNewConnectorRequestV1','aha': 'AhaNewConnectorRequestV1','aircall': 'AircallNewConnectorRequestV1','airtable': 'AirtableNewConnectorRequestV1','alchemer': 'AlchemerNewConnectorRequestV1','algolia': 'AlgoliaNewConnectorRequestV1','amazon_ads': 'AmazonAdsNewConnectorRequestV1','amazon_attribution': 'AmazonAttributionNewConnectorRequestV1','amazon_selling_partner': 'AmazonSellingPartnerNewConnectorRequestV1','amplitude': 'AmplitudeNewConnectorRequestV1','anaplan': 'AnaplanNewConnectorRequestV1','apache_kafka': 'ApacheKafkaNewConnectorRequestV1','appcues': 'AppcuesNewConnectorRequestV1','appfigures': 'AppfiguresNewConnectorRequestV1','apple_search_ads': 'AppleSearchAdsNewConnectorRequestV1','appsflyer': 'AppsflyerNewConnectorRequestV1','asana': 'AsanaNewConnectorRequestV1','assembled': 'AssembledNewConnectorRequestV1','atlassian_jira_align': 'AtlassianJiraAlignNewConnectorRequestV1','atlassian_ops_genie': 'AtlassianOpsGenieNewConnectorRequestV1','attentive': 'AttentiveNewConnectorRequestV1','attio': 'AttioNewConnectorRequestV1','aumni': 'AumniNewConnectorRequestV1','aurora': 'AuroraNewConnectorRequestV1','aurora_postgres': 'AuroraPostgresNewConnectorRequestV1','auth0': 'Auth0NewConnectorRequestV1','autodesk_bim_360': 'AutodeskBim360NewConnectorRequestV1','avantlink': 'AvantlinkNewConnectorRequestV1','awin': 'AwinNewConnectorRequestV1','aws_cloudtrail': 'AwsCloudtrailNewConnectorRequestV1','aws_cost': 'AwsCostNewConnectorRequestV1','aws_inventory': 'AwsInventoryNewConnectorRequestV1','aws_lambda': 'AwsLambdaNewConnectorRequestV1','aws_msk': 'AwsMskNewConnectorRequestV1','azure_blob_storage': 'AzureBlobStorageNewConnectorRequestV1','azure_boards': 'AzureBoardsNewConnectorRequestV1','azure_devops': 'AzureDevopsNewConnectorRequestV1','azure_event_hub': 'AzureEventHubNewConnectorRequestV1','azure_function': 'AzureFunctionNewConnectorRequestV1','azure_postgres': 'AzurePostgresNewConnectorRequestV1','azure_service_bus': 'AzureServiceBusNewConnectorRequestV1','azure_sql_db': 'AzureSqlDbNewConnectorRequestV1','azure_sql_managed_db': 'AzureSqlManagedDbNewConnectorRequestV1','ballotready': 'BallotreadyNewConnectorRequestV1','bamboohr': 'BamboohrNewConnectorRequestV1','big_commerce': 'BigCommerceNewConnectorRequestV1','bigquery_db': 'BigqueryDbNewConnectorRequestV1','billing_platform': 'BillingPlatformNewConnectorRequestV1','bingads': 'BingadsNewConnectorRequestV1','birdeye': 'BirdeyeNewConnectorRequestV1','bitly': 'BitlyNewConnectorRequestV1','box': 'BoxNewConnectorRequestV1','braintree': 'BraintreeNewConnectorRequestV1','braintree_sandbox': 'BraintreeSandboxNewConnectorRequestV1','branch': 'BranchNewConnectorRequestV1','braze': 'BrazeNewConnectorRequestV1','brevo': 'BrevoNewConnectorRequestV1','brex': 'BrexNewConnectorRequestV1','buildkite': 'BuildkiteNewConnectorRequestV1','business_central': 'BusinessCentralNewConnectorRequestV1','buzzsprout': 'BuzzsproutNewConnectorRequestV1','calabrio': 'CalabrioNewConnectorRequestV1','calendly': 'CalendlyNewConnectorRequestV1','campaignmonitor': 'CampaignmonitorNewConnectorRequestV1','canny': 'CannyNewConnectorRequestV1','care_quality_commission': 'CareQualityCommissionNewConnectorRequestV1','castor_edc': 'CastorEdcNewConnectorRequestV1','ceridian_dayforce': 'CeridianDayforceNewConnectorRequestV1','channel_advisor': 'ChannelAdvisorNewConnectorRequestV1','chargebee_product_catalog_1': 'ChargebeeProductCatalog1NewConnectorRequestV1','chargebee_product_catalog_2': 'ChargebeeProductCatalog2NewConnectorRequestV1','chargedesk': 'ChargedeskNewConnectorRequestV1','chartmogul': 'ChartmogulNewConnectorRequestV1','checkout': 'CheckoutNewConnectorRequestV1','checkr': 'CheckrNewConnectorRequestV1','chorusai': 'ChorusaiNewConnectorRequestV1','churnkey': 'ChurnkeyNewConnectorRequestV1','churnzero': 'ChurnzeroNewConnectorRequestV1','cimis': 'CimisNewConnectorRequestV1','cin7': 'Cin7NewConnectorRequestV1','circleci': 'CircleciNewConnectorRequestV1','cj_commission_detail': 'CjCommissionDetailNewConnectorRequestV1','clari': 'ClariNewConnectorRequestV1','clickup': 'ClickupNewConnectorRequestV1','close': 'CloseNewConnectorRequestV1','cloudfront': 'CloudfrontNewConnectorRequestV1','coassemble': 'CoassembleNewConnectorRequestV1','codefresh': 'CodefreshNewConnectorRequestV1','collibra': 'CollibraNewConnectorRequestV1','column': 'ColumnNewConnectorRequestV1','concord': 'ConcordNewConnectorRequestV1','concur': 'ConcurNewConnectorRequestV1','confluence': 'ConfluenceNewConnectorRequestV1','confluent_cloud': 'ConfluentCloudNewConnectorRequestV1','contrast_security': 'ContrastSecurityNewConnectorRequestV1','convex': 'ConvexNewConnectorRequestV1','copper': 'CopperNewConnectorRequestV1','cosmos': 'CosmosNewConnectorRequestV1','coupa': 'CoupaNewConnectorRequestV1','criteo': 'CriteoNewConnectorRequestV1','crossbeam': 'CrossbeamNewConnectorRequestV1','crowddev': 'CrowddevNewConnectorRequestV1','customerio': 'CustomerioNewConnectorRequestV1','cvent': 'CventNewConnectorRequestV1','d2l_brightspace': 'D2lBrightspaceNewConnectorRequestV1','db2': 'Db2NewConnectorRequestV1','db2i_hva': 'Db2iHvaNewConnectorRequestV1','db2i_sap_hva': 'Db2iSapHvaNewConnectorRequestV1','dbt_cloud': 'DbtCloudNewConnectorRequestV1','dcl_logistics': 'DclLogisticsNewConnectorRequestV1','dear': 'DearNewConnectorRequestV1','delighted': 'DelightedNewConnectorRequestV1','deputy': 'DeputyNewConnectorRequestV1','destini': 'DestiniNewConnectorRequestV1','dixa': 'DixaNewConnectorRequestV1','docebo': 'DoceboNewConnectorRequestV1','documentdb': 'DocumentdbNewConnectorRequestV1','double_click_campaign_manager': 'DoubleClickCampaignManagerNewConnectorRequestV1','double_click_publishers': 'DoubleClickPublishersNewConnectorRequestV1','drata': 'DrataNewConnectorRequestV1','drift': 'DriftNewConnectorRequestV1','drip': 'DripNewConnectorRequestV1','dropbox': 'DropboxNewConnectorRequestV1','dropbox_sign': 'DropboxSignNewConnectorRequestV1','dsv': 'DsvNewConnectorRequestV1','dynamics_365': 'Dynamics365NewConnectorRequestV1','dynamics_365_fo': 'Dynamics365FoNewConnectorRequestV1','dynamodb': 'DynamodbNewConnectorRequestV1','easypost': 'EasypostNewConnectorRequestV1','economic': 'EconomicNewConnectorRequestV1','elastic_cloud': 'ElasticCloudNewConnectorRequestV1','eloqua': 'EloquaNewConnectorRequestV1','email': 'EmailNewConnectorRequestV1','employment_hero': 'EmploymentHeroNewConnectorRequestV1','es_self_hosted': 'EsSelfHostedNewConnectorRequestV1','eventbrite': 'EventbriteNewConnectorRequestV1','everhour': 'EverhourNewConnectorRequestV1','expensify': 'ExpensifyNewConnectorRequestV1','ezofficeinventory': 'EzofficeinventoryNewConnectorRequestV1','facebook_ads': 'FacebookAdsNewConnectorRequestV1','facebook_pages': 'FacebookPagesNewConnectorRequestV1','factorial': 'FactorialNewConnectorRequestV1','financial_force': 'FinancialForceNewConnectorRequestV1','firebase': 'FirebaseNewConnectorRequestV1','fivetran_log': 'FivetranLogNewConnectorRequestV1','flexport': 'FlexportNewConnectorRequestV1','float': 'FloatNewConnectorRequestV1','fone_dynamics': 'FoneDynamicsNewConnectorRequestV1','forj_community': 'ForjCommunityNewConnectorRequestV1','fountain': 'FountainNewConnectorRequestV1','freightview': 'FreightviewNewConnectorRequestV1','freshbooks': 'FreshbooksNewConnectorRequestV1','freshchat': 'FreshchatNewConnectorRequestV1','freshdesk': 'FreshdeskNewConnectorRequestV1','freshservice': 'FreshserviceNewConnectorRequestV1','freshteam': 'FreshteamNewConnectorRequestV1','friendbuy': 'FriendbuyNewConnectorRequestV1','front': 'FrontNewConnectorRequestV1','ftp': 'FtpNewConnectorRequestV1','fullstory': 'FullstoryNewConnectorRequestV1','gainsight_customer_success': 'GainsightCustomerSuccessNewConnectorRequestV1','gcs': 'GcsNewConnectorRequestV1','gem': 'GemNewConnectorRequestV1','getfeedback': 'GetfeedbackNewConnectorRequestV1','github': 'GithubNewConnectorRequestV1','gitlab': 'GitlabNewConnectorRequestV1','gladly': 'GladlyNewConnectorRequestV1','globalmeet': 'GlobalmeetNewConnectorRequestV1','gocardless': 'GocardlessNewConnectorRequestV1','gongio': 'GongioNewConnectorRequestV1','google_ads': 'GoogleAdsNewConnectorRequestV1','google_analytics': 'GoogleAnalyticsNewConnectorRequestV1','google_analytics_360': 'GoogleAnalytics360NewConnectorRequestV1','google_analytics_4': 'GoogleAnalytics4NewConnectorRequestV1','google_analytics_4_export': 'GoogleAnalytics4ExportNewConnectorRequestV1','google_analytics_mcf': 'GoogleAnalyticsMcfNewConnectorRequestV1','google_business_profile': 'GoogleBusinessProfileNewConnectorRequestV1','google_calendar': 'GoogleCalendarNewConnectorRequestV1','google_cloud_function': 'GoogleCloudFunctionNewConnectorRequestV1','google_cloud_mysql': 'GoogleCloudMysqlNewConnectorRequestV1','google_cloud_postgresql': 'GoogleCloudPostgresqlNewConnectorRequestV1','google_cloud_sqlserver': 'GoogleCloudSqlserverNewConnectorRequestV1','google_display_and_video_360': 'GoogleDisplayAndVideo360NewConnectorRequestV1','google_drive': 'GoogleDriveNewConnectorRequestV1','google_play': 'GooglePlayNewConnectorRequestV1','google_search_ads_360': 'GoogleSearchAds360NewConnectorRequestV1','google_search_console': 'GoogleSearchConsoleNewConnectorRequestV1','google_sheets': 'GoogleSheetsNewConnectorRequestV1','gorgias': 'GorgiasNewConnectorRequestV1','green_power_monitor': 'GreenPowerMonitorNewConnectorRequestV1','greenhouse': 'GreenhouseNewConnectorRequestV1','grepsr': 'GrepsrNewConnectorRequestV1','grin': 'GrinNewConnectorRequestV1','guru': 'GuruNewConnectorRequestV1','hana_sap_hva_b1': 'HanaSapHvaB1NewConnectorRequestV1','hana_sap_hva_ecc': 'HanaSapHvaEccNewConnectorRequestV1','hana_sap_hva_ecc_netweaver': 'HanaSapHvaEccNetweaverNewConnectorRequestV1','hana_sap_hva_s4': 'HanaSapHvaS4NewConnectorRequestV1','hana_sap_hva_s4_netweaver': 'HanaSapHvaS4NetweaverNewConnectorRequestV1','happyfox': 'HappyfoxNewConnectorRequestV1','harvest': 'HarvestNewConnectorRequestV1','heap': 'HeapNewConnectorRequestV1','height': 'HeightNewConnectorRequestV1','helpscout': 'HelpscoutNewConnectorRequestV1','helpshift': 'HelpshiftNewConnectorRequestV1','heroku_kafka': 'HerokuKafkaNewConnectorRequestV1','heroku_postgres': 'HerokuPostgresNewConnectorRequestV1','hibob': 'HibobNewConnectorRequestV1','hopin': 'HopinNewConnectorRequestV1','hubspot': 'HubspotNewConnectorRequestV1','ilevel': 'IlevelNewConnectorRequestV1','impact': 'ImpactNewConnectorRequestV1','incidentio': 'IncidentioNewConnectorRequestV1','infobip': 'InfobipNewConnectorRequestV1','insightly': 'InsightlyNewConnectorRequestV1','instagram_business': 'InstagramBusinessNewConnectorRequestV1','integral_ad_science': 'IntegralAdScienceNewConnectorRequestV1','integrate': 'IntegrateNewConnectorRequestV1','intercom': 'IntercomNewConnectorRequestV1','ironclad': 'IroncladNewConnectorRequestV1','ironsource': 'IronsourceNewConnectorRequestV1','iterable': 'IterableNewConnectorRequestV1','itunes_connect': 'ItunesConnectNewConnectorRequestV1','ivanti': 'IvantiNewConnectorRequestV1','jira': 'JiraNewConnectorRequestV1','jotform': 'JotformNewConnectorRequestV1','justcall': 'JustcallNewConnectorRequestV1','kandji': 'KandjiNewConnectorRequestV1','katana': 'KatanaNewConnectorRequestV1','keypay': 'KeypayNewConnectorRequestV1','khoros_care': 'KhorosCareNewConnectorRequestV1','kinesis': 'KinesisNewConnectorRequestV1','kissmetrics': 'KissmetricsNewConnectorRequestV1','klarna': 'KlarnaNewConnectorRequestV1','klaviyo': 'KlaviyoNewConnectorRequestV1','konnect_insights': 'KonnectInsightsNewConnectorRequestV1','kustomer': 'KustomerNewConnectorRequestV1','lattice': 'LatticeNewConnectorRequestV1','launchdarkly': 'LaunchdarklyNewConnectorRequestV1','learnupon': 'LearnuponNewConnectorRequestV1','lessonly': 'LessonlyNewConnectorRequestV1','lever': 'LeverNewConnectorRequestV1','liftoff': 'LiftoffNewConnectorRequestV1','light_speed_retail': 'LightSpeedRetailNewConnectorRequestV1','linear': 'LinearNewConnectorRequestV1','linkedin_ads': 'LinkedinAdsNewConnectorRequestV1','linkedin_company_pages': 'LinkedinCompanyPagesNewConnectorRequestV1','linksquares': 'LinksquaresNewConnectorRequestV1','livechat': 'LivechatNewConnectorRequestV1','lob': 'LobNewConnectorRequestV1','looker_source': 'LookerSourceNewConnectorRequestV1','loop': 'LoopNewConnectorRequestV1','loopio': 'LoopioNewConnectorRequestV1','luma': 'LumaNewConnectorRequestV1','magento_mysql': 'MagentoMysqlNewConnectorRequestV1','magento_mysql_rds': 'MagentoMysqlRdsNewConnectorRequestV1','mailchimp': 'MailchimpNewConnectorRequestV1','mailgun': 'MailgunNewConnectorRequestV1','mandrill': 'MandrillNewConnectorRequestV1','maria': 'MariaNewConnectorRequestV1','maria_azure': 'MariaAzureNewConnectorRequestV1','maria_rds': 'MariaRdsNewConnectorRequestV1','marin': 'MarinNewConnectorRequestV1','marketo': 'MarketoNewConnectorRequestV1','mavenlink': 'MavenlinkNewConnectorRequestV1','maxio_chargify': 'MaxioChargifyNewConnectorRequestV1','maxio_saasoptics': 'MaxioSaasopticsNewConnectorRequestV1','medallia': 'MedalliaNewConnectorRequestV1','megaphone': 'MegaphoneNewConnectorRequestV1','meltwater': 'MeltwaterNewConnectorRequestV1','mention': 'MentionNewConnectorRequestV1','microsoft_dynamics_365_fo': 'MicrosoftDynamics365FoNewConnectorRequestV1','microsoft_lists': 'MicrosoftListsNewConnectorRequestV1','microsoft_teams': 'MicrosoftTeamsNewConnectorRequestV1','mixmax': 'MixmaxNewConnectorRequestV1','mixpanel': 'MixpanelNewConnectorRequestV1','mode': 'ModeNewConnectorRequestV1','moloco': 'MolocoNewConnectorRequestV1','monday': 'MondayNewConnectorRequestV1','mongo': 'MongoNewConnectorRequestV1','mongo_sharded': 'MongoShardedNewConnectorRequestV1','mountain': 'MountainNewConnectorRequestV1','mux': 'MuxNewConnectorRequestV1','mysql': 'MysqlNewConnectorRequestV1','mysql_azure': 'MysqlAzureNewConnectorRequestV1','mysql_rds': 'MysqlRdsNewConnectorRequestV1','namely': 'NamelyNewConnectorRequestV1','navan': 'NavanNewConnectorRequestV1','netsuite_suiteanalytics': 'NetsuiteSuiteanalyticsNewConnectorRequestV1','notion': 'NotionNewConnectorRequestV1','nylas': 'NylasNewConnectorRequestV1','okta': 'OktaNewConnectorRequestV1','ometria': 'OmetriaNewConnectorRequestV1','one_drive': 'OneDriveNewConnectorRequestV1','open_exchange_rates': 'OpenExchangeRatesNewConnectorRequestV1','opendistro': 'OpendistroNewConnectorRequestV1','opensearch': 'OpensearchNewConnectorRequestV1','optimizely': 'OptimizelyNewConnectorRequestV1','oracle': 'OracleNewConnectorRequestV1','oracle_business_intelligence_publisher': 'OracleBusinessIntelligencePublisherNewConnectorRequestV1','oracle_ebs': 'OracleEbsNewConnectorRequestV1','oracle_fusion_cloud_apps_crm': 'OracleFusionCloudAppsCrmNewConnectorRequestV1','oracle_fusion_cloud_apps_fscm': 'OracleFusionCloudAppsFscmNewConnectorRequestV1','oracle_fusion_cloud_apps_hcm': 'OracleFusionCloudAppsHcmNewConnectorRequestV1','oracle_hva': 'OracleHvaNewConnectorRequestV1','oracle_moat_analytics': 'OracleMoatAnalyticsNewConnectorRequestV1','oracle_rac': 'OracleRacNewConnectorRequestV1','oracle_rds': 'OracleRdsNewConnectorRequestV1','oracle_sap_hva': 'OracleSapHvaNewConnectorRequestV1','oracle_sap_hva_netweaver': 'OracleSapHvaNetweaverNewConnectorRequestV1','orbit': 'OrbitNewConnectorRequestV1','ordway': 'OrdwayNewConnectorRequestV1','ortto': 'OrttoNewConnectorRequestV1','outbrain': 'OutbrainNewConnectorRequestV1','outreach': 'OutreachNewConnectorRequestV1','pagerduty': 'PagerdutyNewConnectorRequestV1','papershift': 'PapershiftNewConnectorRequestV1','pardot': 'PardotNewConnectorRequestV1','partnerstack_vendor': 'PartnerstackVendorNewConnectorRequestV1','paychex': 'PaychexNewConnectorRequestV1','paypal': 'PaypalNewConnectorRequestV1','paypal_sandbox': 'PaypalSandboxNewConnectorRequestV1','pendo': 'PendoNewConnectorRequestV1','persona': 'PersonaNewConnectorRequestV1','personio': 'PersonioNewConnectorRequestV1','pingdom': 'PingdomNewConnectorRequestV1','pinpoint': 'PinpointNewConnectorRequestV1','pinterest_ads': 'PinterestAdsNewConnectorRequestV1','pinterest_organic': 'PinterestOrganicNewConnectorRequestV1','pipe17': 'Pipe17NewConnectorRequestV1','pipedrive': 'PipedriveNewConnectorRequestV1','pivotal_tracker': 'PivotalTrackerNewConnectorRequestV1','piwik_pro': 'PiwikProNewConnectorRequestV1','planetscale': 'PlanetscaleNewConnectorRequestV1','playvox': 'PlayvoxNewConnectorRequestV1','postgres': 'PostgresNewConnectorRequestV1','postgres_rds': 'PostgresRdsNewConnectorRequestV1','posthog': 'PosthogNewConnectorRequestV1','postmark': 'PostmarkNewConnectorRequestV1','power_reviews_enterprise': 'PowerReviewsEnterpriseNewConnectorRequestV1','prive': 'PriveNewConnectorRequestV1','productboard': 'ProductboardNewConnectorRequestV1','qualaroo': 'QualarooNewConnectorRequestV1','qualtrics': 'QualtricsNewConnectorRequestV1','quickbooks': 'QuickbooksNewConnectorRequestV1','rakutenadvertising': 'RakutenadvertisingNewConnectorRequestV1','ramp': 'RampNewConnectorRequestV1','rarible': 'RaribleNewConnectorRequestV1','recharge': 'RechargeNewConnectorRequestV1','recurly': 'RecurlyNewConnectorRequestV1','reddit_ads': 'RedditAdsNewConnectorRequestV1','redshift_db': 'RedshiftDbNewConnectorRequestV1','reltio': 'ReltioNewConnectorRequestV1','replyio': 'ReplyioNewConnectorRequestV1','resource_management_by_smartsheet': 'ResourceManagementBySmartsheetNewConnectorRequestV1','retailnext': 'RetailnextNewConnectorRequestV1','retently': 'RetentlyNewConnectorRequestV1','revel': 'RevelNewConnectorRequestV1','revops': 'RevopsNewConnectorRequestV1','revx': 'RevxNewConnectorRequestV1','ringcentral': 'RingcentralNewConnectorRequestV1','ringover': 'RingoverNewConnectorRequestV1','rippling': 'RipplingNewConnectorRequestV1','rocketlane': 'RocketlaneNewConnectorRequestV1','rollbar': 'RollbarNewConnectorRequestV1','rootly': 'RootlyNewConnectorRequestV1','rtb_house': 'RtbHouseNewConnectorRequestV1','s3': 'S3NewConnectorRequestV1','safetyculture': 'SafetycultureNewConnectorRequestV1','sage_hr': 'SageHrNewConnectorRequestV1','sage_intacct': 'SageIntacctNewConnectorRequestV1','sailthru': 'SailthruNewConnectorRequestV1','salesforce': 'SalesforceNewConnectorRequestV1','salesforce_commerce_cloud': 'SalesforceCommerceCloudNewConnectorRequestV1','salesforce_marketing_cloud': 'SalesforceMarketingCloudNewConnectorRequestV1','salesforce_sandbox': 'SalesforceSandboxNewConnectorRequestV1','salesloft': 'SalesloftNewConnectorRequestV1','salsify': 'SalsifyNewConnectorRequestV1','samsara': 'SamsaraNewConnectorRequestV1','sap_business_by_design': 'SapBusinessByDesignNewConnectorRequestV1','sap_hana': 'SapHanaNewConnectorRequestV1','sap_hana_db': 'SapHanaDbNewConnectorRequestV1','sap_s4hana': 'SapS4hanaNewConnectorRequestV1','scorm': 'ScormNewConnectorRequestV1','security_journey': 'SecurityJourneyNewConnectorRequestV1','segment': 'SegmentNewConnectorRequestV1','sendgrid': 'SendgridNewConnectorRequestV1','sensor_tower': 'SensorTowerNewConnectorRequestV1','servicenow': 'ServicenowNewConnectorRequestV1','servicetitan': 'ServicetitanNewConnectorRequestV1','sftp': 'SftpNewConnectorRequestV1','share_point': 'SharePointNewConnectorRequestV1','shiphero': 'ShipheroNewConnectorRequestV1','shipstation': 'ShipstationNewConnectorRequestV1','shopify': 'ShopifyNewConnectorRequestV1','shopware': 'ShopwareNewConnectorRequestV1','shortcut': 'ShortcutNewConnectorRequestV1','shortio': 'ShortioNewConnectorRequestV1','simplecast': 'SimplecastNewConnectorRequestV1','simplesat': 'SimplesatNewConnectorRequestV1','skilljar': 'SkilljarNewConnectorRequestV1','skuvault': 'SkuvaultNewConnectorRequestV1','slab': 'SlabNewConnectorRequestV1','slack': 'SlackNewConnectorRequestV1','smadex': 'SmadexNewConnectorRequestV1','smartwaiver': 'SmartwaiverNewConnectorRequestV1','snapchat_ads': 'SnapchatAdsNewConnectorRequestV1','snowflake_db': 'SnowflakeDbNewConnectorRequestV1','snowplow': 'SnowplowNewConnectorRequestV1','sonarqube': 'SonarqubeNewConnectorRequestV1','splitio': 'SplitioNewConnectorRequestV1','splunk': 'SplunkNewConnectorRequestV1','spotify_ads': 'SpotifyAdsNewConnectorRequestV1','sprout': 'SproutNewConnectorRequestV1','sql_server': 'SqlServerNewConnectorRequestV1','sql_server_hva': 'SqlServerHvaNewConnectorRequestV1','sql_server_rds': 'SqlServerRdsNewConnectorRequestV1','sql_server_sap_ecc_hva': 'SqlServerSapEccHvaNewConnectorRequestV1','square': 'SquareNewConnectorRequestV1','squarespace': 'SquarespaceNewConnectorRequestV1','stackadapt': 'StackadaptNewConnectorRequestV1','standard_metrics': 'StandardMetricsNewConnectorRequestV1','statsig': 'StatsigNewConnectorRequestV1','statuspage': 'StatuspageNewConnectorRequestV1','stripe': 'StripeNewConnectorRequestV1','stripe_test': 'StripeTestNewConnectorRequestV1','stylight': 'StylightNewConnectorRequestV1','subscript': 'SubscriptNewConnectorRequestV1','survey_monkey': 'SurveyMonkeyNewConnectorRequestV1','survicate': 'SurvicateNewConnectorRequestV1','swoogo': 'SwoogoNewConnectorRequestV1','tableau_source': 'TableauSourceNewConnectorRequestV1','taboola': 'TaboolaNewConnectorRequestV1','talkdesk': 'TalkdeskNewConnectorRequestV1','talkwalker': 'TalkwalkerNewConnectorRequestV1','teamwork': 'TeamworkNewConnectorRequestV1','tempo': 'TempoNewConnectorRequestV1','the_trade_desk': 'TheTradeDeskNewConnectorRequestV1','thinkific': 'ThinkificNewConnectorRequestV1','tiktok_ads': 'TiktokAdsNewConnectorRequestV1','toggl_track': 'TogglTrackNewConnectorRequestV1','transcend': 'TranscendNewConnectorRequestV1','trello': 'TrelloNewConnectorRequestV1','trisolute': 'TrisoluteNewConnectorRequestV1','twilio': 'TwilioNewConnectorRequestV1','twitter': 'TwitterNewConnectorRequestV1','twitter_ads': 'TwitterAdsNewConnectorRequestV1','typeform': 'TypeformNewConnectorRequestV1','ukg_pro': 'UkgProNewConnectorRequestV1','unicommerce': 'UnicommerceNewConnectorRequestV1','upland': 'UplandNewConnectorRequestV1','uppromote': 'UppromoteNewConnectorRequestV1','uservoice': 'UservoiceNewConnectorRequestV1','vitally': 'VitallyNewConnectorRequestV1','vonage': 'VonageNewConnectorRequestV1','vts': 'VtsNewConnectorRequestV1','vwo': 'VwoNewConnectorRequestV1','wasabi_cloud_storage': 'WasabiCloudStorageNewConnectorRequestV1','webhooks': 'WebhooksNewConnectorRequestV1','when_i_work': 'WhenIWorkNewConnectorRequestV1','wherefour': 'WherefourNewConnectorRequestV1','woocommerce': 'WoocommerceNewConnectorRequestV1','wordpress': 'WordpressNewConnectorRequestV1','workable': 'WorkableNewConnectorRequestV1','workday': 'WorkdayNewConnectorRequestV1','workday_financial_management': 'WorkdayFinancialManagementNewConnectorRequestV1','workday_hcm': 'WorkdayHcmNewConnectorRequestV1','workday_strategic_sourcing': 'WorkdayStrategicSourcingNewConnectorRequestV1','workflowmax': 'WorkflowmaxNewConnectorRequestV1','workramp': 'WorkrampNewConnectorRequestV1','wrike': 'WrikeNewConnectorRequestV1','xero': 'XeroNewConnectorRequestV1','xray': 'XrayNewConnectorRequestV1','xsolla': 'XsollaNewConnectorRequestV1','yahoo_dsp': 'YahooDspNewConnectorRequestV1','yahoo_gemini': 'YahooGeminiNewConnectorRequestV1','yahoo_search_ads_yahoo_japan': 'YahooSearchAdsYahooJapanNewConnectorRequestV1','yotpo': 'YotpoNewConnectorRequestV1','youtube_analytics': 'YoutubeAnalyticsNewConnectorRequestV1','zendesk': 'ZendeskNewConnectorRequestV1','zendesk_chat': 'ZendeskChatNewConnectorRequestV1','zendesk_sell': 'ZendeskSellNewConnectorRequestV1','zendesk_sunshine': 'ZendeskSunshineNewConnectorRequestV1','zenefits': 'ZenefitsNewConnectorRequestV1','zoho_books': 'ZohoBooksNewConnectorRequestV1','zoho_campaigns': 'ZohoCampaignsNewConnectorRequestV1','zoho_crm': 'ZohoCrmNewConnectorRequestV1','zoho_desk': 'ZohoDeskNewConnectorRequestV1','zoom': 'ZoomNewConnectorRequestV1','zuora': 'ZuoraNewConnectorRequestV1','zuora_sandbox': 'ZuoraSandboxNewConnectorRequestV1'
    }

    @classmethod
    def get_discriminator_value(cls, obj: Dict[str, Any]) -> Optional[str]:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Union[Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self]]:
        """Create an instance of NewConnectorRequestV1 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of connect_card_config
        if self.connect_card_config:
            _dict['connect_card_config'] = self.connect_card_config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Optional[Union[Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self, Self]]:
        """Create an instance of NewConnectorRequestV1 from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type:
            klass = globals()[object_type]
            return klass.from_dict(obj)
        else:
            raise ValueError("NewConnectorRequestV1 failed to lookup discriminator value from " +
                             json.dumps(obj) + ". Discriminator property name: " + cls.__discriminator_property_name +
                             ", mapping: " + json.dumps(cls.__discriminator_value_class_map))

from openapi_client.models.activecampaign_new_connector_request_v1 import ActivecampaignNewConnectorRequestV1
from openapi_client.models.acumatica_new_connector_request_v1 import AcumaticaNewConnectorRequestV1
from openapi_client.models.ada_new_connector_request_v1 import AdaNewConnectorRequestV1
from openapi_client.models.adjust_new_connector_request_v1 import AdjustNewConnectorRequestV1
from openapi_client.models.adobe_analytics_data_feed_new_connector_request_v1 import AdobeAnalyticsDataFeedNewConnectorRequestV1
from openapi_client.models.adobe_analytics_new_connector_request_v1 import AdobeAnalyticsNewConnectorRequestV1
from openapi_client.models.adobe_commerce_new_connector_request_v1 import AdobeCommerceNewConnectorRequestV1
from openapi_client.models.adp_workforce_now_new_connector_request_v1 import AdpWorkforceNowNewConnectorRequestV1
from openapi_client.models.adroll_new_connector_request_v1 import AdrollNewConnectorRequestV1
from openapi_client.models.affinity_new_connector_request_v1 import AffinityNewConnectorRequestV1
from openapi_client.models.afterpay_new_connector_request_v1 import AfterpayNewConnectorRequestV1
from openapi_client.models.aha_new_connector_request_v1 import AhaNewConnectorRequestV1
from openapi_client.models.aircall_new_connector_request_v1 import AircallNewConnectorRequestV1
from openapi_client.models.airtable_new_connector_request_v1 import AirtableNewConnectorRequestV1
from openapi_client.models.alchemer_new_connector_request_v1 import AlchemerNewConnectorRequestV1
from openapi_client.models.algolia_new_connector_request_v1 import AlgoliaNewConnectorRequestV1
from openapi_client.models.amazon_ads_new_connector_request_v1 import AmazonAdsNewConnectorRequestV1
from openapi_client.models.amazon_attribution_new_connector_request_v1 import AmazonAttributionNewConnectorRequestV1
from openapi_client.models.amazon_selling_partner_new_connector_request_v1 import AmazonSellingPartnerNewConnectorRequestV1
from openapi_client.models.amplitude_new_connector_request_v1 import AmplitudeNewConnectorRequestV1
from openapi_client.models.anaplan_new_connector_request_v1 import AnaplanNewConnectorRequestV1
from openapi_client.models.apache_kafka_new_connector_request_v1 import ApacheKafkaNewConnectorRequestV1
from openapi_client.models.appcues_new_connector_request_v1 import AppcuesNewConnectorRequestV1
from openapi_client.models.appfigures_new_connector_request_v1 import AppfiguresNewConnectorRequestV1
from openapi_client.models.apple_search_ads_new_connector_request_v1 import AppleSearchAdsNewConnectorRequestV1
from openapi_client.models.appsflyer_new_connector_request_v1 import AppsflyerNewConnectorRequestV1
from openapi_client.models.asana_new_connector_request_v1 import AsanaNewConnectorRequestV1
from openapi_client.models.assembled_new_connector_request_v1 import AssembledNewConnectorRequestV1
from openapi_client.models.atlassian_jira_align_new_connector_request_v1 import AtlassianJiraAlignNewConnectorRequestV1
from openapi_client.models.atlassian_ops_genie_new_connector_request_v1 import AtlassianOpsGenieNewConnectorRequestV1
from openapi_client.models.attentive_new_connector_request_v1 import AttentiveNewConnectorRequestV1
from openapi_client.models.attio_new_connector_request_v1 import AttioNewConnectorRequestV1
from openapi_client.models.aumni_new_connector_request_v1 import AumniNewConnectorRequestV1
from openapi_client.models.aurora_new_connector_request_v1 import AuroraNewConnectorRequestV1
from openapi_client.models.aurora_postgres_new_connector_request_v1 import AuroraPostgresNewConnectorRequestV1
from openapi_client.models.auth0_new_connector_request_v1 import Auth0NewConnectorRequestV1
from openapi_client.models.autodesk_bim360_new_connector_request_v1 import AutodeskBim360NewConnectorRequestV1
from openapi_client.models.avantlink_new_connector_request_v1 import AvantlinkNewConnectorRequestV1
from openapi_client.models.awin_new_connector_request_v1 import AwinNewConnectorRequestV1
from openapi_client.models.aws_cloudtrail_new_connector_request_v1 import AwsCloudtrailNewConnectorRequestV1
from openapi_client.models.aws_cost_new_connector_request_v1 import AwsCostNewConnectorRequestV1
from openapi_client.models.aws_inventory_new_connector_request_v1 import AwsInventoryNewConnectorRequestV1
from openapi_client.models.aws_lambda_new_connector_request_v1 import AwsLambdaNewConnectorRequestV1
from openapi_client.models.aws_msk_new_connector_request_v1 import AwsMskNewConnectorRequestV1
from openapi_client.models.azure_blob_storage_new_connector_request_v1 import AzureBlobStorageNewConnectorRequestV1
from openapi_client.models.azure_boards_new_connector_request_v1 import AzureBoardsNewConnectorRequestV1
from openapi_client.models.azure_devops_new_connector_request_v1 import AzureDevopsNewConnectorRequestV1
from openapi_client.models.azure_event_hub_new_connector_request_v1 import AzureEventHubNewConnectorRequestV1
from openapi_client.models.azure_function_new_connector_request_v1 import AzureFunctionNewConnectorRequestV1
from openapi_client.models.azure_postgres_new_connector_request_v1 import AzurePostgresNewConnectorRequestV1
from openapi_client.models.azure_service_bus_new_connector_request_v1 import AzureServiceBusNewConnectorRequestV1
from openapi_client.models.azure_sql_db_new_connector_request_v1 import AzureSqlDbNewConnectorRequestV1
from openapi_client.models.azure_sql_managed_db_new_connector_request_v1 import AzureSqlManagedDbNewConnectorRequestV1
from openapi_client.models.ballotready_new_connector_request_v1 import BallotreadyNewConnectorRequestV1
from openapi_client.models.bamboohr_new_connector_request_v1 import BamboohrNewConnectorRequestV1
from openapi_client.models.big_commerce_new_connector_request_v1 import BigCommerceNewConnectorRequestV1
from openapi_client.models.bigquery_db_new_connector_request_v1 import BigqueryDbNewConnectorRequestV1
from openapi_client.models.billing_platform_new_connector_request_v1 import BillingPlatformNewConnectorRequestV1
from openapi_client.models.bingads_new_connector_request_v1 import BingadsNewConnectorRequestV1
from openapi_client.models.birdeye_new_connector_request_v1 import BirdeyeNewConnectorRequestV1
from openapi_client.models.bitly_new_connector_request_v1 import BitlyNewConnectorRequestV1
from openapi_client.models.box_new_connector_request_v1 import BoxNewConnectorRequestV1
from openapi_client.models.braintree_new_connector_request_v1 import BraintreeNewConnectorRequestV1
from openapi_client.models.braintree_sandbox_new_connector_request_v1 import BraintreeSandboxNewConnectorRequestV1
from openapi_client.models.branch_new_connector_request_v1 import BranchNewConnectorRequestV1
from openapi_client.models.braze_new_connector_request_v1 import BrazeNewConnectorRequestV1
from openapi_client.models.brevo_new_connector_request_v1 import BrevoNewConnectorRequestV1
from openapi_client.models.brex_new_connector_request_v1 import BrexNewConnectorRequestV1
from openapi_client.models.buildkite_new_connector_request_v1 import BuildkiteNewConnectorRequestV1
from openapi_client.models.business_central_new_connector_request_v1 import BusinessCentralNewConnectorRequestV1
from openapi_client.models.buzzsprout_new_connector_request_v1 import BuzzsproutNewConnectorRequestV1
from openapi_client.models.calabrio_new_connector_request_v1 import CalabrioNewConnectorRequestV1
from openapi_client.models.calendly_new_connector_request_v1 import CalendlyNewConnectorRequestV1
from openapi_client.models.campaignmonitor_new_connector_request_v1 import CampaignmonitorNewConnectorRequestV1
from openapi_client.models.canny_new_connector_request_v1 import CannyNewConnectorRequestV1
from openapi_client.models.care_quality_commission_new_connector_request_v1 import CareQualityCommissionNewConnectorRequestV1
from openapi_client.models.castor_edc_new_connector_request_v1 import CastorEdcNewConnectorRequestV1
from openapi_client.models.ceridian_dayforce_new_connector_request_v1 import CeridianDayforceNewConnectorRequestV1
from openapi_client.models.channel_advisor_new_connector_request_v1 import ChannelAdvisorNewConnectorRequestV1
from openapi_client.models.chargebee_product_catalog1_new_connector_request_v1 import ChargebeeProductCatalog1NewConnectorRequestV1
from openapi_client.models.chargebee_product_catalog2_new_connector_request_v1 import ChargebeeProductCatalog2NewConnectorRequestV1
from openapi_client.models.chargedesk_new_connector_request_v1 import ChargedeskNewConnectorRequestV1
from openapi_client.models.chartmogul_new_connector_request_v1 import ChartmogulNewConnectorRequestV1
from openapi_client.models.checkout_new_connector_request_v1 import CheckoutNewConnectorRequestV1
from openapi_client.models.checkr_new_connector_request_v1 import CheckrNewConnectorRequestV1
from openapi_client.models.chorusai_new_connector_request_v1 import ChorusaiNewConnectorRequestV1
from openapi_client.models.churnkey_new_connector_request_v1 import ChurnkeyNewConnectorRequestV1
from openapi_client.models.churnzero_new_connector_request_v1 import ChurnzeroNewConnectorRequestV1
from openapi_client.models.cimis_new_connector_request_v1 import CimisNewConnectorRequestV1
from openapi_client.models.cin7_new_connector_request_v1 import Cin7NewConnectorRequestV1
from openapi_client.models.circleci_new_connector_request_v1 import CircleciNewConnectorRequestV1
from openapi_client.models.cj_commission_detail_new_connector_request_v1 import CjCommissionDetailNewConnectorRequestV1
from openapi_client.models.clari_new_connector_request_v1 import ClariNewConnectorRequestV1
from openapi_client.models.clickup_new_connector_request_v1 import ClickupNewConnectorRequestV1
from openapi_client.models.close_new_connector_request_v1 import CloseNewConnectorRequestV1
from openapi_client.models.cloudfront_new_connector_request_v1 import CloudfrontNewConnectorRequestV1
from openapi_client.models.coassemble_new_connector_request_v1 import CoassembleNewConnectorRequestV1
from openapi_client.models.codefresh_new_connector_request_v1 import CodefreshNewConnectorRequestV1
from openapi_client.models.collibra_new_connector_request_v1 import CollibraNewConnectorRequestV1
from openapi_client.models.column_new_connector_request_v1 import ColumnNewConnectorRequestV1
from openapi_client.models.concord_new_connector_request_v1 import ConcordNewConnectorRequestV1
from openapi_client.models.concur_new_connector_request_v1 import ConcurNewConnectorRequestV1
from openapi_client.models.confluence_new_connector_request_v1 import ConfluenceNewConnectorRequestV1
from openapi_client.models.confluent_cloud_new_connector_request_v1 import ConfluentCloudNewConnectorRequestV1
from openapi_client.models.contrast_security_new_connector_request_v1 import ContrastSecurityNewConnectorRequestV1
from openapi_client.models.convex_new_connector_request_v1 import ConvexNewConnectorRequestV1
from openapi_client.models.copper_new_connector_request_v1 import CopperNewConnectorRequestV1
from openapi_client.models.cosmos_new_connector_request_v1 import CosmosNewConnectorRequestV1
from openapi_client.models.coupa_new_connector_request_v1 import CoupaNewConnectorRequestV1
from openapi_client.models.criteo_new_connector_request_v1 import CriteoNewConnectorRequestV1
from openapi_client.models.crossbeam_new_connector_request_v1 import CrossbeamNewConnectorRequestV1
from openapi_client.models.crowddev_new_connector_request_v1 import CrowddevNewConnectorRequestV1
from openapi_client.models.customerio_new_connector_request_v1 import CustomerioNewConnectorRequestV1
from openapi_client.models.cvent_new_connector_request_v1 import CventNewConnectorRequestV1
from openapi_client.models.d2l_brightspace_new_connector_request_v1 import D2lBrightspaceNewConnectorRequestV1
from openapi_client.models.db2_new_connector_request_v1 import Db2NewConnectorRequestV1
from openapi_client.models.db2i_hva_new_connector_request_v1 import Db2iHvaNewConnectorRequestV1
from openapi_client.models.db2i_sap_hva_new_connector_request_v1 import Db2iSapHvaNewConnectorRequestV1
from openapi_client.models.dbt_cloud_new_connector_request_v1 import DbtCloudNewConnectorRequestV1
from openapi_client.models.dcl_logistics_new_connector_request_v1 import DclLogisticsNewConnectorRequestV1
from openapi_client.models.dear_new_connector_request_v1 import DearNewConnectorRequestV1
from openapi_client.models.delighted_new_connector_request_v1 import DelightedNewConnectorRequestV1
from openapi_client.models.deputy_new_connector_request_v1 import DeputyNewConnectorRequestV1
from openapi_client.models.destini_new_connector_request_v1 import DestiniNewConnectorRequestV1
from openapi_client.models.dixa_new_connector_request_v1 import DixaNewConnectorRequestV1
from openapi_client.models.docebo_new_connector_request_v1 import DoceboNewConnectorRequestV1
from openapi_client.models.documentdb_new_connector_request_v1 import DocumentdbNewConnectorRequestV1
from openapi_client.models.double_click_campaign_manager_new_connector_request_v1 import DoubleClickCampaignManagerNewConnectorRequestV1
from openapi_client.models.double_click_publishers_new_connector_request_v1 import DoubleClickPublishersNewConnectorRequestV1
from openapi_client.models.drata_new_connector_request_v1 import DrataNewConnectorRequestV1
from openapi_client.models.drift_new_connector_request_v1 import DriftNewConnectorRequestV1
from openapi_client.models.drip_new_connector_request_v1 import DripNewConnectorRequestV1
from openapi_client.models.dropbox_new_connector_request_v1 import DropboxNewConnectorRequestV1
from openapi_client.models.dropbox_sign_new_connector_request_v1 import DropboxSignNewConnectorRequestV1
from openapi_client.models.dsv_new_connector_request_v1 import DsvNewConnectorRequestV1
from openapi_client.models.dynamics365_fo_new_connector_request_v1 import Dynamics365FoNewConnectorRequestV1
from openapi_client.models.dynamics365_new_connector_request_v1 import Dynamics365NewConnectorRequestV1
from openapi_client.models.dynamodb_new_connector_request_v1 import DynamodbNewConnectorRequestV1
from openapi_client.models.easypost_new_connector_request_v1 import EasypostNewConnectorRequestV1
from openapi_client.models.economic_new_connector_request_v1 import EconomicNewConnectorRequestV1
from openapi_client.models.elastic_cloud_new_connector_request_v1 import ElasticCloudNewConnectorRequestV1
from openapi_client.models.eloqua_new_connector_request_v1 import EloquaNewConnectorRequestV1
from openapi_client.models.email_new_connector_request_v1 import EmailNewConnectorRequestV1
from openapi_client.models.employment_hero_new_connector_request_v1 import EmploymentHeroNewConnectorRequestV1
from openapi_client.models.es_self_hosted_new_connector_request_v1 import EsSelfHostedNewConnectorRequestV1
from openapi_client.models.eventbrite_new_connector_request_v1 import EventbriteNewConnectorRequestV1
from openapi_client.models.everhour_new_connector_request_v1 import EverhourNewConnectorRequestV1
from openapi_client.models.expensify_new_connector_request_v1 import ExpensifyNewConnectorRequestV1
from openapi_client.models.ezofficeinventory_new_connector_request_v1 import EzofficeinventoryNewConnectorRequestV1
from openapi_client.models.facebook_ads_new_connector_request_v1 import FacebookAdsNewConnectorRequestV1
from openapi_client.models.facebook_pages_new_connector_request_v1 import FacebookPagesNewConnectorRequestV1
from openapi_client.models.factorial_new_connector_request_v1 import FactorialNewConnectorRequestV1
from openapi_client.models.financial_force_new_connector_request_v1 import FinancialForceNewConnectorRequestV1
from openapi_client.models.firebase_new_connector_request_v1 import FirebaseNewConnectorRequestV1
from openapi_client.models.fivetran_log_new_connector_request_v1 import FivetranLogNewConnectorRequestV1
from openapi_client.models.flexport_new_connector_request_v1 import FlexportNewConnectorRequestV1
from openapi_client.models.float_new_connector_request_v1 import FloatNewConnectorRequestV1
from openapi_client.models.fone_dynamics_new_connector_request_v1 import FoneDynamicsNewConnectorRequestV1
from openapi_client.models.forj_community_new_connector_request_v1 import ForjCommunityNewConnectorRequestV1
from openapi_client.models.fountain_new_connector_request_v1 import FountainNewConnectorRequestV1
from openapi_client.models.freightview_new_connector_request_v1 import FreightviewNewConnectorRequestV1
from openapi_client.models.freshbooks_new_connector_request_v1 import FreshbooksNewConnectorRequestV1
from openapi_client.models.freshchat_new_connector_request_v1 import FreshchatNewConnectorRequestV1
from openapi_client.models.freshdesk_new_connector_request_v1 import FreshdeskNewConnectorRequestV1
from openapi_client.models.freshservice_new_connector_request_v1 import FreshserviceNewConnectorRequestV1
from openapi_client.models.freshteam_new_connector_request_v1 import FreshteamNewConnectorRequestV1
from openapi_client.models.friendbuy_new_connector_request_v1 import FriendbuyNewConnectorRequestV1
from openapi_client.models.front_new_connector_request_v1 import FrontNewConnectorRequestV1
from openapi_client.models.ftp_new_connector_request_v1 import FtpNewConnectorRequestV1
from openapi_client.models.fullstory_new_connector_request_v1 import FullstoryNewConnectorRequestV1
from openapi_client.models.gainsight_customer_success_new_connector_request_v1 import GainsightCustomerSuccessNewConnectorRequestV1
from openapi_client.models.gcs_new_connector_request_v1 import GcsNewConnectorRequestV1
from openapi_client.models.gem_new_connector_request_v1 import GemNewConnectorRequestV1
from openapi_client.models.getfeedback_new_connector_request_v1 import GetfeedbackNewConnectorRequestV1
from openapi_client.models.github_new_connector_request_v1 import GithubNewConnectorRequestV1
from openapi_client.models.gitlab_new_connector_request_v1 import GitlabNewConnectorRequestV1
from openapi_client.models.gladly_new_connector_request_v1 import GladlyNewConnectorRequestV1
from openapi_client.models.globalmeet_new_connector_request_v1 import GlobalmeetNewConnectorRequestV1
from openapi_client.models.gocardless_new_connector_request_v1 import GocardlessNewConnectorRequestV1
from openapi_client.models.gongio_new_connector_request_v1 import GongioNewConnectorRequestV1
from openapi_client.models.google_ads_new_connector_request_v1 import GoogleAdsNewConnectorRequestV1
from openapi_client.models.google_analytics360_new_connector_request_v1 import GoogleAnalytics360NewConnectorRequestV1
from openapi_client.models.google_analytics4_export_new_connector_request_v1 import GoogleAnalytics4ExportNewConnectorRequestV1
from openapi_client.models.google_analytics4_new_connector_request_v1 import GoogleAnalytics4NewConnectorRequestV1
from openapi_client.models.google_analytics_mcf_new_connector_request_v1 import GoogleAnalyticsMcfNewConnectorRequestV1
from openapi_client.models.google_analytics_new_connector_request_v1 import GoogleAnalyticsNewConnectorRequestV1
from openapi_client.models.google_business_profile_new_connector_request_v1 import GoogleBusinessProfileNewConnectorRequestV1
from openapi_client.models.google_calendar_new_connector_request_v1 import GoogleCalendarNewConnectorRequestV1
from openapi_client.models.google_cloud_function_new_connector_request_v1 import GoogleCloudFunctionNewConnectorRequestV1
from openapi_client.models.google_cloud_mysql_new_connector_request_v1 import GoogleCloudMysqlNewConnectorRequestV1
from openapi_client.models.google_cloud_postgresql_new_connector_request_v1 import GoogleCloudPostgresqlNewConnectorRequestV1
from openapi_client.models.google_cloud_sqlserver_new_connector_request_v1 import GoogleCloudSqlserverNewConnectorRequestV1
from openapi_client.models.google_display_and_video360_new_connector_request_v1 import GoogleDisplayAndVideo360NewConnectorRequestV1
from openapi_client.models.google_drive_new_connector_request_v1 import GoogleDriveNewConnectorRequestV1
from openapi_client.models.google_play_new_connector_request_v1 import GooglePlayNewConnectorRequestV1
from openapi_client.models.google_search_ads360_new_connector_request_v1 import GoogleSearchAds360NewConnectorRequestV1
from openapi_client.models.google_search_console_new_connector_request_v1 import GoogleSearchConsoleNewConnectorRequestV1
from openapi_client.models.google_sheets_new_connector_request_v1 import GoogleSheetsNewConnectorRequestV1
from openapi_client.models.gorgias_new_connector_request_v1 import GorgiasNewConnectorRequestV1
from openapi_client.models.green_power_monitor_new_connector_request_v1 import GreenPowerMonitorNewConnectorRequestV1
from openapi_client.models.greenhouse_new_connector_request_v1 import GreenhouseNewConnectorRequestV1
from openapi_client.models.grepsr_new_connector_request_v1 import GrepsrNewConnectorRequestV1
from openapi_client.models.grin_new_connector_request_v1 import GrinNewConnectorRequestV1
from openapi_client.models.guru_new_connector_request_v1 import GuruNewConnectorRequestV1
from openapi_client.models.hana_sap_hva_b1_new_connector_request_v1 import HanaSapHvaB1NewConnectorRequestV1
from openapi_client.models.hana_sap_hva_ecc_netweaver_new_connector_request_v1 import HanaSapHvaEccNetweaverNewConnectorRequestV1
from openapi_client.models.hana_sap_hva_ecc_new_connector_request_v1 import HanaSapHvaEccNewConnectorRequestV1
from openapi_client.models.hana_sap_hva_s4_netweaver_new_connector_request_v1 import HanaSapHvaS4NetweaverNewConnectorRequestV1
from openapi_client.models.hana_sap_hva_s4_new_connector_request_v1 import HanaSapHvaS4NewConnectorRequestV1
from openapi_client.models.happyfox_new_connector_request_v1 import HappyfoxNewConnectorRequestV1
from openapi_client.models.harvest_new_connector_request_v1 import HarvestNewConnectorRequestV1
from openapi_client.models.heap_new_connector_request_v1 import HeapNewConnectorRequestV1
from openapi_client.models.height_new_connector_request_v1 import HeightNewConnectorRequestV1
from openapi_client.models.helpscout_new_connector_request_v1 import HelpscoutNewConnectorRequestV1
from openapi_client.models.helpshift_new_connector_request_v1 import HelpshiftNewConnectorRequestV1
from openapi_client.models.heroku_kafka_new_connector_request_v1 import HerokuKafkaNewConnectorRequestV1
from openapi_client.models.heroku_postgres_new_connector_request_v1 import HerokuPostgresNewConnectorRequestV1
from openapi_client.models.hibob_new_connector_request_v1 import HibobNewConnectorRequestV1
from openapi_client.models.hopin_new_connector_request_v1 import HopinNewConnectorRequestV1
from openapi_client.models.hubspot_new_connector_request_v1 import HubspotNewConnectorRequestV1
from openapi_client.models.ilevel_new_connector_request_v1 import IlevelNewConnectorRequestV1
from openapi_client.models.impact_new_connector_request_v1 import ImpactNewConnectorRequestV1
from openapi_client.models.incidentio_new_connector_request_v1 import IncidentioNewConnectorRequestV1
from openapi_client.models.infobip_new_connector_request_v1 import InfobipNewConnectorRequestV1
from openapi_client.models.insightly_new_connector_request_v1 import InsightlyNewConnectorRequestV1
from openapi_client.models.instagram_business_new_connector_request_v1 import InstagramBusinessNewConnectorRequestV1
from openapi_client.models.integral_ad_science_new_connector_request_v1 import IntegralAdScienceNewConnectorRequestV1
from openapi_client.models.integrate_new_connector_request_v1 import IntegrateNewConnectorRequestV1
from openapi_client.models.intercom_new_connector_request_v1 import IntercomNewConnectorRequestV1
from openapi_client.models.ironclad_new_connector_request_v1 import IroncladNewConnectorRequestV1
from openapi_client.models.ironsource_new_connector_request_v1 import IronsourceNewConnectorRequestV1
from openapi_client.models.iterable_new_connector_request_v1 import IterableNewConnectorRequestV1
from openapi_client.models.itunes_connect_new_connector_request_v1 import ItunesConnectNewConnectorRequestV1
from openapi_client.models.ivanti_new_connector_request_v1 import IvantiNewConnectorRequestV1
from openapi_client.models.jira_new_connector_request_v1 import JiraNewConnectorRequestV1
from openapi_client.models.jotform_new_connector_request_v1 import JotformNewConnectorRequestV1
from openapi_client.models.justcall_new_connector_request_v1 import JustcallNewConnectorRequestV1
from openapi_client.models.kandji_new_connector_request_v1 import KandjiNewConnectorRequestV1
from openapi_client.models.katana_new_connector_request_v1 import KatanaNewConnectorRequestV1
from openapi_client.models.keypay_new_connector_request_v1 import KeypayNewConnectorRequestV1
from openapi_client.models.khoros_care_new_connector_request_v1 import KhorosCareNewConnectorRequestV1
from openapi_client.models.kinesis_new_connector_request_v1 import KinesisNewConnectorRequestV1
from openapi_client.models.kissmetrics_new_connector_request_v1 import KissmetricsNewConnectorRequestV1
from openapi_client.models.klarna_new_connector_request_v1 import KlarnaNewConnectorRequestV1
from openapi_client.models.klaviyo_new_connector_request_v1 import KlaviyoNewConnectorRequestV1
from openapi_client.models.konnect_insights_new_connector_request_v1 import KonnectInsightsNewConnectorRequestV1
from openapi_client.models.kustomer_new_connector_request_v1 import KustomerNewConnectorRequestV1
from openapi_client.models.lattice_new_connector_request_v1 import LatticeNewConnectorRequestV1
from openapi_client.models.launchdarkly_new_connector_request_v1 import LaunchdarklyNewConnectorRequestV1
from openapi_client.models.learnupon_new_connector_request_v1 import LearnuponNewConnectorRequestV1
from openapi_client.models.lessonly_new_connector_request_v1 import LessonlyNewConnectorRequestV1
from openapi_client.models.lever_new_connector_request_v1 import LeverNewConnectorRequestV1
from openapi_client.models.liftoff_new_connector_request_v1 import LiftoffNewConnectorRequestV1
from openapi_client.models.light_speed_retail_new_connector_request_v1 import LightSpeedRetailNewConnectorRequestV1
from openapi_client.models.linear_new_connector_request_v1 import LinearNewConnectorRequestV1
from openapi_client.models.linkedin_ads_new_connector_request_v1 import LinkedinAdsNewConnectorRequestV1
from openapi_client.models.linkedin_company_pages_new_connector_request_v1 import LinkedinCompanyPagesNewConnectorRequestV1
from openapi_client.models.linksquares_new_connector_request_v1 import LinksquaresNewConnectorRequestV1
from openapi_client.models.livechat_new_connector_request_v1 import LivechatNewConnectorRequestV1
from openapi_client.models.lob_new_connector_request_v1 import LobNewConnectorRequestV1
from openapi_client.models.looker_source_new_connector_request_v1 import LookerSourceNewConnectorRequestV1
from openapi_client.models.loop_new_connector_request_v1 import LoopNewConnectorRequestV1
from openapi_client.models.loopio_new_connector_request_v1 import LoopioNewConnectorRequestV1
from openapi_client.models.luma_new_connector_request_v1 import LumaNewConnectorRequestV1
from openapi_client.models.magento_mysql_new_connector_request_v1 import MagentoMysqlNewConnectorRequestV1
from openapi_client.models.magento_mysql_rds_new_connector_request_v1 import MagentoMysqlRdsNewConnectorRequestV1
from openapi_client.models.mailchimp_new_connector_request_v1 import MailchimpNewConnectorRequestV1
from openapi_client.models.mailgun_new_connector_request_v1 import MailgunNewConnectorRequestV1
from openapi_client.models.mandrill_new_connector_request_v1 import MandrillNewConnectorRequestV1
from openapi_client.models.maria_azure_new_connector_request_v1 import MariaAzureNewConnectorRequestV1
from openapi_client.models.maria_new_connector_request_v1 import MariaNewConnectorRequestV1
from openapi_client.models.maria_rds_new_connector_request_v1 import MariaRdsNewConnectorRequestV1
from openapi_client.models.marin_new_connector_request_v1 import MarinNewConnectorRequestV1
from openapi_client.models.marketo_new_connector_request_v1 import MarketoNewConnectorRequestV1
from openapi_client.models.mavenlink_new_connector_request_v1 import MavenlinkNewConnectorRequestV1
from openapi_client.models.maxio_chargify_new_connector_request_v1 import MaxioChargifyNewConnectorRequestV1
from openapi_client.models.maxio_saasoptics_new_connector_request_v1 import MaxioSaasopticsNewConnectorRequestV1
from openapi_client.models.medallia_new_connector_request_v1 import MedalliaNewConnectorRequestV1
from openapi_client.models.megaphone_new_connector_request_v1 import MegaphoneNewConnectorRequestV1
from openapi_client.models.meltwater_new_connector_request_v1 import MeltwaterNewConnectorRequestV1
from openapi_client.models.mention_new_connector_request_v1 import MentionNewConnectorRequestV1
from openapi_client.models.microsoft_dynamics365_fo_new_connector_request_v1 import MicrosoftDynamics365FoNewConnectorRequestV1
from openapi_client.models.microsoft_lists_new_connector_request_v1 import MicrosoftListsNewConnectorRequestV1
from openapi_client.models.microsoft_teams_new_connector_request_v1 import MicrosoftTeamsNewConnectorRequestV1
from openapi_client.models.mixmax_new_connector_request_v1 import MixmaxNewConnectorRequestV1
from openapi_client.models.mixpanel_new_connector_request_v1 import MixpanelNewConnectorRequestV1
from openapi_client.models.mode_new_connector_request_v1 import ModeNewConnectorRequestV1
from openapi_client.models.model15five_new_connector_request_v1 import Model15fiveNewConnectorRequestV1
from openapi_client.models.model360learning_new_connector_request_v1 import Model360learningNewConnectorRequestV1
from openapi_client.models.model6sense_new_connector_request_v1 import Model6senseNewConnectorRequestV1
from openapi_client.models.moloco_new_connector_request_v1 import MolocoNewConnectorRequestV1
from openapi_client.models.monday_new_connector_request_v1 import MondayNewConnectorRequestV1
from openapi_client.models.mongo_new_connector_request_v1 import MongoNewConnectorRequestV1
from openapi_client.models.mongo_sharded_new_connector_request_v1 import MongoShardedNewConnectorRequestV1
from openapi_client.models.mountain_new_connector_request_v1 import MountainNewConnectorRequestV1
from openapi_client.models.mux_new_connector_request_v1 import MuxNewConnectorRequestV1
from openapi_client.models.mysql_azure_new_connector_request_v1 import MysqlAzureNewConnectorRequestV1
from openapi_client.models.mysql_new_connector_request_v1 import MysqlNewConnectorRequestV1
from openapi_client.models.mysql_rds_new_connector_request_v1 import MysqlRdsNewConnectorRequestV1
from openapi_client.models.namely_new_connector_request_v1 import NamelyNewConnectorRequestV1
from openapi_client.models.navan_new_connector_request_v1 import NavanNewConnectorRequestV1
from openapi_client.models.netsuite_suiteanalytics_new_connector_request_v1 import NetsuiteSuiteanalyticsNewConnectorRequestV1
from openapi_client.models.notion_new_connector_request_v1 import NotionNewConnectorRequestV1
from openapi_client.models.nylas_new_connector_request_v1 import NylasNewConnectorRequestV1
from openapi_client.models.okta_new_connector_request_v1 import OktaNewConnectorRequestV1
from openapi_client.models.ometria_new_connector_request_v1 import OmetriaNewConnectorRequestV1
from openapi_client.models.one_drive_new_connector_request_v1 import OneDriveNewConnectorRequestV1
from openapi_client.models.open_exchange_rates_new_connector_request_v1 import OpenExchangeRatesNewConnectorRequestV1
from openapi_client.models.opendistro_new_connector_request_v1 import OpendistroNewConnectorRequestV1
from openapi_client.models.opensearch_new_connector_request_v1 import OpensearchNewConnectorRequestV1
from openapi_client.models.optimizely_new_connector_request_v1 import OptimizelyNewConnectorRequestV1
from openapi_client.models.oracle_business_intelligence_publisher_new_connector_request_v1 import OracleBusinessIntelligencePublisherNewConnectorRequestV1
from openapi_client.models.oracle_ebs_new_connector_request_v1 import OracleEbsNewConnectorRequestV1
from openapi_client.models.oracle_fusion_cloud_apps_crm_new_connector_request_v1 import OracleFusionCloudAppsCrmNewConnectorRequestV1
from openapi_client.models.oracle_fusion_cloud_apps_fscm_new_connector_request_v1 import OracleFusionCloudAppsFscmNewConnectorRequestV1
from openapi_client.models.oracle_fusion_cloud_apps_hcm_new_connector_request_v1 import OracleFusionCloudAppsHcmNewConnectorRequestV1
from openapi_client.models.oracle_hva_new_connector_request_v1 import OracleHvaNewConnectorRequestV1
from openapi_client.models.oracle_moat_analytics_new_connector_request_v1 import OracleMoatAnalyticsNewConnectorRequestV1
from openapi_client.models.oracle_new_connector_request_v1 import OracleNewConnectorRequestV1
from openapi_client.models.oracle_rac_new_connector_request_v1 import OracleRacNewConnectorRequestV1
from openapi_client.models.oracle_rds_new_connector_request_v1 import OracleRdsNewConnectorRequestV1
from openapi_client.models.oracle_sap_hva_netweaver_new_connector_request_v1 import OracleSapHvaNetweaverNewConnectorRequestV1
from openapi_client.models.oracle_sap_hva_new_connector_request_v1 import OracleSapHvaNewConnectorRequestV1
from openapi_client.models.orbit_new_connector_request_v1 import OrbitNewConnectorRequestV1
from openapi_client.models.ordway_new_connector_request_v1 import OrdwayNewConnectorRequestV1
from openapi_client.models.ortto_new_connector_request_v1 import OrttoNewConnectorRequestV1
from openapi_client.models.outbrain_new_connector_request_v1 import OutbrainNewConnectorRequestV1
from openapi_client.models.outreach_new_connector_request_v1 import OutreachNewConnectorRequestV1
from openapi_client.models.pagerduty_new_connector_request_v1 import PagerdutyNewConnectorRequestV1
from openapi_client.models.papershift_new_connector_request_v1 import PapershiftNewConnectorRequestV1
from openapi_client.models.pardot_new_connector_request_v1 import PardotNewConnectorRequestV1
from openapi_client.models.partnerstack_vendor_new_connector_request_v1 import PartnerstackVendorNewConnectorRequestV1
from openapi_client.models.paychex_new_connector_request_v1 import PaychexNewConnectorRequestV1
from openapi_client.models.paypal_new_connector_request_v1 import PaypalNewConnectorRequestV1
from openapi_client.models.paypal_sandbox_new_connector_request_v1 import PaypalSandboxNewConnectorRequestV1
from openapi_client.models.pendo_new_connector_request_v1 import PendoNewConnectorRequestV1
from openapi_client.models.persona_new_connector_request_v1 import PersonaNewConnectorRequestV1
from openapi_client.models.personio_new_connector_request_v1 import PersonioNewConnectorRequestV1
from openapi_client.models.pingdom_new_connector_request_v1 import PingdomNewConnectorRequestV1
from openapi_client.models.pinpoint_new_connector_request_v1 import PinpointNewConnectorRequestV1
from openapi_client.models.pinterest_ads_new_connector_request_v1 import PinterestAdsNewConnectorRequestV1
from openapi_client.models.pinterest_organic_new_connector_request_v1 import PinterestOrganicNewConnectorRequestV1
from openapi_client.models.pipe17_new_connector_request_v1 import Pipe17NewConnectorRequestV1
from openapi_client.models.pipedrive_new_connector_request_v1 import PipedriveNewConnectorRequestV1
from openapi_client.models.pivotal_tracker_new_connector_request_v1 import PivotalTrackerNewConnectorRequestV1
from openapi_client.models.piwik_pro_new_connector_request_v1 import PiwikProNewConnectorRequestV1
from openapi_client.models.planetscale_new_connector_request_v1 import PlanetscaleNewConnectorRequestV1
from openapi_client.models.playvox_new_connector_request_v1 import PlayvoxNewConnectorRequestV1
from openapi_client.models.postgres_new_connector_request_v1 import PostgresNewConnectorRequestV1
from openapi_client.models.postgres_rds_new_connector_request_v1 import PostgresRdsNewConnectorRequestV1
from openapi_client.models.posthog_new_connector_request_v1 import PosthogNewConnectorRequestV1
from openapi_client.models.postmark_new_connector_request_v1 import PostmarkNewConnectorRequestV1
from openapi_client.models.power_reviews_enterprise_new_connector_request_v1 import PowerReviewsEnterpriseNewConnectorRequestV1
from openapi_client.models.prive_new_connector_request_v1 import PriveNewConnectorRequestV1
from openapi_client.models.productboard_new_connector_request_v1 import ProductboardNewConnectorRequestV1
from openapi_client.models.qualaroo_new_connector_request_v1 import QualarooNewConnectorRequestV1
from openapi_client.models.qualtrics_new_connector_request_v1 import QualtricsNewConnectorRequestV1
from openapi_client.models.quickbooks_new_connector_request_v1 import QuickbooksNewConnectorRequestV1
from openapi_client.models.rakutenadvertising_new_connector_request_v1 import RakutenadvertisingNewConnectorRequestV1
from openapi_client.models.ramp_new_connector_request_v1 import RampNewConnectorRequestV1
from openapi_client.models.rarible_new_connector_request_v1 import RaribleNewConnectorRequestV1
from openapi_client.models.recharge_new_connector_request_v1 import RechargeNewConnectorRequestV1
from openapi_client.models.recurly_new_connector_request_v1 import RecurlyNewConnectorRequestV1
from openapi_client.models.reddit_ads_new_connector_request_v1 import RedditAdsNewConnectorRequestV1
from openapi_client.models.redshift_db_new_connector_request_v1 import RedshiftDbNewConnectorRequestV1
from openapi_client.models.reltio_new_connector_request_v1 import ReltioNewConnectorRequestV1
from openapi_client.models.replyio_new_connector_request_v1 import ReplyioNewConnectorRequestV1
from openapi_client.models.resource_management_by_smartsheet_new_connector_request_v1 import ResourceManagementBySmartsheetNewConnectorRequestV1
from openapi_client.models.retailnext_new_connector_request_v1 import RetailnextNewConnectorRequestV1
from openapi_client.models.retently_new_connector_request_v1 import RetentlyNewConnectorRequestV1
from openapi_client.models.revel_new_connector_request_v1 import RevelNewConnectorRequestV1
from openapi_client.models.revops_new_connector_request_v1 import RevopsNewConnectorRequestV1
from openapi_client.models.revx_new_connector_request_v1 import RevxNewConnectorRequestV1
from openapi_client.models.ringcentral_new_connector_request_v1 import RingcentralNewConnectorRequestV1
from openapi_client.models.ringover_new_connector_request_v1 import RingoverNewConnectorRequestV1
from openapi_client.models.rippling_new_connector_request_v1 import RipplingNewConnectorRequestV1
from openapi_client.models.rocketlane_new_connector_request_v1 import RocketlaneNewConnectorRequestV1
from openapi_client.models.rollbar_new_connector_request_v1 import RollbarNewConnectorRequestV1
from openapi_client.models.rootly_new_connector_request_v1 import RootlyNewConnectorRequestV1
from openapi_client.models.rtb_house_new_connector_request_v1 import RtbHouseNewConnectorRequestV1
from openapi_client.models.s3_new_connector_request_v1 import S3NewConnectorRequestV1
from openapi_client.models.safetyculture_new_connector_request_v1 import SafetycultureNewConnectorRequestV1
from openapi_client.models.sage_hr_new_connector_request_v1 import SageHrNewConnectorRequestV1
from openapi_client.models.sage_intacct_new_connector_request_v1 import SageIntacctNewConnectorRequestV1
from openapi_client.models.sailthru_new_connector_request_v1 import SailthruNewConnectorRequestV1
from openapi_client.models.salesforce_commerce_cloud_new_connector_request_v1 import SalesforceCommerceCloudNewConnectorRequestV1
from openapi_client.models.salesforce_marketing_cloud_new_connector_request_v1 import SalesforceMarketingCloudNewConnectorRequestV1
from openapi_client.models.salesforce_new_connector_request_v1 import SalesforceNewConnectorRequestV1
from openapi_client.models.salesforce_sandbox_new_connector_request_v1 import SalesforceSandboxNewConnectorRequestV1
from openapi_client.models.salesloft_new_connector_request_v1 import SalesloftNewConnectorRequestV1
from openapi_client.models.salsify_new_connector_request_v1 import SalsifyNewConnectorRequestV1
from openapi_client.models.samsara_new_connector_request_v1 import SamsaraNewConnectorRequestV1
from openapi_client.models.sap_business_by_design_new_connector_request_v1 import SapBusinessByDesignNewConnectorRequestV1
from openapi_client.models.sap_hana_db_new_connector_request_v1 import SapHanaDbNewConnectorRequestV1
from openapi_client.models.sap_hana_new_connector_request_v1 import SapHanaNewConnectorRequestV1
from openapi_client.models.sap_s4hana_new_connector_request_v1 import SapS4hanaNewConnectorRequestV1
from openapi_client.models.scorm_new_connector_request_v1 import ScormNewConnectorRequestV1
from openapi_client.models.security_journey_new_connector_request_v1 import SecurityJourneyNewConnectorRequestV1
from openapi_client.models.segment_new_connector_request_v1 import SegmentNewConnectorRequestV1
from openapi_client.models.sendgrid_new_connector_request_v1 import SendgridNewConnectorRequestV1
from openapi_client.models.sensor_tower_new_connector_request_v1 import SensorTowerNewConnectorRequestV1
from openapi_client.models.servicenow_new_connector_request_v1 import ServicenowNewConnectorRequestV1
from openapi_client.models.servicetitan_new_connector_request_v1 import ServicetitanNewConnectorRequestV1
from openapi_client.models.sftp_new_connector_request_v1 import SftpNewConnectorRequestV1
from openapi_client.models.share_point_new_connector_request_v1 import SharePointNewConnectorRequestV1
from openapi_client.models.shiphero_new_connector_request_v1 import ShipheroNewConnectorRequestV1
from openapi_client.models.shipstation_new_connector_request_v1 import ShipstationNewConnectorRequestV1
from openapi_client.models.shopify_new_connector_request_v1 import ShopifyNewConnectorRequestV1
from openapi_client.models.shopware_new_connector_request_v1 import ShopwareNewConnectorRequestV1
from openapi_client.models.shortcut_new_connector_request_v1 import ShortcutNewConnectorRequestV1
from openapi_client.models.shortio_new_connector_request_v1 import ShortioNewConnectorRequestV1
from openapi_client.models.simplecast_new_connector_request_v1 import SimplecastNewConnectorRequestV1
from openapi_client.models.simplesat_new_connector_request_v1 import SimplesatNewConnectorRequestV1
from openapi_client.models.skilljar_new_connector_request_v1 import SkilljarNewConnectorRequestV1
from openapi_client.models.skuvault_new_connector_request_v1 import SkuvaultNewConnectorRequestV1
from openapi_client.models.slab_new_connector_request_v1 import SlabNewConnectorRequestV1
from openapi_client.models.slack_new_connector_request_v1 import SlackNewConnectorRequestV1
from openapi_client.models.smadex_new_connector_request_v1 import SmadexNewConnectorRequestV1
from openapi_client.models.smartwaiver_new_connector_request_v1 import SmartwaiverNewConnectorRequestV1
from openapi_client.models.snapchat_ads_new_connector_request_v1 import SnapchatAdsNewConnectorRequestV1
from openapi_client.models.snowflake_db_new_connector_request_v1 import SnowflakeDbNewConnectorRequestV1
from openapi_client.models.snowplow_new_connector_request_v1 import SnowplowNewConnectorRequestV1
from openapi_client.models.sonarqube_new_connector_request_v1 import SonarqubeNewConnectorRequestV1
from openapi_client.models.splitio_new_connector_request_v1 import SplitioNewConnectorRequestV1
from openapi_client.models.splunk_new_connector_request_v1 import SplunkNewConnectorRequestV1
from openapi_client.models.spotify_ads_new_connector_request_v1 import SpotifyAdsNewConnectorRequestV1
from openapi_client.models.sprout_new_connector_request_v1 import SproutNewConnectorRequestV1
from openapi_client.models.sql_server_hva_new_connector_request_v1 import SqlServerHvaNewConnectorRequestV1
from openapi_client.models.sql_server_new_connector_request_v1 import SqlServerNewConnectorRequestV1
from openapi_client.models.sql_server_rds_new_connector_request_v1 import SqlServerRdsNewConnectorRequestV1
from openapi_client.models.sql_server_sap_ecc_hva_new_connector_request_v1 import SqlServerSapEccHvaNewConnectorRequestV1
from openapi_client.models.square_new_connector_request_v1 import SquareNewConnectorRequestV1
from openapi_client.models.squarespace_new_connector_request_v1 import SquarespaceNewConnectorRequestV1
from openapi_client.models.stackadapt_new_connector_request_v1 import StackadaptNewConnectorRequestV1
from openapi_client.models.standard_metrics_new_connector_request_v1 import StandardMetricsNewConnectorRequestV1
from openapi_client.models.statsig_new_connector_request_v1 import StatsigNewConnectorRequestV1
from openapi_client.models.statuspage_new_connector_request_v1 import StatuspageNewConnectorRequestV1
from openapi_client.models.stripe_new_connector_request_v1 import StripeNewConnectorRequestV1
from openapi_client.models.stripe_test_new_connector_request_v1 import StripeTestNewConnectorRequestV1
from openapi_client.models.stylight_new_connector_request_v1 import StylightNewConnectorRequestV1
from openapi_client.models.subscript_new_connector_request_v1 import SubscriptNewConnectorRequestV1
from openapi_client.models.survey_monkey_new_connector_request_v1 import SurveyMonkeyNewConnectorRequestV1
from openapi_client.models.survicate_new_connector_request_v1 import SurvicateNewConnectorRequestV1
from openapi_client.models.swoogo_new_connector_request_v1 import SwoogoNewConnectorRequestV1
from openapi_client.models.tableau_source_new_connector_request_v1 import TableauSourceNewConnectorRequestV1
from openapi_client.models.taboola_new_connector_request_v1 import TaboolaNewConnectorRequestV1
from openapi_client.models.talkdesk_new_connector_request_v1 import TalkdeskNewConnectorRequestV1
from openapi_client.models.talkwalker_new_connector_request_v1 import TalkwalkerNewConnectorRequestV1
from openapi_client.models.teamwork_new_connector_request_v1 import TeamworkNewConnectorRequestV1
from openapi_client.models.tempo_new_connector_request_v1 import TempoNewConnectorRequestV1
from openapi_client.models.the_trade_desk_new_connector_request_v1 import TheTradeDeskNewConnectorRequestV1
from openapi_client.models.thinkific_new_connector_request_v1 import ThinkificNewConnectorRequestV1
from openapi_client.models.tiktok_ads_new_connector_request_v1 import TiktokAdsNewConnectorRequestV1
from openapi_client.models.toggl_track_new_connector_request_v1 import TogglTrackNewConnectorRequestV1
from openapi_client.models.transcend_new_connector_request_v1 import TranscendNewConnectorRequestV1
from openapi_client.models.trello_new_connector_request_v1 import TrelloNewConnectorRequestV1
from openapi_client.models.trisolute_new_connector_request_v1 import TrisoluteNewConnectorRequestV1
from openapi_client.models.twilio_new_connector_request_v1 import TwilioNewConnectorRequestV1
from openapi_client.models.twitter_ads_new_connector_request_v1 import TwitterAdsNewConnectorRequestV1
from openapi_client.models.twitter_new_connector_request_v1 import TwitterNewConnectorRequestV1
from openapi_client.models.typeform_new_connector_request_v1 import TypeformNewConnectorRequestV1
from openapi_client.models.ukg_pro_new_connector_request_v1 import UkgProNewConnectorRequestV1
from openapi_client.models.unicommerce_new_connector_request_v1 import UnicommerceNewConnectorRequestV1
from openapi_client.models.upland_new_connector_request_v1 import UplandNewConnectorRequestV1
from openapi_client.models.uppromote_new_connector_request_v1 import UppromoteNewConnectorRequestV1
from openapi_client.models.uservoice_new_connector_request_v1 import UservoiceNewConnectorRequestV1
from openapi_client.models.vitally_new_connector_request_v1 import VitallyNewConnectorRequestV1
from openapi_client.models.vonage_new_connector_request_v1 import VonageNewConnectorRequestV1
from openapi_client.models.vts_new_connector_request_v1 import VtsNewConnectorRequestV1
from openapi_client.models.vwo_new_connector_request_v1 import VwoNewConnectorRequestV1
from openapi_client.models.wasabi_cloud_storage_new_connector_request_v1 import WasabiCloudStorageNewConnectorRequestV1
from openapi_client.models.webhooks_new_connector_request_v1 import WebhooksNewConnectorRequestV1
from openapi_client.models.when_i_work_new_connector_request_v1 import WhenIWorkNewConnectorRequestV1
from openapi_client.models.wherefour_new_connector_request_v1 import WherefourNewConnectorRequestV1
from openapi_client.models.woocommerce_new_connector_request_v1 import WoocommerceNewConnectorRequestV1
from openapi_client.models.wordpress_new_connector_request_v1 import WordpressNewConnectorRequestV1
from openapi_client.models.workable_new_connector_request_v1 import WorkableNewConnectorRequestV1
from openapi_client.models.workday_financial_management_new_connector_request_v1 import WorkdayFinancialManagementNewConnectorRequestV1
from openapi_client.models.workday_hcm_new_connector_request_v1 import WorkdayHcmNewConnectorRequestV1
from openapi_client.models.workday_new_connector_request_v1 import WorkdayNewConnectorRequestV1
from openapi_client.models.workday_strategic_sourcing_new_connector_request_v1 import WorkdayStrategicSourcingNewConnectorRequestV1
from openapi_client.models.workflowmax_new_connector_request_v1 import WorkflowmaxNewConnectorRequestV1
from openapi_client.models.workramp_new_connector_request_v1 import WorkrampNewConnectorRequestV1
from openapi_client.models.wrike_new_connector_request_v1 import WrikeNewConnectorRequestV1
from openapi_client.models.xero_new_connector_request_v1 import XeroNewConnectorRequestV1
from openapi_client.models.xray_new_connector_request_v1 import XrayNewConnectorRequestV1
from openapi_client.models.xsolla_new_connector_request_v1 import XsollaNewConnectorRequestV1
from openapi_client.models.yahoo_dsp_new_connector_request_v1 import YahooDspNewConnectorRequestV1
from openapi_client.models.yahoo_gemini_new_connector_request_v1 import YahooGeminiNewConnectorRequestV1
from openapi_client.models.yahoo_search_ads_yahoo_japan_new_connector_request_v1 import YahooSearchAdsYahooJapanNewConnectorRequestV1
from openapi_client.models.yotpo_new_connector_request_v1 import YotpoNewConnectorRequestV1
from openapi_client.models.youtube_analytics_new_connector_request_v1 import YoutubeAnalyticsNewConnectorRequestV1
from openapi_client.models.zendesk_chat_new_connector_request_v1 import ZendeskChatNewConnectorRequestV1
from openapi_client.models.zendesk_new_connector_request_v1 import ZendeskNewConnectorRequestV1
from openapi_client.models.zendesk_sell_new_connector_request_v1 import ZendeskSellNewConnectorRequestV1
from openapi_client.models.zendesk_sunshine_new_connector_request_v1 import ZendeskSunshineNewConnectorRequestV1
from openapi_client.models.zenefits_new_connector_request_v1 import ZenefitsNewConnectorRequestV1
from openapi_client.models.zoho_books_new_connector_request_v1 import ZohoBooksNewConnectorRequestV1
from openapi_client.models.zoho_campaigns_new_connector_request_v1 import ZohoCampaignsNewConnectorRequestV1
from openapi_client.models.zoho_crm_new_connector_request_v1 import ZohoCrmNewConnectorRequestV1
from openapi_client.models.zoho_desk_new_connector_request_v1 import ZohoDeskNewConnectorRequestV1
from openapi_client.models.zoom_new_connector_request_v1 import ZoomNewConnectorRequestV1
from openapi_client.models.zuora_new_connector_request_v1 import ZuoraNewConnectorRequestV1
from openapi_client.models.zuora_sandbox_new_connector_request_v1 import ZuoraSandboxNewConnectorRequestV1
# TODO: Rewrite to not use raise_errors
NewConnectorRequestV1.model_rebuild(raise_errors=False)

