# coding: utf-8

"""
    OpenAPI Definition

    The OpenAPI Specification is a standard format to define the structure and syntax of REST APIs. OpenAPI documents are both machine and human-readable, which enables anyone to easily determine how each API works. [More details](https://www.openapis.org/faq)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, SecretStr, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class OracleHvaConfigV1Config(BaseModel):
    """
    
    """ # noqa: E501
    public_key: Optional[StrictStr] = Field(default=None, description="Public Key")
    agent_user: Optional[StrictStr] = Field(default=None, description="The agent's user.")
    update_method: Optional[Dict[str, Any]] = Field(default=None, description="The method used to detect new or changed rows. Supported values: - `LOGMINER` - Fivetran uses LogMiner, a utility that is part of Oracle Database, to detect modified rows in the source tables. - `TELEPORT` - Fivetran's proprietary replication method that uses compressed snapshots to detect and apply changes.")
    agent_password: Optional[SecretStr] = Field(default=None, description="The agent user's password. It should have a minimum length of 10 characters.")
    agent_public_cert: Optional[StrictStr] = Field(default=None, description="The agent public certificate.")
    tunnel_port: Optional[StrictInt] = Field(default=None, description="SSH port, specify only to connect via an SSH tunnel.")
    database: Optional[StrictStr] = Field(default=None, description="The database name.")
    password: Optional[SecretStr] = Field(default=None, description="The user's password.")
    asm_tns: Optional[StrictStr] = Field(default=None, description="ASM TNS.")
    asm_option: Optional[StrictBool] = Field(default=None, description="Default value: `false`. Set to `true` if you're using ASM on a non-RAC instance.")
    host: Optional[StrictStr] = Field(default=None, description="DB instance host or IP address.")
    schema_prefix: Optional[StrictStr] = Field(default=None, description="Destination schema prefix. Prefix for each replicated schema. For example with prefix 'x', source schemas 'foo' and 'bar' get replicated as 'x_foo' and 'x_bar'. The prefix is permanent and cannot be changed after connection creation")
    agent_host: Optional[StrictStr] = Field(default=None, description="The host of the agent. This is the same as database host, since the agent must be installed in the same machine as source database.")
    asm_password: Optional[SecretStr] = Field(default=None, description="ASM password. Mandatory if `use_oracle_rac` or `asm_option` is set to `true`.")
    connection_type: Optional[Dict[str, Any]] = Field(default=None, description="Possible values:`Directly`, `PrivateLink`, `SshTunnel`. `SshTunnel` is used as a value if this parameter is omitted in the request and any of the following parameter's values is specified: `tunnel_host`, `tunnel_port`, `tunnel_user`. Otherwise, `Directly` is used as a value if the parameter is omitted.")
    pdb_name: Optional[StrictStr] = Field(default=None, description="(Multi-tenant databases only) The database's PDB name. Exclude this parameter for single-tenant databases.")
    use_oracle_rac: Optional[StrictBool] = Field(default=None, description="Default value: `false`. Set to `true` if you're using a RAC instance.")
    always_encrypted: Optional[StrictBool] = Field(default=None, description="Require TLS through Tunnel")
    tunnel_user: Optional[StrictStr] = Field(default=None, description="SSH user, specify only to connect via an SSH tunnel.")
    port: Optional[StrictInt] = Field(default=None, description="The port number.")
    tns: Optional[StrictStr] = Field(default=None, description="Single-tenant database: The database's SID. <br> Multi-tenant database: The database's TNS.")
    tunnel_host: Optional[StrictStr] = Field(default=None, description="SSH host, specify only to connect via an SSH tunnel (do not use a load balancer).")
    agent_ora_home: Optional[StrictStr] = Field(default=None, description="The home directory of the Oracle database.")
    agent_port: Optional[StrictInt] = Field(default=None, description="The port number of the agent.")
    asm_oracle_home: Optional[StrictStr] = Field(default=None, description="ASM Oracle Home path.")
    user: Optional[StrictStr] = Field(default=None, description="The user name.")
    asm_user: Optional[StrictStr] = Field(default=None, description="ASM user. Mandatory if `use_oracle_rac` or `asm_option` is set to `true`.")
    __properties: ClassVar[List[str]] = ["public_key", "agent_user", "update_method", "agent_password", "agent_public_cert", "tunnel_port", "database", "password", "asm_tns", "asm_option", "host", "schema_prefix", "agent_host", "asm_password", "connection_type", "pdb_name", "use_oracle_rac", "always_encrypted", "tunnel_user", "port", "tns", "tunnel_host", "agent_ora_home", "agent_port", "asm_oracle_home", "user", "asm_user"]

    @field_validator('update_method')
    def update_method_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('LOGMINER', 'TELEPORT', 'DIRECT_CAPTURE'):
            raise ValueError("must be one of enum values ('LOGMINER', 'TELEPORT', 'DIRECT_CAPTURE')")
        return value

    @field_validator('connection_type')
    def connection_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Directly', 'PrivateLink', 'SshTunnel'):
            raise ValueError("must be one of enum values ('Directly', 'PrivateLink', 'SshTunnel')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OracleHvaConfigV1Config from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OracleHvaConfigV1Config from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "public_key": obj.get("public_key"),
            "agent_user": obj.get("agent_user"),
            "update_method": obj.get("update_method"),
            "agent_password": obj.get("agent_password"),
            "agent_public_cert": obj.get("agent_public_cert"),
            "tunnel_port": obj.get("tunnel_port"),
            "database": obj.get("database"),
            "password": obj.get("password"),
            "asm_tns": obj.get("asm_tns"),
            "asm_option": obj.get("asm_option"),
            "host": obj.get("host"),
            "schema_prefix": obj.get("schema_prefix"),
            "agent_host": obj.get("agent_host"),
            "asm_password": obj.get("asm_password"),
            "connection_type": obj.get("connection_type"),
            "pdb_name": obj.get("pdb_name"),
            "use_oracle_rac": obj.get("use_oracle_rac"),
            "always_encrypted": obj.get("always_encrypted"),
            "tunnel_user": obj.get("tunnel_user"),
            "port": obj.get("port"),
            "tns": obj.get("tns"),
            "tunnel_host": obj.get("tunnel_host"),
            "agent_ora_home": obj.get("agent_ora_home"),
            "agent_port": obj.get("agent_port"),
            "asm_oracle_home": obj.get("asm_oracle_home"),
            "user": obj.get("user"),
            "asm_user": obj.get("asm_user")
        })
        return _obj


