# coding: utf-8

"""
    OpenAPI Definition

    The OpenAPI Specification is a standard format to define the structure and syntax of REST APIs. OpenAPI documents are both machine and human-readable, which enables anyone to easily determine how each API works. [More details](https://www.openapis.org/faq)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, SecretStr, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class RedshiftConfigV1Config(BaseModel):
    """
    
    """ # noqa: E501
    public_key: Optional[StrictStr] = Field(default=None, description="Public Key")
    auth_type: Optional[Dict[str, Any]] = Field(default=None, description="Authentication type. Default value: `PASSWORD`.")
    connection_type: Optional[Dict[str, Any]] = Field(default=None, description="Connection method. Default value: `Directly`.")
    cluster_region: Optional[StrictStr] = Field(default=None, description="Cluster region. Must be populated if `connection_type` is set to `SshTunnel` and `auth_type` is set to `IAM`.")
    external_id: Optional[StrictStr] = Field(default=None, description="Fivetran generated External ID")
    always_encrypted: Optional[StrictBool] = Field(default=None, description="Require TLS through Tunnel")
    tunnel_user: Optional[StrictStr] = Field(default=None, description="SSH user name. Must be populated if `connection_type` is set to `SshTunnel`.")
    cluster_id: Optional[StrictStr] = Field(default=None, description="Cluster ID. Must be populated if `connection_type` is set to `SshTunnel` and `auth_type` is set to `IAM`.")
    tunnel_port: Optional[StrictInt] = Field(default=None, description="SSH server port name. Must be populated if `connection_type` is set to `SshTunnel`.")
    database: Optional[StrictStr] = Field(default=None, description="Database name")
    password: Optional[SecretStr] = Field(default=None, description="Database user password. Required if authentication type is `PASSWORD`.")
    role_arn: Optional[StrictStr] = Field(default=None, description="Role ARN with Redshift permissions. Required if authentication type is `IAM`.")
    port: Optional[StrictInt] = Field(default=None, description="Server port number")
    host: Optional[StrictStr] = Field(default=None, description="Server name")
    tunnel_host: Optional[StrictStr] = Field(default=None, description="SSH server name. Must be populated if `connection_type` is set to `SshTunnel`.")
    resource_id: Optional[StrictStr] = Field(default=None, description="This field is currently being introduced to test the Self-serve Private Link functionality")
    is_redshift_serverless: Optional[StrictBool] = Field(default=None, description="Is your destination Redshift Serverless")
    user: Optional[StrictStr] = Field(default=None, description="Database user name")
    __properties: ClassVar[List[str]] = ["public_key", "auth_type", "connection_type", "cluster_region", "external_id", "always_encrypted", "tunnel_user", "cluster_id", "tunnel_port", "database", "password", "role_arn", "port", "host", "tunnel_host", "resource_id", "is_redshift_serverless", "user"]

    @field_validator('auth_type')
    def auth_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('PASSWORD', 'IAM'):
            raise ValueError("must be one of enum values ('PASSWORD', 'IAM')")
        return value

    @field_validator('connection_type')
    def connection_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Directly', 'PrivateLink', 'SshTunnel'):
            raise ValueError("must be one of enum values ('Directly', 'PrivateLink', 'SshTunnel')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RedshiftConfigV1Config from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RedshiftConfigV1Config from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "public_key": obj.get("public_key"),
            "auth_type": obj.get("auth_type"),
            "connection_type": obj.get("connection_type"),
            "cluster_region": obj.get("cluster_region"),
            "external_id": obj.get("external_id"),
            "always_encrypted": obj.get("always_encrypted"),
            "tunnel_user": obj.get("tunnel_user"),
            "cluster_id": obj.get("cluster_id"),
            "tunnel_port": obj.get("tunnel_port"),
            "database": obj.get("database"),
            "password": obj.get("password"),
            "role_arn": obj.get("role_arn"),
            "port": obj.get("port"),
            "host": obj.get("host"),
            "tunnel_host": obj.get("tunnel_host"),
            "resource_id": obj.get("resource_id"),
            "is_redshift_serverless": obj.get("is_redshift_serverless"),
            "user": obj.get("user")
        })
        return _obj


