# coding: utf-8

"""
    OpenAPI Definition

    The OpenAPI Specification is a standard format to define the structure and syntax of REST APIs. OpenAPI documents are both machine and human-readable, which enables anyone to easily determine how each API works. [More details](https://www.openapis.org/faq)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, SecretStr, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SnowflakeDbConfigV1Config(BaseModel):
    """
    
    """ # noqa: E501
    role: Optional[StrictStr] = Field(default=None, description="Snowflake Connector role name")
    connection_type: Optional[Dict[str, Any]] = Field(default=None, description="Directly or Private Link")
    auth: Optional[Dict[str, Any]] = Field(default=None, description="Password-based or key-based authentication type")
    update_method: Optional[Dict[str, Any]] = Field(default=None, description="Default value: `Teleport`")
    private_key: Optional[SecretStr] = Field(default=None, description="Private access key.  The field should be specified if authentication type is `KEY_PAIR`.")
    workspace_schema: Optional[StrictStr] = Field(default=None, description="The name of the schema that belongs to the workspace database where the temporary tables will be created.")
    database: Optional[StrictStr] = Field(default=None, description="The database name: Snowflake")
    password: Optional[SecretStr] = Field(default=None, description="The Snowflake user's password.")
    is_private_key_encrypted: Optional[StrictBool] = Field(default=None, description="Indicates that a private key is encrypted. The default value: `false`. The field can be specified if authentication type is `KEY_PAIR`.")
    port: Optional[StrictInt] = Field(default=None, description="The Snowflake optional port number.")
    host: Optional[StrictStr] = Field(default=None, description="Host name")
    passphrase: Optional[SecretStr] = Field(default=None, description="In case private key is encrypted, you are required to enter passphrase that was used to encrypt the private key. The field can be specified if authentication type is `KEY_PAIR`.")
    schema_prefix: Optional[StrictStr] = Field(default=None, description="Destination schema prefix. Prefix for each replicated schema. For example with prefix 'x', source schemas 'foo' and 'bar' get replicated as 'x_foo' and 'x_bar'. The prefix is permanent and cannot be changed after connection creation")
    user: Optional[StrictStr] = Field(default=None, description="The Snowflake username.")
    workspace_name: Optional[StrictStr] = Field(default=None, description="The name of the database where the temporary tables will be created.")
    use_workspace: Optional[StrictBool] = Field(default=None, description="Choose a database and schema to create temporary tables for syncs.")
    __properties: ClassVar[List[str]] = ["role", "connection_type", "auth", "update_method", "private_key", "workspace_schema", "database", "password", "is_private_key_encrypted", "port", "host", "passphrase", "schema_prefix", "user", "workspace_name", "use_workspace"]

    @field_validator('connection_type')
    def connection_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Directly', 'PrivateLink'):
            raise ValueError("must be one of enum values ('Directly', 'PrivateLink')")
        return value

    @field_validator('auth')
    def auth_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('PASSWORD', 'KEY_PAIR'):
            raise ValueError("must be one of enum values ('PASSWORD', 'KEY_PAIR')")
        return value

    @field_validator('update_method')
    def update_method_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('TIME_TRAVEL', 'TELEPORT'):
            raise ValueError("must be one of enum values ('TIME_TRAVEL', 'TELEPORT')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SnowflakeDbConfigV1Config from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SnowflakeDbConfigV1Config from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "role": obj.get("role"),
            "connection_type": obj.get("connection_type"),
            "auth": obj.get("auth"),
            "update_method": obj.get("update_method"),
            "private_key": obj.get("private_key"),
            "workspace_schema": obj.get("workspace_schema"),
            "database": obj.get("database"),
            "password": obj.get("password"),
            "is_private_key_encrypted": obj.get("is_private_key_encrypted"),
            "port": obj.get("port"),
            "host": obj.get("host"),
            "passphrase": obj.get("passphrase"),
            "schema_prefix": obj.get("schema_prefix"),
            "user": obj.get("user"),
            "workspace_name": obj.get("workspace_name"),
            "use_workspace": obj.get("use_workspace")
        })
        return _obj


