# coding: utf-8

"""
    OpenAPI Definition

    The OpenAPI Specification is a standard format to define the structure and syntax of REST APIs. OpenAPI documents are both machine and human-readable, which enables anyone to easily determine how each API works. [More details](https://www.openapis.org/faq)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, SecretStr, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SqlServerSapEccHvaConfigV1Config(BaseModel):
    """
    
    """ # noqa: E501
    public_key: Optional[StrictStr] = Field(default=None, description="Public Key.")
    agent_user: Optional[StrictStr] = Field(default=None, description="The agent's username.")
    tde_certificate: Optional[SecretStr] = Field(default=None, description="Certificate used to protect a database encryption key")
    update_method: Optional[Dict[str, Any]] = Field(default=None, description="(Optional) The incremental update method the connector will use. The possible values are `\"TELEPORT\"` or `\"NATIVE_UPDATE\"`. The type defaults to `\"NATIVE_UPDATE\"` if the value is set to `null` or not specified.")
    agent_password: Optional[SecretStr] = Field(default=None, description="The password for the agent user.")
    agent_public_cert: Optional[StrictStr] = Field(default=None, description="The public certificate generated by the agent.")
    tunnel_port: Optional[StrictInt] = Field(default=None, description="SSH port, specify only to connect via an SSH tunnel.")
    database: Optional[StrictStr] = Field(default=None, description="The database name.")
    password: Optional[SecretStr] = Field(default=None, description="The user's password.")
    tde_password: Optional[SecretStr] = Field(default=None, description="Password of the TDE private key")
    host: Optional[StrictStr] = Field(default=None, description="DB instance host or IP address.")
    schema_prefix: Optional[StrictStr] = Field(default=None, description="Destination schema prefix. Prefix for each replicated schema. For example with prefix 'x', source schemas 'foo' and 'bar' get replicated as 'x_foo' and 'x_bar'. The prefix is permanent and cannot be changed after connection creation")
    agent_host: Optional[StrictStr] = Field(default=None, description="The host address of the machine running the agent. Often the same as the DB host.")
    sap_schema: Optional[StrictStr] = Field(default=None, description="SAP Schema Name.")
    connection_type: Optional[Dict[str, Any]] = Field(default=None, description="Possible values: `Directly`, `PrivateLink`, `SshTunnel`. `SshTunnel` is used as a value if this parameter is omitted in the request and any of the following parameter's values is specified: `tunnel_host`, `tunnel_port`, `tunnel_user`. Otherwise, `Directly` is used as a value if the parameter is omitted.")
    enable_tde: Optional[StrictBool] = Field(default=None, description="Using Transparent Data Encryption (TDE)")
    tde_certificate_name: Optional[StrictStr] = Field(default=None, description="Name of the Certificate used to protect a database encryption key")
    always_encrypted: Optional[StrictBool] = Field(default=None, description="Require TLS.")
    enable_archive_log_only: Optional[StrictBool] = Field(default=None, description="Use archive log only mode")
    tunnel_user: Optional[StrictStr] = Field(default=None, description="SSH user, specify only to connect via an SSH tunnel.")
    tde_private_key: Optional[SecretStr] = Field(default=None, description="Private key associated with the TDE certificate")
    port: Optional[StrictInt] = Field(default=None, description="The port number.")
    archive_log_format: Optional[StrictStr] = Field(default=None, description="Format for archive log file names")
    tunnel_host: Optional[StrictStr] = Field(default=None, description="SSH host, specify only to connect via an SSH tunnel (do not use a load balancer).")
    agent_port: Optional[StrictInt] = Field(default=None, description="The port that the agent has open for Fivetran's connection. Default value is 4343.")
    archive_log_path: Optional[StrictStr] = Field(default=None, description="Directory where archive logs are located")
    user: Optional[StrictStr] = Field(default=None, description="The user name.  For Azure Databases, the format must be `user@domain`.")
    __properties: ClassVar[List[str]] = ["public_key", "agent_user", "tde_certificate", "update_method", "agent_password", "agent_public_cert", "tunnel_port", "database", "password", "tde_password", "host", "schema_prefix", "agent_host", "sap_schema", "connection_type", "enable_tde", "tde_certificate_name", "always_encrypted", "enable_archive_log_only", "tunnel_user", "tde_private_key", "port", "archive_log_format", "tunnel_host", "agent_port", "archive_log_path", "user"]

    @field_validator('update_method')
    def update_method_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('NATIVE_UPDATE', 'TELEPORT', 'DIRECT'):
            raise ValueError("must be one of enum values ('NATIVE_UPDATE', 'TELEPORT', 'DIRECT')")
        return value

    @field_validator('connection_type')
    def connection_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('Directly', 'PrivateLink', 'SshTunnel'):
            raise ValueError("must be one of enum values ('Directly', 'PrivateLink', 'SshTunnel')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SqlServerSapEccHvaConfigV1Config from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SqlServerSapEccHvaConfigV1Config from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "public_key": obj.get("public_key"),
            "agent_user": obj.get("agent_user"),
            "tde_certificate": obj.get("tde_certificate"),
            "update_method": obj.get("update_method"),
            "agent_password": obj.get("agent_password"),
            "agent_public_cert": obj.get("agent_public_cert"),
            "tunnel_port": obj.get("tunnel_port"),
            "database": obj.get("database"),
            "password": obj.get("password"),
            "tde_password": obj.get("tde_password"),
            "host": obj.get("host"),
            "schema_prefix": obj.get("schema_prefix"),
            "agent_host": obj.get("agent_host"),
            "sap_schema": obj.get("sap_schema"),
            "connection_type": obj.get("connection_type"),
            "enable_tde": obj.get("enable_tde"),
            "tde_certificate_name": obj.get("tde_certificate_name"),
            "always_encrypted": obj.get("always_encrypted"),
            "enable_archive_log_only": obj.get("enable_archive_log_only"),
            "tunnel_user": obj.get("tunnel_user"),
            "tde_private_key": obj.get("tde_private_key"),
            "port": obj.get("port"),
            "archive_log_format": obj.get("archive_log_format"),
            "tunnel_host": obj.get("tunnel_host"),
            "agent_port": obj.get("agent_port"),
            "archive_log_path": obj.get("archive_log_path"),
            "user": obj.get("user")
        })
        return _obj


